import themeSwapper from 'tailwindcss-theme-swapper';
import { inputToRGB, rgbToHsv, rgbToHex, TinyColor } from '@ctrl/tinycolor';

const basePreset = {
  content: [],
  theme: {
    extend: {
      columns: {
        1: "1",
        2: "2",
        3: "3",
        4: "4",
        5: "5",
        6: "6",
        7: "7",
        8: "8",
        9: "9",
        10: "10",
        11: "11",
        12: "12",
        13: "13",
        14: "14",
        15: "15",
        16: "16"
      },
      spacing: {
        px: "1px",
        0: "0px",
        0.25: "0.0625rem",
        0.5: "0.125rem",
        0.75: "0.1875rem",
        1: "0.25rem",
        1.25: "0.3125rem",
        1.5: "0.375rem",
        1.75: "0.4375rem",
        2: "0.5rem",
        2.25: "0.5625rem",
        2.5: "0.625rem",
        2.75: "0.6875rem",
        3: "0.75rem",
        3.25: "0.8125rem",
        3.5: "0.875rem",
        3.75: "0.9375rem",
        4: "1rem",
        4.25: "1.0625rem",
        4.5: "1.125rem",
        4.75: "1.1875rem",
        5: "1.25rem",
        5.25: "1.3125rem",
        5.5: "1.375rem",
        5.75: "1.4375rem",
        6: "1.5rem",
        6.25: "1.5625rem",
        6.5: "1.625rem",
        6.75: "1.6875rem",
        7: "1.75rem",
        7.25: "1.8125rem",
        7.5: "1.875rem",
        7.75: "1.9375rem",
        8: "2rem",
        9: "2.25rem",
        10: "2.5rem",
        11: "2.75rem",
        12: "3rem",
        13: "3.25rem",
        14: "3.5rem",
        15: "3.75rem",
        16: "4rem",
        17: "4.25rem",
        18: "4.5rem",
        19: "4.75rem",
        20: "5rem",
        21: "5.25rem",
        22: "5.5rem",
        23: "5.75rem",
        24: "6rem",
        25: "6.25rem",
        26: "6.5rem",
        27: "6.75rem",
        28: "7rem",
        29: "7.25rem",
        30: "7.5rem",
        31: "7.75rem",
        32: "8rem",
        33: "8.25rem",
        34: "8.5rem",
        35: "8.75rem",
        36: "9rem",
        37: "9.25rem",
        38: "9.5rem",
        39: "9.75rem",
        40: "10rem",
        41: "10.25rem",
        42: "10.5rem",
        43: "10.75rem",
        44: "11rem",
        45: "11.25rem",
        46: "11.5rem",
        47: "11.75rem",
        48: "12rem",
        49: "12.25rem",
        50: "12.5rem",
        51: "12.75rem",
        52: "13rem",
        53: "13.25rem",
        54: "13.5rem",
        55: "13.75rem",
        56: "14rem",
        57: "14.25rem",
        58: "14.5rem",
        59: "14.75rem",
        60: "15rem",
        61: "15.25rem",
        62: "15.5rem",
        63: "15.75rem",
        64: "16rem",
        65: "16.25rem",
        66: "16.5rem",
        67: "16.75rem",
        68: "17rem",
        69: "17.25rem",
        70: "17.5rem",
        71: "17.75rem",
        72: "18rem",
        73: "18.25rem",
        74: "18.5rem",
        75: "18.75rem",
        76: "19rem",
        77: "19.25rem",
        78: "19.5rem",
        79: "19.75rem",
        80: "20rem",
        81: "20.25rem",
        82: "20.5rem",
        83: "20.75rem",
        84: "21rem",
        85: "21.25rem",
        86: "21.5rem",
        87: "21.75rem",
        88: "22rem",
        89: "22.25rem",
        90: "22.5rem",
        91: "22.75rem",
        92: "23rem",
        93: "23.25rem",
        94: "23.5rem",
        95: "23.75rem",
        96: "24rem",
        97: "24.25rem",
        98: "24.5rem",
        99: "24.75rem",
        100: "25rem",
        101: "25.25rem",
        102: "25.5rem",
        103: "25.75rem",
        104: "26rem",
        105: "26.25rem",
        106: "26.5rem",
        107: "26.75rem",
        108: "27rem",
        109: "27.25rem",
        110: "27.5rem",
        111: "27.75rem",
        112: "28rem",
        113: "28.25rem",
        114: "28.5rem",
        115: "28.75rem",
        116: "29rem",
        117: "29.25rem",
        118: "29.5rem",
        119: "29.75rem",
        120: "30rem",
        121: "30.25rem",
        122: "30.5rem",
        123: "30.75rem",
        124: "31rem",
        125: "31.25rem",
        126: "31.5rem",
        127: "31.75rem",
        128: "32rem",
        129: "32.25rem",
        130: "32.5rem",
        131: "32.75rem",
        132: "33rem",
        133: "33.25rem",
        134: "33.5rem",
        135: "33.75rem",
        136: "34rem",
        137: "34.25rem",
        138: "34.5rem",
        139: "34.75rem",
        140: "35rem",
        141: "35.25rem",
        142: "35.5rem",
        143: "35.75rem",
        144: "36rem",
        145: "36.25rem",
        146: "36.5rem",
        147: "36.75rem",
        148: "37rem",
        149: "37.25rem",
        150: "37.5rem",
        151: "37.75rem",
        152: "38rem",
        153: "38.25rem",
        154: "38.5rem",
        155: "38.75rem",
        156: "39rem",
        157: "39.25rem",
        158: "39.5rem",
        159: "39.75rem",
        160: "40rem",
        161: "40.25rem",
        162: "40.5rem",
        163: "40.75rem",
        164: "41rem",
        165: "41.25rem",
        166: "41.5rem",
        167: "41.75rem",
        168: "42rem",
        169: "42.25rem",
        170: "42.5rem",
        171: "42.75rem",
        172: "43rem",
        173: "43.25rem",
        174: "43.5rem",
        175: "43.75rem",
        176: "44rem",
        177: "44.25rem",
        178: "44.5rem",
        179: "44.75rem",
        180: "45rem",
        181: "45.25rem",
        182: "45.5rem",
        183: "45.75rem",
        184: "46rem",
        185: "46.25rem",
        186: "46.5rem",
        187: "46.75rem",
        188: "47rem",
        189: "47.25rem",
        190: "47.5rem",
        191: "47.75rem",
        192: "48rem",
        193: "48.25rem",
        194: "48.5rem",
        195: "48.75rem",
        196: "49rem",
        197: "49.25rem",
        198: "49.5rem",
        199: "49.75rem",
        200: "50rem",
        201: "50.25rem",
        202: "50.5rem",
        203: "50.75rem",
        204: "51rem",
        205: "51.25rem",
        206: "51.5rem",
        207: "51.75rem",
        208: "52rem",
        209: "52.25rem",
        210: "52.5rem",
        211: "52.75rem",
        212: "53rem",
        213: "53.25rem",
        214: "53.5rem",
        215: "53.75rem",
        216: "54rem",
        217: "54.25rem",
        218: "54.5rem",
        219: "54.75rem",
        220: "55rem",
        221: "55.25rem",
        222: "55.5rem",
        223: "55.75rem",
        224: "56rem",
        225: "56.25rem",
        226: "56.5rem",
        227: "56.75rem",
        228: "57rem",
        229: "57.25rem",
        230: "57.5rem",
        231: "57.75rem",
        232: "58rem",
        233: "58.25rem",
        234: "58.5rem",
        235: "58.75rem",
        236: "59rem",
        237: "59.25rem",
        238: "59.5rem",
        239: "59.75rem",
        240: "60rem",
        241: "60.25rem",
        242: "60.5rem",
        243: "60.75rem",
        244: "61rem",
        245: "61.25rem",
        246: "61.5rem",
        247: "61.75rem",
        248: "62rem",
        249: "62.25rem",
        250: "62.5rem",
        251: "62.75rem",
        252: "63rem",
        253: "63.25rem",
        254: "63.5rem",
        255: "63.75rem",
        256: "64rem",
        "1px": "1px",
        "2px": "2px",
        "3px": "3px",
        "4px": "4px",
        "5px": "5px",
        "6px": "6px",
        "7px": "7px",
        "8px": "8px",
        "9px": "9px",
        "10px": "10px",
        "11px": "11px",
        "12px": "12px",
        "13px": "13px",
        "14px": "14px",
        "15px": "15px",
        "16px": "16px",
        "17px": "17px",
        "18px": "18px",
        "19px": "19px",
        "20px": "20px",
        "21px": "21px",
        "22px": "22px",
        "23px": "23px",
        "24px": "24px",
        "25px": "25px",
        "26px": "26px",
        "27px": "27px",
        "28px": "28px",
        "29px": "29px",
        "30px": "30px",
        "31px": "31px",
        "32px": "32px",
        "33px": "33px",
        "34px": "34px",
        "35px": "35px",
        "36px": "36px",
        "37px": "37px",
        "38px": "38px",
        "39px": "39px",
        "40px": "40px",
        "41px": "41px",
        "42px": "42px",
        "43px": "43px",
        "44px": "44px",
        "45px": "45px",
        "46px": "46px",
        "47px": "47px",
        "48px": "48px",
        "49px": "49px",
        "50px": "50px",
        "51px": "51px",
        "52px": "52px",
        "53px": "53px",
        "54px": "54px",
        "55px": "55px",
        "56px": "56px",
        "57px": "57px",
        "58px": "58px",
        "59px": "59px",
        "60px": "60px",
        "61px": "61px",
        "62px": "62px",
        "63px": "63px",
        "64px": "64px",
        "65px": "65px",
        "66px": "66px",
        "67px": "67px",
        "68px": "68px",
        "69px": "69px",
        "70px": "70px",
        "71px": "71px",
        "72px": "72px",
        "73px": "73px",
        "74px": "74px",
        "75px": "75px",
        "76px": "76px",
        "77px": "77px",
        "78px": "78px",
        "79px": "79px",
        "80px": "80px",
        "81px": "81px",
        "82px": "82px",
        "83px": "83px",
        "84px": "84px",
        "85px": "85px",
        "86px": "86px",
        "87px": "87px",
        "88px": "88px",
        "89px": "89px",
        "90px": "90px",
        "91px": "91px",
        "92px": "92px",
        "93px": "93px",
        "94px": "94px",
        "95px": "95px",
        "96px": "96px",
        "97px": "97px",
        "98px": "98px",
        "99px": "99px",
        "100px": "100px",
        "101px": "101px",
        "102px": "102px",
        "103px": "103px",
        "104px": "104px",
        "105px": "105px",
        "106px": "106px",
        "107px": "107px",
        "108px": "108px",
        "109px": "109px",
        "110px": "110px",
        "111px": "111px",
        "112px": "112px",
        "113px": "113px",
        "114px": "114px",
        "115px": "115px",
        "116px": "116px",
        "117px": "117px",
        "118px": "118px",
        "119px": "119px",
        "120px": "120px",
        "121px": "121px",
        "122px": "122px",
        "123px": "123px",
        "124px": "124px",
        "125px": "125px",
        "126px": "126px",
        "127px": "127px",
        "128px": "128px",
        "129px": "129px",
        "130px": "130px",
        "131px": "131px",
        "132px": "132px",
        "133px": "133px",
        "134px": "134px",
        "135px": "135px",
        "136px": "136px",
        "137px": "137px",
        "138px": "138px",
        "139px": "139px",
        "140px": "140px",
        "141px": "141px",
        "142px": "142px",
        "143px": "143px",
        "144px": "144px",
        "145px": "145px",
        "146px": "146px",
        "147px": "147px",
        "148px": "148px",
        "149px": "149px",
        "150px": "150px",
        "151px": "151px",
        "152px": "152px",
        "153px": "153px",
        "154px": "154px",
        "155px": "155px",
        "156px": "156px",
        "157px": "157px",
        "158px": "158px",
        "159px": "159px",
        "160px": "160px",
        "161px": "161px",
        "162px": "162px",
        "163px": "163px",
        "164px": "164px",
        "165px": "165px",
        "166px": "166px",
        "167px": "167px",
        "168px": "168px",
        "169px": "169px",
        "170px": "170px",
        "171px": "171px",
        "172px": "172px",
        "173px": "173px",
        "174px": "174px",
        "175px": "175px",
        "176px": "176px",
        "177px": "177px",
        "178px": "178px",
        "179px": "179px",
        "180px": "180px",
        "181px": "181px",
        "182px": "182px",
        "183px": "183px",
        "184px": "184px",
        "185px": "185px",
        "186px": "186px",
        "187px": "187px",
        "188px": "188px",
        "189px": "189px",
        "190px": "190px",
        "191px": "191px",
        "192px": "192px",
        "193px": "193px",
        "194px": "194px",
        "195px": "195px",
        "196px": "196px",
        "197px": "197px",
        "198px": "198px",
        "199px": "199px",
        "200px": "200px",
        "201px": "201px",
        "202px": "202px",
        "203px": "203px",
        "204px": "204px",
        "205px": "205px",
        "206px": "206px",
        "207px": "207px",
        "208px": "208px",
        "209px": "209px",
        "210px": "210px",
        "211px": "211px",
        "212px": "212px",
        "213px": "213px",
        "214px": "214px",
        "215px": "215px",
        "216px": "216px",
        "217px": "217px",
        "218px": "218px",
        "219px": "219px",
        "220px": "220px",
        "221px": "221px",
        "222px": "222px",
        "223px": "223px",
        "224px": "224px",
        "225px": "225px",
        "226px": "226px",
        "227px": "227px",
        "228px": "228px",
        "229px": "229px",
        "230px": "230px",
        "231px": "231px",
        "232px": "232px",
        "233px": "233px",
        "234px": "234px",
        "235px": "235px",
        "236px": "236px",
        "237px": "237px",
        "238px": "238px",
        "239px": "239px",
        "240px": "240px",
        "241px": "241px",
        "242px": "242px",
        "243px": "243px",
        "244px": "244px",
        "245px": "245px",
        "246px": "246px",
        "247px": "247px",
        "248px": "248px",
        "249px": "249px",
        "250px": "250px",
        "251px": "251px",
        "252px": "252px",
        "253px": "253px",
        "254px": "254px",
        "255px": "255px",
        "256px": "256px",
        "257px": "257px",
        "258px": "258px",
        "259px": "259px",
        "260px": "260px",
        "261px": "261px",
        "262px": "262px",
        "263px": "263px",
        "264px": "264px",
        "265px": "265px",
        "266px": "266px",
        "267px": "267px",
        "268px": "268px",
        "269px": "269px",
        "270px": "270px",
        "271px": "271px",
        "272px": "272px",
        "273px": "273px",
        "274px": "274px",
        "275px": "275px",
        "276px": "276px",
        "277px": "277px",
        "278px": "278px",
        "279px": "279px",
        "280px": "280px",
        "281px": "281px",
        "282px": "282px",
        "283px": "283px",
        "284px": "284px",
        "285px": "285px",
        "286px": "286px",
        "287px": "287px",
        "288px": "288px",
        "289px": "289px",
        "290px": "290px",
        "291px": "291px",
        "292px": "292px",
        "293px": "293px",
        "294px": "294px",
        "295px": "295px",
        "296px": "296px",
        "297px": "297px",
        "298px": "298px",
        "299px": "299px",
        "300px": "300px",
        "301px": "301px",
        "302px": "302px",
        "303px": "303px",
        "304px": "304px",
        "305px": "305px",
        "306px": "306px",
        "307px": "307px",
        "308px": "308px",
        "309px": "309px",
        "310px": "310px",
        "311px": "311px",
        "312px": "312px",
        "313px": "313px",
        "314px": "314px",
        "315px": "315px",
        "316px": "316px",
        "317px": "317px",
        "318px": "318px",
        "319px": "319px",
        "320px": "320px",
        "321px": "321px",
        "322px": "322px",
        "323px": "323px",
        "324px": "324px",
        "325px": "325px",
        "326px": "326px",
        "327px": "327px",
        "328px": "328px",
        "329px": "329px",
        "330px": "330px",
        "331px": "331px",
        "332px": "332px",
        "333px": "333px",
        "334px": "334px",
        "335px": "335px",
        "336px": "336px",
        "337px": "337px",
        "338px": "338px",
        "339px": "339px",
        "340px": "340px",
        "341px": "341px",
        "342px": "342px",
        "343px": "343px",
        "344px": "344px",
        "345px": "345px",
        "346px": "346px",
        "347px": "347px",
        "348px": "348px",
        "349px": "349px",
        "350px": "350px",
        "351px": "351px",
        "352px": "352px",
        "353px": "353px",
        "354px": "354px",
        "355px": "355px",
        "356px": "356px",
        "357px": "357px",
        "358px": "358px",
        "359px": "359px",
        "360px": "360px",
        "361px": "361px",
        "362px": "362px",
        "363px": "363px",
        "364px": "364px",
        "365px": "365px",
        "366px": "366px",
        "367px": "367px",
        "368px": "368px",
        "369px": "369px",
        "370px": "370px",
        "371px": "371px",
        "372px": "372px",
        "373px": "373px",
        "374px": "374px",
        "375px": "375px",
        "376px": "376px",
        "377px": "377px",
        "378px": "378px",
        "379px": "379px",
        "380px": "380px",
        "381px": "381px",
        "382px": "382px",
        "383px": "383px",
        "384px": "384px",
        "385px": "385px",
        "386px": "386px",
        "387px": "387px",
        "388px": "388px",
        "389px": "389px",
        "390px": "390px",
        "391px": "391px",
        "392px": "392px",
        "393px": "393px",
        "394px": "394px",
        "395px": "395px",
        "396px": "396px",
        "397px": "397px",
        "398px": "398px",
        "399px": "399px",
        "400px": "400px",
        "401px": "401px",
        "402px": "402px",
        "403px": "403px",
        "404px": "404px",
        "405px": "405px",
        "406px": "406px",
        "407px": "407px",
        "408px": "408px",
        "409px": "409px",
        "410px": "410px",
        "411px": "411px",
        "412px": "412px",
        "413px": "413px",
        "414px": "414px",
        "415px": "415px",
        "416px": "416px",
        "417px": "417px",
        "418px": "418px",
        "419px": "419px",
        "420px": "420px",
        "421px": "421px",
        "422px": "422px",
        "423px": "423px",
        "424px": "424px",
        "425px": "425px",
        "426px": "426px",
        "427px": "427px",
        "428px": "428px",
        "429px": "429px",
        "430px": "430px",
        "431px": "431px",
        "432px": "432px",
        "433px": "433px",
        "434px": "434px",
        "435px": "435px",
        "436px": "436px",
        "437px": "437px",
        "438px": "438px",
        "439px": "439px",
        "440px": "440px",
        "441px": "441px",
        "442px": "442px",
        "443px": "443px",
        "444px": "444px",
        "445px": "445px",
        "446px": "446px",
        "447px": "447px",
        "448px": "448px",
        "449px": "449px",
        "450px": "450px",
        "451px": "451px",
        "452px": "452px",
        "453px": "453px",
        "454px": "454px",
        "455px": "455px",
        "456px": "456px",
        "457px": "457px",
        "458px": "458px",
        "459px": "459px",
        "460px": "460px",
        "461px": "461px",
        "462px": "462px",
        "463px": "463px",
        "464px": "464px",
        "465px": "465px",
        "466px": "466px",
        "467px": "467px",
        "468px": "468px",
        "469px": "469px",
        "470px": "470px",
        "471px": "471px",
        "472px": "472px",
        "473px": "473px",
        "474px": "474px",
        "475px": "475px",
        "476px": "476px",
        "477px": "477px",
        "478px": "478px",
        "479px": "479px",
        "480px": "480px",
        "481px": "481px",
        "482px": "482px",
        "483px": "483px",
        "484px": "484px",
        "485px": "485px",
        "486px": "486px",
        "487px": "487px",
        "488px": "488px",
        "489px": "489px",
        "490px": "490px",
        "491px": "491px",
        "492px": "492px",
        "493px": "493px",
        "494px": "494px",
        "495px": "495px",
        "496px": "496px",
        "497px": "497px",
        "498px": "498px",
        "499px": "499px",
        "500px": "500px",
        "501px": "501px",
        "502px": "502px",
        "503px": "503px",
        "504px": "504px",
        "505px": "505px",
        "506px": "506px",
        "507px": "507px",
        "508px": "508px",
        "509px": "509px",
        "510px": "510px",
        "511px": "511px",
        "512px": "512px",
        "513px": "513px",
        "514px": "514px",
        "515px": "515px",
        "516px": "516px",
        "517px": "517px",
        "518px": "518px",
        "519px": "519px",
        "520px": "520px",
        "521px": "521px",
        "522px": "522px",
        "523px": "523px",
        "524px": "524px",
        "525px": "525px",
        "526px": "526px",
        "527px": "527px",
        "528px": "528px",
        "529px": "529px",
        "530px": "530px",
        "531px": "531px",
        "532px": "532px",
        "533px": "533px",
        "534px": "534px",
        "535px": "535px",
        "536px": "536px",
        "537px": "537px",
        "538px": "538px",
        "539px": "539px",
        "540px": "540px",
        "541px": "541px",
        "542px": "542px",
        "543px": "543px",
        "544px": "544px",
        "545px": "545px",
        "546px": "546px",
        "547px": "547px",
        "548px": "548px",
        "549px": "549px",
        "550px": "550px",
        "551px": "551px",
        "552px": "552px",
        "553px": "553px",
        "554px": "554px",
        "555px": "555px",
        "556px": "556px",
        "557px": "557px",
        "558px": "558px",
        "559px": "559px",
        "560px": "560px",
        "561px": "561px",
        "562px": "562px",
        "563px": "563px",
        "564px": "564px",
        "565px": "565px",
        "566px": "566px",
        "567px": "567px",
        "568px": "568px",
        "569px": "569px",
        "570px": "570px",
        "571px": "571px",
        "572px": "572px",
        "573px": "573px",
        "574px": "574px",
        "575px": "575px",
        "576px": "576px",
        "577px": "577px",
        "578px": "578px",
        "579px": "579px",
        "580px": "580px",
        "581px": "581px",
        "582px": "582px",
        "583px": "583px",
        "584px": "584px",
        "585px": "585px",
        "586px": "586px",
        "587px": "587px",
        "588px": "588px",
        "589px": "589px",
        "590px": "590px",
        "591px": "591px",
        "592px": "592px",
        "593px": "593px",
        "594px": "594px",
        "595px": "595px",
        "596px": "596px",
        "597px": "597px",
        "598px": "598px",
        "599px": "599px",
        "600px": "600px",
        "601px": "601px",
        "602px": "602px",
        "603px": "603px",
        "604px": "604px",
        "605px": "605px",
        "606px": "606px",
        "607px": "607px",
        "608px": "608px",
        "609px": "609px",
        "610px": "610px",
        "611px": "611px",
        "612px": "612px",
        "613px": "613px",
        "614px": "614px",
        "615px": "615px",
        "616px": "616px",
        "617px": "617px",
        "618px": "618px",
        "619px": "619px",
        "620px": "620px",
        "621px": "621px",
        "622px": "622px",
        "623px": "623px",
        "624px": "624px",
        "625px": "625px",
        "626px": "626px",
        "627px": "627px",
        "628px": "628px",
        "629px": "629px",
        "630px": "630px",
        "631px": "631px",
        "632px": "632px",
        "633px": "633px",
        "634px": "634px",
        "635px": "635px",
        "636px": "636px",
        "637px": "637px",
        "638px": "638px",
        "639px": "639px",
        "640px": "640px",
        "641px": "641px",
        "642px": "642px",
        "643px": "643px",
        "644px": "644px",
        "645px": "645px",
        "646px": "646px",
        "647px": "647px",
        "648px": "648px",
        "649px": "649px",
        "650px": "650px",
        "651px": "651px",
        "652px": "652px",
        "653px": "653px",
        "654px": "654px",
        "655px": "655px",
        "656px": "656px",
        "657px": "657px",
        "658px": "658px",
        "659px": "659px",
        "660px": "660px",
        "661px": "661px",
        "662px": "662px",
        "663px": "663px",
        "664px": "664px",
        "665px": "665px",
        "666px": "666px",
        "667px": "667px",
        "668px": "668px",
        "669px": "669px",
        "670px": "670px",
        "671px": "671px",
        "672px": "672px",
        "673px": "673px",
        "674px": "674px",
        "675px": "675px",
        "676px": "676px",
        "677px": "677px",
        "678px": "678px",
        "679px": "679px",
        "680px": "680px",
        "681px": "681px",
        "682px": "682px",
        "683px": "683px",
        "684px": "684px",
        "685px": "685px",
        "686px": "686px",
        "687px": "687px",
        "688px": "688px",
        "689px": "689px",
        "690px": "690px",
        "691px": "691px",
        "692px": "692px",
        "693px": "693px",
        "694px": "694px",
        "695px": "695px",
        "696px": "696px",
        "697px": "697px",
        "698px": "698px",
        "699px": "699px",
        "700px": "700px",
        "701px": "701px",
        "702px": "702px",
        "703px": "703px",
        "704px": "704px",
        "705px": "705px",
        "706px": "706px",
        "707px": "707px",
        "708px": "708px",
        "709px": "709px",
        "710px": "710px",
        "711px": "711px",
        "712px": "712px",
        "713px": "713px",
        "714px": "714px",
        "715px": "715px",
        "716px": "716px",
        "717px": "717px",
        "718px": "718px",
        "719px": "719px",
        "720px": "720px",
        "721px": "721px",
        "722px": "722px",
        "723px": "723px",
        "724px": "724px",
        "725px": "725px",
        "726px": "726px",
        "727px": "727px",
        "728px": "728px",
        "729px": "729px",
        "730px": "730px",
        "731px": "731px",
        "732px": "732px",
        "733px": "733px",
        "734px": "734px",
        "735px": "735px",
        "736px": "736px",
        "737px": "737px",
        "738px": "738px",
        "739px": "739px",
        "740px": "740px",
        "741px": "741px",
        "742px": "742px",
        "743px": "743px",
        "744px": "744px",
        "745px": "745px",
        "746px": "746px",
        "747px": "747px",
        "748px": "748px",
        "749px": "749px",
        "750px": "750px",
        "751px": "751px",
        "752px": "752px",
        "753px": "753px",
        "754px": "754px",
        "755px": "755px",
        "756px": "756px",
        "757px": "757px",
        "758px": "758px",
        "759px": "759px",
        "760px": "760px",
        "761px": "761px",
        "762px": "762px",
        "763px": "763px",
        "764px": "764px",
        "765px": "765px",
        "766px": "766px",
        "767px": "767px",
        "768px": "768px",
        "769px": "769px",
        "770px": "770px",
        "771px": "771px",
        "772px": "772px",
        "773px": "773px",
        "774px": "774px",
        "775px": "775px",
        "776px": "776px",
        "777px": "777px",
        "778px": "778px",
        "779px": "779px",
        "780px": "780px",
        "781px": "781px",
        "782px": "782px",
        "783px": "783px",
        "784px": "784px",
        "785px": "785px",
        "786px": "786px",
        "787px": "787px",
        "788px": "788px",
        "789px": "789px",
        "790px": "790px",
        "791px": "791px",
        "792px": "792px",
        "793px": "793px",
        "794px": "794px",
        "795px": "795px",
        "796px": "796px",
        "797px": "797px",
        "798px": "798px",
        "799px": "799px",
        "800px": "800px",
        "801px": "801px",
        "802px": "802px",
        "803px": "803px",
        "804px": "804px",
        "805px": "805px",
        "806px": "806px",
        "807px": "807px",
        "808px": "808px",
        "809px": "809px",
        "810px": "810px",
        "811px": "811px",
        "812px": "812px",
        "813px": "813px",
        "814px": "814px",
        "815px": "815px",
        "816px": "816px",
        "817px": "817px",
        "818px": "818px",
        "819px": "819px",
        "820px": "820px",
        "821px": "821px",
        "822px": "822px",
        "823px": "823px",
        "824px": "824px",
        "825px": "825px",
        "826px": "826px",
        "827px": "827px",
        "828px": "828px",
        "829px": "829px",
        "830px": "830px",
        "831px": "831px",
        "832px": "832px",
        "833px": "833px",
        "834px": "834px",
        "835px": "835px",
        "836px": "836px",
        "837px": "837px",
        "838px": "838px",
        "839px": "839px",
        "840px": "840px",
        "841px": "841px",
        "842px": "842px",
        "843px": "843px",
        "844px": "844px",
        "845px": "845px",
        "846px": "846px",
        "847px": "847px",
        "848px": "848px",
        "849px": "849px",
        "850px": "850px",
        "851px": "851px",
        "852px": "852px",
        "853px": "853px",
        "854px": "854px",
        "855px": "855px",
        "856px": "856px",
        "857px": "857px",
        "858px": "858px",
        "859px": "859px",
        "860px": "860px",
        "861px": "861px",
        "862px": "862px",
        "863px": "863px",
        "864px": "864px",
        "865px": "865px",
        "866px": "866px",
        "867px": "867px",
        "868px": "868px",
        "869px": "869px",
        "870px": "870px",
        "871px": "871px",
        "872px": "872px",
        "873px": "873px",
        "874px": "874px",
        "875px": "875px",
        "876px": "876px",
        "877px": "877px",
        "878px": "878px",
        "879px": "879px",
        "880px": "880px",
        "881px": "881px",
        "882px": "882px",
        "883px": "883px",
        "884px": "884px",
        "885px": "885px",
        "886px": "886px",
        "887px": "887px",
        "888px": "888px",
        "889px": "889px",
        "890px": "890px",
        "891px": "891px",
        "892px": "892px",
        "893px": "893px",
        "894px": "894px",
        "895px": "895px",
        "896px": "896px",
        "897px": "897px",
        "898px": "898px",
        "899px": "899px",
        "900px": "900px",
        "901px": "901px",
        "902px": "902px",
        "903px": "903px",
        "904px": "904px",
        "905px": "905px",
        "906px": "906px",
        "907px": "907px",
        "908px": "908px",
        "909px": "909px",
        "910px": "910px",
        "911px": "911px",
        "912px": "912px",
        "913px": "913px",
        "914px": "914px",
        "915px": "915px",
        "916px": "916px",
        "917px": "917px",
        "918px": "918px",
        "919px": "919px",
        "920px": "920px",
        "921px": "921px",
        "922px": "922px",
        "923px": "923px",
        "924px": "924px",
        "925px": "925px",
        "926px": "926px",
        "927px": "927px",
        "928px": "928px",
        "929px": "929px",
        "930px": "930px",
        "931px": "931px",
        "932px": "932px",
        "933px": "933px",
        "934px": "934px",
        "935px": "935px",
        "936px": "936px",
        "937px": "937px",
        "938px": "938px",
        "939px": "939px",
        "940px": "940px",
        "941px": "941px",
        "942px": "942px",
        "943px": "943px",
        "944px": "944px",
        "945px": "945px",
        "946px": "946px",
        "947px": "947px",
        "948px": "948px",
        "949px": "949px",
        "950px": "950px",
        "951px": "951px",
        "952px": "952px",
        "953px": "953px",
        "954px": "954px",
        "955px": "955px",
        "956px": "956px",
        "957px": "957px",
        "958px": "958px",
        "959px": "959px",
        "960px": "960px",
        "961px": "961px",
        "962px": "962px",
        "963px": "963px",
        "964px": "964px",
        "965px": "965px",
        "966px": "966px",
        "967px": "967px",
        "968px": "968px",
        "969px": "969px",
        "970px": "970px",
        "971px": "971px",
        "972px": "972px",
        "973px": "973px",
        "974px": "974px",
        "975px": "975px",
        "976px": "976px",
        "977px": "977px",
        "978px": "978px",
        "979px": "979px",
        "980px": "980px",
        "981px": "981px",
        "982px": "982px",
        "983px": "983px",
        "984px": "984px",
        "985px": "985px",
        "986px": "986px",
        "987px": "987px",
        "988px": "988px",
        "989px": "989px",
        "990px": "990px",
        "991px": "991px",
        "992px": "992px",
        "993px": "993px",
        "994px": "994px",
        "995px": "995px",
        "996px": "996px",
        "997px": "997px",
        "998px": "998px",
        "999px": "999px",
        "1000px": "1000px",
        "1001px": "1001px",
        "1002px": "1002px",
        "1003px": "1003px",
        "1004px": "1004px",
        "1005px": "1005px",
        "1006px": "1006px",
        "1007px": "1007px",
        "1008px": "1008px",
        "1009px": "1009px",
        "1010px": "1010px",
        "1011px": "1011px",
        "1012px": "1012px",
        "1013px": "1013px",
        "1014px": "1014px",
        "1015px": "1015px",
        "1016px": "1016px",
        "1017px": "1017px",
        "1018px": "1018px",
        "1019px": "1019px",
        "1020px": "1020px",
        "1021px": "1021px",
        "1022px": "1022px",
        "1023px": "1023px",
        "1024px": "1024px"
      },
      aspectRatio: {
        1: "1",
        2: "2",
        3: "3",
        4: "4",
        5: "5",
        6: "6",
        7: "7",
        8: "8",
        9: "9",
        10: "10",
        11: "11",
        12: "12",
        13: "13",
        14: "14",
        15: "15",
        16: "16"
      },
      blur: {
        px: "1px",
        0: "0",
        0.25: "0.0625rem",
        0.5: "0.125rem",
        0.75: "0.1875rem",
        1: "0.25rem",
        1.25: "0.3125rem",
        1.5: "0.375rem",
        1.75: "0.4375rem",
        2: "0.5rem",
        2.25: "0.5625rem",
        2.5: "0.625rem",
        2.75: "0.6875rem",
        3: "0.75rem",
        3.25: "0.8125rem",
        3.5: "0.875rem",
        3.75: "0.9375rem",
        4: "1rem",
        4.25: "1.0625rem",
        4.5: "1.125rem",
        4.75: "1.1875rem",
        5: "1.25rem",
        5.25: "1.3125rem",
        5.5: "1.375rem",
        5.75: "1.4375rem",
        6: "1.5rem",
        6.25: "1.5625rem",
        6.5: "1.625rem",
        6.75: "1.6875rem",
        7: "1.75rem",
        7.25: "1.8125rem",
        7.5: "1.875rem",
        7.75: "1.9375rem",
        8: "2rem",
        9: "2.25rem",
        10: "2.5rem",
        11: "2.75rem",
        12: "3rem",
        13: "3.25rem",
        14: "3.5rem",
        15: "3.75rem",
        16: "4rem",
        "1px": "1px",
        "2px": "2px",
        "3px": "3px",
        "4px": "4px",
        "5px": "5px",
        "6px": "6px",
        "7px": "7px",
        "8px": "8px",
        "9px": "9px",
        "10px": "10px",
        "11px": "11px",
        "12px": "12px",
        "13px": "13px",
        "14px": "14px",
        "15px": "15px",
        "16px": "16px",
        "17px": "17px",
        "18px": "18px",
        "19px": "19px",
        "20px": "20px",
        "21px": "21px",
        "22px": "22px",
        "23px": "23px",
        "24px": "24px",
        "25px": "25px",
        "26px": "26px",
        "27px": "27px",
        "28px": "28px",
        "29px": "29px",
        "30px": "30px",
        "31px": "31px",
        "32px": "32px",
        "33px": "33px",
        "34px": "34px",
        "35px": "35px",
        "36px": "36px",
        "37px": "37px",
        "38px": "38px",
        "39px": "39px",
        "40px": "40px",
        "41px": "41px",
        "42px": "42px",
        "43px": "43px",
        "44px": "44px",
        "45px": "45px",
        "46px": "46px",
        "47px": "47px",
        "48px": "48px",
        "49px": "49px",
        "50px": "50px",
        "51px": "51px",
        "52px": "52px",
        "53px": "53px",
        "54px": "54px",
        "55px": "55px",
        "56px": "56px",
        "57px": "57px",
        "58px": "58px",
        "59px": "59px",
        "60px": "60px",
        "61px": "61px",
        "62px": "62px",
        "63px": "63px",
        "64px": "64px"
      },
      brightness: {
        0: "0",
        5: ".05",
        10: ".1",
        15: ".15",
        20: ".2",
        25: ".25",
        30: ".3",
        35: ".35",
        40: ".4",
        45: ".45",
        50: ".5",
        55: ".55",
        60: ".6",
        65: ".65",
        70: ".7",
        75: ".75",
        80: ".8",
        85: ".85",
        90: ".9",
        95: ".95",
        100: "1",
        105: "1.05",
        110: "1.1",
        115: "1.15",
        120: "1.2",
        125: "1.25",
        130: "1.3",
        135: "1.35",
        140: "1.4",
        145: "1.45",
        150: "1.5",
        155: "1.55",
        160: "1.6",
        165: "1.65",
        170: "1.7",
        175: "1.75",
        180: "1.8",
        185: "1.85",
        190: "1.9",
        195: "1.95",
        200: "2"
      },
      borderRadius: {
        px: "1px",
        0: "0px",
        0.25: "0.0625rem",
        0.5: "0.125rem",
        0.75: "0.1875rem",
        1: "0.25rem",
        1.25: "0.3125rem",
        1.5: "0.375rem",
        1.75: "0.4375rem",
        2: "0.5rem",
        2.25: "0.5625rem",
        2.5: "0.625rem",
        2.75: "0.6875rem",
        3: "0.75rem",
        3.25: "0.8125rem",
        3.5: "0.875rem",
        3.75: "0.9375rem",
        4: "1rem",
        4.25: "1.0625rem",
        4.5: "1.125rem",
        4.75: "1.1875rem",
        5: "1.25rem",
        5.25: "1.3125rem",
        5.5: "1.375rem",
        5.75: "1.4375rem",
        6: "1.5rem",
        6.25: "1.5625rem",
        6.5: "1.625rem",
        6.75: "1.6875rem",
        7: "1.75rem",
        7.25: "1.8125rem",
        7.5: "1.875rem",
        7.75: "1.9375rem",
        8: "2rem",
        9: "2.25rem",
        10: "2.5rem",
        11: "2.75rem",
        12: "3rem",
        13: "3.25rem",
        14: "3.5rem",
        15: "3.75rem",
        16: "4rem",
        "1px": "1px",
        "2px": "2px",
        "3px": "3px",
        "4px": "4px",
        "5px": "5px",
        "6px": "6px",
        "7px": "7px",
        "8px": "8px",
        "9px": "9px",
        "10px": "10px",
        "11px": "11px",
        "12px": "12px",
        "13px": "13px",
        "14px": "14px",
        "15px": "15px",
        "16px": "16px",
        "17px": "17px",
        "18px": "18px",
        "19px": "19px",
        "20px": "20px",
        "21px": "21px",
        "22px": "22px",
        "23px": "23px",
        "24px": "24px",
        "25px": "25px",
        "26px": "26px",
        "27px": "27px",
        "28px": "28px",
        "29px": "29px",
        "30px": "30px",
        "31px": "31px",
        "32px": "32px",
        "33px": "33px",
        "34px": "34px",
        "35px": "35px",
        "36px": "36px",
        "37px": "37px",
        "38px": "38px",
        "39px": "39px",
        "40px": "40px",
        "41px": "41px",
        "42px": "42px",
        "43px": "43px",
        "44px": "44px",
        "45px": "45px",
        "46px": "46px",
        "47px": "47px",
        "48px": "48px",
        "49px": "49px",
        "50px": "50px",
        "51px": "51px",
        "52px": "52px",
        "53px": "53px",
        "54px": "54px",
        "55px": "55px",
        "56px": "56px",
        "57px": "57px",
        "58px": "58px",
        "59px": "59px",
        "60px": "60px",
        "61px": "61px",
        "62px": "62px",
        "63px": "63px",
        "64px": "64px"
      },
      borderWidth: {
        px: "1px",
        0: "0px",
        1: "1px",
        2: "2px",
        3: "3px",
        4: "4px",
        5: "5px",
        6: "6px",
        7: "7px",
        8: "8px",
        9: "9px",
        10: "10px",
        11: "11px",
        12: "12px",
        13: "13px",
        14: "14px",
        15: "15px",
        16: "16px"
      },
      contrast: {
        0: "0",
        5: ".05",
        10: ".1",
        15: ".15",
        20: ".2",
        25: ".25",
        30: ".3",
        35: ".35",
        40: ".4",
        45: ".45",
        50: ".5",
        55: ".55",
        60: ".6",
        65: ".65",
        70: ".7",
        75: ".75",
        80: ".8",
        85: ".85",
        90: ".9",
        95: ".95",
        100: "1",
        105: "1.05",
        110: "1.1",
        115: "1.15",
        120: "1.2",
        125: "1.25",
        130: "1.3",
        135: "1.35",
        140: "1.4",
        145: "1.45",
        150: "1.5",
        155: "1.55",
        160: "1.6",
        165: "1.65",
        170: "1.7",
        175: "1.75",
        180: "1.8",
        185: "1.85",
        190: "1.9",
        195: "1.95",
        200: "2"
      },
      hueRotate: {
        0: "0deg",
        1: "1deg",
        2: "2deg",
        3: "3deg",
        4: "4deg",
        5: "5deg",
        6: "6deg",
        7: "7deg",
        8: "8deg",
        9: "9deg",
        10: "10deg",
        11: "11deg",
        12: "12deg",
        13: "13deg",
        14: "14deg",
        15: "15deg",
        16: "16deg",
        17: "17deg",
        18: "18deg",
        19: "19deg",
        20: "20deg",
        21: "21deg",
        22: "22deg",
        23: "23deg",
        24: "24deg",
        25: "25deg",
        26: "26deg",
        27: "27deg",
        28: "28deg",
        29: "29deg",
        30: "30deg",
        31: "31deg",
        32: "32deg",
        33: "33deg",
        34: "34deg",
        35: "35deg",
        36: "36deg",
        37: "37deg",
        38: "38deg",
        39: "39deg",
        40: "40deg",
        41: "41deg",
        42: "42deg",
        43: "43deg",
        44: "44deg",
        45: "45deg",
        46: "46deg",
        47: "47deg",
        48: "48deg",
        49: "49deg",
        50: "50deg",
        51: "51deg",
        52: "52deg",
        53: "53deg",
        54: "54deg",
        55: "55deg",
        56: "56deg",
        57: "57deg",
        58: "58deg",
        59: "59deg",
        60: "60deg",
        61: "61deg",
        62: "62deg",
        63: "63deg",
        64: "64deg",
        65: "65deg",
        66: "66deg",
        67: "67deg",
        68: "68deg",
        69: "69deg",
        70: "70deg",
        71: "71deg",
        72: "72deg",
        73: "73deg",
        74: "74deg",
        75: "75deg",
        76: "76deg",
        77: "77deg",
        78: "78deg",
        79: "79deg",
        80: "80deg",
        81: "81deg",
        82: "82deg",
        83: "83deg",
        84: "84deg",
        85: "85deg",
        86: "86deg",
        87: "87deg",
        88: "88deg",
        89: "89deg",
        90: "90deg",
        91: "91deg",
        92: "92deg",
        93: "93deg",
        94: "94deg",
        95: "95deg",
        96: "96deg",
        97: "97deg",
        98: "98deg",
        99: "99deg",
        100: "100deg",
        101: "101deg",
        102: "102deg",
        103: "103deg",
        104: "104deg",
        105: "105deg",
        106: "106deg",
        107: "107deg",
        108: "108deg",
        109: "109deg",
        110: "110deg",
        111: "111deg",
        112: "112deg",
        113: "113deg",
        114: "114deg",
        115: "115deg",
        116: "116deg",
        117: "117deg",
        118: "118deg",
        119: "119deg",
        120: "120deg",
        121: "121deg",
        122: "122deg",
        123: "123deg",
        124: "124deg",
        125: "125deg",
        126: "126deg",
        127: "127deg",
        128: "128deg",
        129: "129deg",
        130: "130deg",
        131: "131deg",
        132: "132deg",
        133: "133deg",
        134: "134deg",
        135: "135deg",
        136: "136deg",
        137: "137deg",
        138: "138deg",
        139: "139deg",
        140: "140deg",
        141: "141deg",
        142: "142deg",
        143: "143deg",
        144: "144deg",
        145: "145deg",
        146: "146deg",
        147: "147deg",
        148: "148deg",
        149: "149deg",
        150: "150deg",
        151: "151deg",
        152: "152deg",
        153: "153deg",
        154: "154deg",
        155: "155deg",
        156: "156deg",
        157: "157deg",
        158: "158deg",
        159: "159deg",
        160: "160deg",
        161: "161deg",
        162: "162deg",
        163: "163deg",
        164: "164deg",
        165: "165deg",
        166: "166deg",
        167: "167deg",
        168: "168deg",
        169: "169deg",
        170: "170deg",
        171: "171deg",
        172: "172deg",
        173: "173deg",
        174: "174deg",
        175: "175deg",
        176: "176deg",
        177: "177deg",
        178: "178deg",
        179: "179deg",
        180: "180deg",
        181: "181deg",
        182: "182deg",
        183: "183deg",
        184: "184deg",
        185: "185deg",
        186: "186deg",
        187: "187deg",
        188: "188deg",
        189: "189deg",
        190: "190deg",
        191: "191deg",
        192: "192deg",
        193: "193deg",
        194: "194deg",
        195: "195deg",
        196: "196deg",
        197: "197deg",
        198: "198deg",
        199: "199deg",
        200: "200deg",
        201: "201deg",
        202: "202deg",
        203: "203deg",
        204: "204deg",
        205: "205deg",
        206: "206deg",
        207: "207deg",
        208: "208deg",
        209: "209deg",
        210: "210deg",
        211: "211deg",
        212: "212deg",
        213: "213deg",
        214: "214deg",
        215: "215deg",
        216: "216deg",
        217: "217deg",
        218: "218deg",
        219: "219deg",
        220: "220deg",
        221: "221deg",
        222: "222deg",
        223: "223deg",
        224: "224deg",
        225: "225deg",
        226: "226deg",
        227: "227deg",
        228: "228deg",
        229: "229deg",
        230: "230deg",
        231: "231deg",
        232: "232deg",
        233: "233deg",
        234: "234deg",
        235: "235deg",
        236: "236deg",
        237: "237deg",
        238: "238deg",
        239: "239deg",
        240: "240deg",
        241: "241deg",
        242: "242deg",
        243: "243deg",
        244: "244deg",
        245: "245deg",
        246: "246deg",
        247: "247deg",
        248: "248deg",
        249: "249deg",
        250: "250deg",
        251: "251deg",
        252: "252deg",
        253: "253deg",
        254: "254deg",
        255: "255deg",
        256: "256deg",
        257: "257deg",
        258: "258deg",
        259: "259deg",
        260: "260deg",
        261: "261deg",
        262: "262deg",
        263: "263deg",
        264: "264deg",
        265: "265deg",
        266: "266deg",
        267: "267deg",
        268: "268deg",
        269: "269deg",
        270: "270deg",
        271: "271deg",
        272: "272deg",
        273: "273deg",
        274: "274deg",
        275: "275deg",
        276: "276deg",
        277: "277deg",
        278: "278deg",
        279: "279deg",
        280: "280deg",
        281: "281deg",
        282: "282deg",
        283: "283deg",
        284: "284deg",
        285: "285deg",
        286: "286deg",
        287: "287deg",
        288: "288deg",
        289: "289deg",
        290: "290deg",
        291: "291deg",
        292: "292deg",
        293: "293deg",
        294: "294deg",
        295: "295deg",
        296: "296deg",
        297: "297deg",
        298: "298deg",
        299: "299deg",
        300: "300deg",
        301: "301deg",
        302: "302deg",
        303: "303deg",
        304: "304deg",
        305: "305deg",
        306: "306deg",
        307: "307deg",
        308: "308deg",
        309: "309deg",
        310: "310deg",
        311: "311deg",
        312: "312deg",
        313: "313deg",
        314: "314deg",
        315: "315deg",
        316: "316deg",
        317: "317deg",
        318: "318deg",
        319: "319deg",
        320: "320deg",
        321: "321deg",
        322: "322deg",
        323: "323deg",
        324: "324deg",
        325: "325deg",
        326: "326deg",
        327: "327deg",
        328: "328deg",
        329: "329deg",
        330: "330deg",
        331: "331deg",
        332: "332deg",
        333: "333deg",
        334: "334deg",
        335: "335deg",
        336: "336deg",
        337: "337deg",
        338: "338deg",
        339: "339deg",
        340: "340deg",
        341: "341deg",
        342: "342deg",
        343: "343deg",
        344: "344deg",
        345: "345deg",
        346: "346deg",
        347: "347deg",
        348: "348deg",
        349: "349deg",
        350: "350deg",
        351: "351deg",
        352: "352deg",
        353: "353deg",
        354: "354deg",
        355: "355deg",
        356: "356deg",
        357: "357deg",
        358: "358deg",
        359: "359deg",
        360: "360deg"
      },
      flexBasis: {
        half: "50%",
        "1/2": "50%",
        "1/3": "33.333333%",
        "2/3": "66.666667%",
        "1/4": "25%",
        "2/4": "50%",
        "3/4": "75%",
        "1/5": "20%",
        "2/5": "40%",
        "3/5": "60%",
        "4/5": "80%",
        "1/6": "16.666667%",
        "2/6": "33.333333%",
        "3/6": "50%",
        "4/6": "66.666667%",
        "5/6": "83.333333%",
        "1/7": "14.285714%",
        "2/7": "28.571429%",
        "3/7": "42.857143%",
        "4/7": "57.142857%",
        "5/7": "71.428571%",
        "6/7": "85.714286%",
        "1/8": "12.5%",
        "2/8": "25%",
        "3/8": "37.5%",
        "4/8": "50%",
        "5/8": "62.5%",
        "6/8": "75%",
        "7/8": "87.5%",
        "1/9": "11.111111%",
        "2/9": "22.222222%",
        "3/9": "33.333333%",
        "4/9": "44.444444%",
        "5/9": "55.555556%",
        "6/9": "66.666667%",
        "7/9": "77.777778%",
        "8/9": "88.888889%",
        "1/10": "10%",
        "2/10": "20%",
        "3/10": "30%",
        "4/10": "40%",
        "5/10": "50%",
        "6/10": "60%",
        "7/10": "70%",
        "8/10": "80%",
        "9/10": "90%",
        "1/11": "9.090909%",
        "2/11": "18.181818%",
        "3/11": "27.272727%",
        "4/11": "36.363636%",
        "5/11": "45.454545%",
        "6/11": "54.545455%",
        "7/11": "63.636364%",
        "8/11": "72.727273%",
        "9/11": "81.818182%",
        "10/11": "90.909091%",
        "1/12": "8.333333%",
        "2/12": "16.666667%",
        "3/12": "25%",
        "4/12": "33.333333%",
        "5/12": "41.666667%",
        "6/12": "50%",
        "7/12": "58.333333%",
        "8/12": "66.666667%",
        "9/12": "75%",
        "10/12": "83.333333%",
        "11/12": "91.666667%",
        "1/13": "7.692308%",
        "2/13": "15.384615%",
        "3/13": "23.076923%",
        "4/13": "30.769231%",
        "5/13": "38.461538%",
        "6/13": "46.153846%",
        "7/13": "53.846154%",
        "8/13": "61.538462%",
        "9/13": "69.230769%",
        "10/13": "76.923077%",
        "11/13": "84.615385%",
        "12/13": "92.307692%",
        "1/14": "7.142857%",
        "2/14": "14.285714%",
        "3/14": "21.428571%",
        "4/14": "28.571429%",
        "5/14": "35.714286%",
        "6/14": "42.857143%",
        "7/14": "50%",
        "8/14": "57.142857%",
        "9/14": "64.285714%",
        "10/14": "71.428571%",
        "11/14": "78.571429%",
        "12/14": "85.714286%",
        "13/14": "92.857143%",
        "1/15": "6.666667%",
        "2/15": "13.333333%",
        "3/15": "20%",
        "4/15": "26.666667%",
        "5/15": "33.333333%",
        "6/15": "40%",
        "7/15": "46.666667%",
        "8/15": "53.333333%",
        "9/15": "60%",
        "10/15": "66.666667%",
        "11/15": "73.333333%",
        "12/15": "80%",
        "13/15": "86.666667%",
        "14/15": "93.333333%",
        "1/16": "6.25%",
        "2/16": "12.5%",
        "3/16": "18.75%",
        "4/16": "25%",
        "5/16": "31.25%",
        "6/16": "37.5%",
        "7/16": "43.75%",
        "8/16": "50%",
        "9/16": "56.25%",
        "10/16": "62.5%",
        "11/16": "68.75%",
        "12/16": "75%",
        "13/16": "81.25%",
        "14/16": "87.5%",
        "15/16": "93.75%"
      },
      flexGrow: {
        0: "0",
        1: "1",
        2: "2",
        3: "3",
        4: "4",
        5: "5",
        6: "6",
        7: "7",
        8: "8"
      },
      flexShrink: {
        0: "0",
        1: "1",
        2: "2",
        3: "3",
        4: "4",
        5: "5",
        6: "6",
        7: "7",
        8: "8"
      },
      fontSize: {
        3: "0.75rem",
        3.25: "0.8125rem",
        3.5: "0.875rem",
        3.75: "0.9375rem",
        4: "1rem",
        4.25: "1.0625rem",
        4.5: "1.125rem",
        4.75: "1.1875rem",
        5: "1.25rem",
        5.25: "1.3125rem",
        5.5: "1.375rem",
        5.75: "1.4375rem",
        6: "1.5rem",
        6.25: "1.5625rem",
        6.5: "1.625rem",
        6.75: "1.6875rem",
        7: "1.75rem",
        7.25: "1.8125rem",
        7.5: "1.875rem",
        7.75: "1.9375rem",
        8: "2rem",
        9: "2.25rem",
        10: "2.5rem",
        11: "2.75rem",
        12: "3rem",
        13: "3.25rem",
        14: "3.5rem",
        15: "3.75rem",
        16: "4rem",
        17: "4.25rem",
        18: "4.5rem",
        19: "4.75rem",
        20: "5rem",
        21: "5.25rem",
        22: "5.5rem",
        23: "5.75rem",
        24: "6rem",
        25: "6.25rem",
        26: "6.5rem",
        27: "6.75rem",
        28: "7rem",
        29: "7.25rem",
        30: "7.5rem",
        31: "7.75rem",
        32: "8rem",
        "12px": "12px",
        "13px": "13px",
        "14px": "14px",
        "15px": "15px",
        "16px": "16px",
        "17px": "17px",
        "18px": "18px",
        "19px": "19px",
        "20px": "20px",
        "21px": "21px",
        "22px": "22px",
        "23px": "23px",
        "24px": "24px",
        "25px": "25px",
        "26px": "26px",
        "27px": "27px",
        "28px": "28px",
        "29px": "29px",
        "30px": "30px",
        "31px": "31px",
        "32px": "32px",
        "33px": "33px",
        "34px": "34px",
        "35px": "35px",
        "36px": "36px",
        "37px": "37px",
        "38px": "38px",
        "39px": "39px",
        "40px": "40px",
        "41px": "41px",
        "42px": "42px",
        "43px": "43px",
        "44px": "44px",
        "45px": "45px",
        "46px": "46px",
        "47px": "47px",
        "48px": "48px",
        "49px": "49px",
        "50px": "50px",
        "51px": "51px",
        "52px": "52px",
        "53px": "53px",
        "54px": "54px",
        "55px": "55px",
        "56px": "56px",
        "57px": "57px",
        "58px": "58px",
        "59px": "59px",
        "60px": "60px",
        "61px": "61px",
        "62px": "62px",
        "63px": "63px",
        "64px": "64px",
        "65px": "65px",
        "66px": "66px",
        "67px": "67px",
        "68px": "68px",
        "69px": "69px",
        "70px": "70px",
        "71px": "71px",
        "72px": "72px",
        "73px": "73px",
        "74px": "74px",
        "75px": "75px",
        "76px": "76px",
        "77px": "77px",
        "78px": "78px",
        "79px": "79px",
        "80px": "80px",
        "81px": "81px",
        "82px": "82px",
        "83px": "83px",
        "84px": "84px",
        "85px": "85px",
        "86px": "86px",
        "87px": "87px",
        "88px": "88px",
        "89px": "89px",
        "90px": "90px",
        "91px": "91px",
        "92px": "92px",
        "93px": "93px",
        "94px": "94px",
        "95px": "95px",
        "96px": "96px",
        "97px": "97px",
        "98px": "98px",
        "99px": "99px",
        "100px": "100px",
        "101px": "101px",
        "102px": "102px",
        "103px": "103px",
        "104px": "104px",
        "105px": "105px",
        "106px": "106px",
        "107px": "107px",
        "108px": "108px",
        "109px": "109px",
        "110px": "110px",
        "111px": "111px",
        "112px": "112px",
        "113px": "113px",
        "114px": "114px",
        "115px": "115px",
        "116px": "116px",
        "117px": "117px",
        "118px": "118px",
        "119px": "119px",
        "120px": "120px",
        "121px": "121px",
        "122px": "122px",
        "123px": "123px",
        "124px": "124px",
        "125px": "125px",
        "126px": "126px",
        "127px": "127px",
        "128px": "128px"
      },
      fontWeight: {
        100: "100",
        200: "200",
        300: "300",
        400: "400",
        500: "500",
        600: "600",
        700: "700",
        800: "800",
        900: "900"
      },
      gridColumn: {
        "span-1": "span 1 / span 1",
        "span-2": "span 2 / span 2",
        "span-3": "span 3 / span 3",
        "span-4": "span 4 / span 4",
        "span-5": "span 5 / span 5",
        "span-6": "span 6 / span 6",
        "span-7": "span 7 / span 7",
        "span-8": "span 8 / span 8",
        "span-9": "span 9 / span 9",
        "span-10": "span 10 / span 10",
        "span-11": "span 11 / span 11",
        "span-12": "span 12 / span 12",
        "span-13": "span 13 / span 13",
        "span-14": "span 14 / span 14",
        "span-15": "span 15 / span 15",
        "span-16": "span 16 / span 16"
      },
      gridColumnEnd: {
        1: "1",
        2: "2",
        3: "3",
        4: "4",
        5: "5",
        6: "6",
        7: "7",
        8: "8",
        9: "9",
        10: "10",
        11: "11",
        12: "12",
        13: "13",
        14: "14",
        15: "15",
        16: "16"
      },
      gridColumnStart: {
        1: "1",
        2: "2",
        3: "3",
        4: "4",
        5: "5",
        6: "6",
        7: "7",
        8: "8",
        9: "9",
        10: "10",
        11: "11",
        12: "12",
        13: "13",
        14: "14",
        15: "15",
        16: "16"
      },
      gridRow: {
        "span-1": "span 1 / span 1",
        "span-2": "span 2 / span 2",
        "span-3": "span 3 / span 3",
        "span-4": "span 4 / span 4",
        "span-5": "span 5 / span 5",
        "span-6": "span 6 / span 6",
        "span-7": "span 7 / span 7",
        "span-8": "span 8 / span 8"
      },
      gridRowStart: {
        1: "1",
        2: "2",
        3: "3",
        4: "4",
        5: "5",
        6: "6",
        7: "7",
        8: "8"
      },
      gridRowEnd: {
        1: "1",
        2: "2",
        3: "3",
        4: "4",
        5: "5",
        6: "6",
        7: "7",
        8: "8"
      },
      gridTemplateColumns: {
        1: "repeat(1, minmax(0, 1fr))",
        2: "repeat(2, minmax(0, 1fr))",
        3: "repeat(3, minmax(0, 1fr))",
        4: "repeat(4, minmax(0, 1fr))",
        5: "repeat(5, minmax(0, 1fr))",
        6: "repeat(6, minmax(0, 1fr))",
        7: "repeat(7, minmax(0, 1fr))",
        8: "repeat(8, minmax(0, 1fr))",
        9: "repeat(9, minmax(0, 1fr))",
        10: "repeat(10, minmax(0, 1fr))",
        11: "repeat(11, minmax(0, 1fr))",
        12: "repeat(12, minmax(0, 1fr))",
        13: "repeat(13, minmax(0, 1fr))",
        14: "repeat(14, minmax(0, 1fr))",
        15: "repeat(15, minmax(0, 1fr))",
        16: "repeat(16, minmax(0, 1fr))"
      },
      gridTemplateRows: {
        1: "repeat(1, minmax(0, 1fr))",
        2: "repeat(2, minmax(0, 1fr))",
        3: "repeat(3, minmax(0, 1fr))",
        4: "repeat(4, minmax(0, 1fr))",
        5: "repeat(5, minmax(0, 1fr))",
        6: "repeat(6, minmax(0, 1fr))",
        7: "repeat(7, minmax(0, 1fr))",
        8: "repeat(8, minmax(0, 1fr))"
      },
      height: {
        half: "50%",
        "1/2": "50%",
        "1/3": "33.333333%",
        "2/3": "66.666667%",
        "1/4": "25%",
        "2/4": "50%",
        "3/4": "75%",
        "1/5": "20%",
        "2/5": "40%",
        "3/5": "60%",
        "4/5": "80%",
        "1/6": "16.666667%",
        "2/6": "33.333333%",
        "3/6": "50%",
        "4/6": "66.666667%",
        "5/6": "83.333333%",
        "1/7": "14.285714%",
        "2/7": "28.571429%",
        "3/7": "42.857143%",
        "4/7": "57.142857%",
        "5/7": "71.428571%",
        "6/7": "85.714286%",
        "1/8": "12.5%",
        "2/8": "25%",
        "3/8": "37.5%",
        "4/8": "50%",
        "5/8": "62.5%",
        "6/8": "75%",
        "7/8": "87.5%",
        "1/9": "11.111111%",
        "2/9": "22.222222%",
        "3/9": "33.333333%",
        "4/9": "44.444444%",
        "5/9": "55.555556%",
        "6/9": "66.666667%",
        "7/9": "77.777778%",
        "8/9": "88.888889%",
        "1/10": "10%",
        "2/10": "20%",
        "3/10": "30%",
        "4/10": "40%",
        "5/10": "50%",
        "6/10": "60%",
        "7/10": "70%",
        "8/10": "80%",
        "9/10": "90%",
        "1/11": "9.090909%",
        "2/11": "18.181818%",
        "3/11": "27.272727%",
        "4/11": "36.363636%",
        "5/11": "45.454545%",
        "6/11": "54.545455%",
        "7/11": "63.636364%",
        "8/11": "72.727273%",
        "9/11": "81.818182%",
        "10/11": "90.909091%",
        "1/12": "8.333333%",
        "2/12": "16.666667%",
        "3/12": "25%",
        "4/12": "33.333333%",
        "5/12": "41.666667%",
        "6/12": "50%",
        "7/12": "58.333333%",
        "8/12": "66.666667%",
        "9/12": "75%",
        "10/12": "83.333333%",
        "11/12": "91.666667%",
        "1/13": "7.692308%",
        "2/13": "15.384615%",
        "3/13": "23.076923%",
        "4/13": "30.769231%",
        "5/13": "38.461538%",
        "6/13": "46.153846%",
        "7/13": "53.846154%",
        "8/13": "61.538462%",
        "9/13": "69.230769%",
        "10/13": "76.923077%",
        "11/13": "84.615385%",
        "12/13": "92.307692%",
        "1/14": "7.142857%",
        "2/14": "14.285714%",
        "3/14": "21.428571%",
        "4/14": "28.571429%",
        "5/14": "35.714286%",
        "6/14": "42.857143%",
        "7/14": "50%",
        "8/14": "57.142857%",
        "9/14": "64.285714%",
        "10/14": "71.428571%",
        "11/14": "78.571429%",
        "12/14": "85.714286%",
        "13/14": "92.857143%",
        "1/15": "6.666667%",
        "2/15": "13.333333%",
        "3/15": "20%",
        "4/15": "26.666667%",
        "5/15": "33.333333%",
        "6/15": "40%",
        "7/15": "46.666667%",
        "8/15": "53.333333%",
        "9/15": "60%",
        "10/15": "66.666667%",
        "11/15": "73.333333%",
        "12/15": "80%",
        "13/15": "86.666667%",
        "14/15": "93.333333%",
        "1/16": "6.25%",
        "2/16": "12.5%",
        "3/16": "18.75%",
        "4/16": "25%",
        "5/16": "31.25%",
        "6/16": "37.5%",
        "7/16": "43.75%",
        "8/16": "50%",
        "9/16": "56.25%",
        "10/16": "62.5%",
        "11/16": "68.75%",
        "12/16": "75%",
        "13/16": "81.25%",
        "14/16": "87.5%",
        "15/16": "93.75%"
      },
      inset: {
        half: "50%",
        "1/2": "50%",
        "1/3": "33.333333%",
        "2/3": "66.666667%",
        "1/4": "25%",
        "2/4": "50%",
        "3/4": "75%",
        "1/5": "20%",
        "2/5": "40%",
        "3/5": "60%",
        "4/5": "80%",
        "1/6": "16.666667%",
        "2/6": "33.333333%",
        "3/6": "50%",
        "4/6": "66.666667%",
        "5/6": "83.333333%",
        "1/7": "14.285714%",
        "2/7": "28.571429%",
        "3/7": "42.857143%",
        "4/7": "57.142857%",
        "5/7": "71.428571%",
        "6/7": "85.714286%",
        "1/8": "12.5%",
        "2/8": "25%",
        "3/8": "37.5%",
        "4/8": "50%",
        "5/8": "62.5%",
        "6/8": "75%",
        "7/8": "87.5%",
        "1/9": "11.111111%",
        "2/9": "22.222222%",
        "3/9": "33.333333%",
        "4/9": "44.444444%",
        "5/9": "55.555556%",
        "6/9": "66.666667%",
        "7/9": "77.777778%",
        "8/9": "88.888889%",
        "1/10": "10%",
        "2/10": "20%",
        "3/10": "30%",
        "4/10": "40%",
        "5/10": "50%",
        "6/10": "60%",
        "7/10": "70%",
        "8/10": "80%",
        "9/10": "90%",
        "1/11": "9.090909%",
        "2/11": "18.181818%",
        "3/11": "27.272727%",
        "4/11": "36.363636%",
        "5/11": "45.454545%",
        "6/11": "54.545455%",
        "7/11": "63.636364%",
        "8/11": "72.727273%",
        "9/11": "81.818182%",
        "10/11": "90.909091%",
        "1/12": "8.333333%",
        "2/12": "16.666667%",
        "3/12": "25%",
        "4/12": "33.333333%",
        "5/12": "41.666667%",
        "6/12": "50%",
        "7/12": "58.333333%",
        "8/12": "66.666667%",
        "9/12": "75%",
        "10/12": "83.333333%",
        "11/12": "91.666667%",
        "1/13": "7.692308%",
        "2/13": "15.384615%",
        "3/13": "23.076923%",
        "4/13": "30.769231%",
        "5/13": "38.461538%",
        "6/13": "46.153846%",
        "7/13": "53.846154%",
        "8/13": "61.538462%",
        "9/13": "69.230769%",
        "10/13": "76.923077%",
        "11/13": "84.615385%",
        "12/13": "92.307692%",
        "1/14": "7.142857%",
        "2/14": "14.285714%",
        "3/14": "21.428571%",
        "4/14": "28.571429%",
        "5/14": "35.714286%",
        "6/14": "42.857143%",
        "7/14": "50%",
        "8/14": "57.142857%",
        "9/14": "64.285714%",
        "10/14": "71.428571%",
        "11/14": "78.571429%",
        "12/14": "85.714286%",
        "13/14": "92.857143%",
        "1/15": "6.666667%",
        "2/15": "13.333333%",
        "3/15": "20%",
        "4/15": "26.666667%",
        "5/15": "33.333333%",
        "6/15": "40%",
        "7/15": "46.666667%",
        "8/15": "53.333333%",
        "9/15": "60%",
        "10/15": "66.666667%",
        "11/15": "73.333333%",
        "12/15": "80%",
        "13/15": "86.666667%",
        "14/15": "93.333333%",
        "1/16": "6.25%",
        "2/16": "12.5%",
        "3/16": "18.75%",
        "4/16": "25%",
        "5/16": "31.25%",
        "6/16": "37.5%",
        "7/16": "43.75%",
        "8/16": "50%",
        "9/16": "56.25%",
        "10/16": "62.5%",
        "11/16": "68.75%",
        "12/16": "75%",
        "13/16": "81.25%",
        "14/16": "87.5%",
        "15/16": "93.75%"
      },
      lineHeight: {
        3: "0.75rem",
        3.25: "0.8125rem",
        3.5: "0.875rem",
        3.75: "0.9375rem",
        4: "1rem",
        4.25: "1.0625rem",
        4.5: "1.125rem",
        4.75: "1.1875rem",
        5: "1.25rem",
        5.25: "1.3125rem",
        5.5: "1.375rem",
        5.75: "1.4375rem",
        6: "1.5rem",
        6.25: "1.5625rem",
        6.5: "1.625rem",
        6.75: "1.6875rem",
        7: "1.75rem",
        7.25: "1.8125rem",
        7.5: "1.875rem",
        7.75: "1.9375rem",
        8: "2rem",
        9: "2.25rem",
        10: "2.5rem",
        11: "2.75rem",
        12: "3rem",
        13: "3.25rem",
        14: "3.5rem",
        15: "3.75rem",
        16: "4rem",
        17: "4.25rem",
        18: "4.5rem",
        19: "4.75rem",
        20: "5rem",
        21: "5.25rem",
        22: "5.5rem",
        23: "5.75rem",
        24: "6rem",
        25: "6.25rem",
        26: "6.5rem",
        27: "6.75rem",
        28: "7rem",
        29: "7.25rem",
        30: "7.5rem",
        31: "7.75rem",
        32: "8rem",
        "12px": "12px",
        "13px": "13px",
        "14px": "14px",
        "15px": "15px",
        "16px": "16px",
        "17px": "17px",
        "18px": "18px",
        "19px": "19px",
        "20px": "20px",
        "21px": "21px",
        "22px": "22px",
        "23px": "23px",
        "24px": "24px",
        "25px": "25px",
        "26px": "26px",
        "27px": "27px",
        "28px": "28px",
        "29px": "29px",
        "30px": "30px",
        "31px": "31px",
        "32px": "32px",
        "33px": "33px",
        "34px": "34px",
        "35px": "35px",
        "36px": "36px",
        "37px": "37px",
        "38px": "38px",
        "39px": "39px",
        "40px": "40px",
        "41px": "41px",
        "42px": "42px",
        "43px": "43px",
        "44px": "44px",
        "45px": "45px",
        "46px": "46px",
        "47px": "47px",
        "48px": "48px",
        "49px": "49px",
        "50px": "50px",
        "51px": "51px",
        "52px": "52px",
        "53px": "53px",
        "54px": "54px",
        "55px": "55px",
        "56px": "56px",
        "57px": "57px",
        "58px": "58px",
        "59px": "59px",
        "60px": "60px",
        "61px": "61px",
        "62px": "62px",
        "63px": "63px",
        "64px": "64px",
        "65px": "65px",
        "66px": "66px",
        "67px": "67px",
        "68px": "68px",
        "69px": "69px",
        "70px": "70px",
        "71px": "71px",
        "72px": "72px",
        "73px": "73px",
        "74px": "74px",
        "75px": "75px",
        "76px": "76px",
        "77px": "77px",
        "78px": "78px",
        "79px": "79px",
        "80px": "80px",
        "81px": "81px",
        "82px": "82px",
        "83px": "83px",
        "84px": "84px",
        "85px": "85px",
        "86px": "86px",
        "87px": "87px",
        "88px": "88px",
        "89px": "89px",
        "90px": "90px",
        "91px": "91px",
        "92px": "92px",
        "93px": "93px",
        "94px": "94px",
        "95px": "95px",
        "96px": "96px",
        "97px": "97px",
        "98px": "98px",
        "99px": "99px",
        "100px": "100px",
        "101px": "101px",
        "102px": "102px",
        "103px": "103px",
        "104px": "104px",
        "105px": "105px",
        "106px": "106px",
        "107px": "107px",
        "108px": "108px",
        "109px": "109px",
        "110px": "110px",
        "111px": "111px",
        "112px": "112px",
        "113px": "113px",
        "114px": "114px",
        "115px": "115px",
        "116px": "116px",
        "117px": "117px",
        "118px": "118px",
        "119px": "119px",
        "120px": "120px",
        "121px": "121px",
        "122px": "122px",
        "123px": "123px",
        "124px": "124px",
        "125px": "125px",
        "126px": "126px",
        "127px": "127px",
        "128px": "128px"
      },
      maxHeight: ({ theme }) => ({
        ...theme("spacing"),
        half: "50%",
        px: "1px",
        "1px": "1px",
        none: "0rem",
        0: "0px"
      }),
      maxWidth: ({ theme }) => ({
        ...theme("spacing"),
        half: "50%",
        px: "1px",
        "1px": "1px",
        none: "0rem",
        0: "0px"
      }),
      minHeight: ({ theme }) => ({
        ...theme("spacing"),
        half: "50%",
        px: "1px",
        "1px": "1px",
        none: "0rem",
        0: "0px"
      }),
      minWidth: ({ theme }) => ({
        ...theme("spacing"),
        half: "50%",
        px: "1px",
        "1px": "1px",
        none: "0rem",
        0: "0px"
      }),
      opacity: {
        0: "0",
        5: "0.05",
        10: "0.1",
        15: "0.15",
        20: "0.2",
        25: "0.25",
        30: "0.3",
        35: "0.35",
        40: "0.4",
        45: "0.45",
        50: "0.5",
        55: "0.55",
        60: "0.6",
        65: "0.65",
        70: "0.7",
        75: "0.75",
        80: "0.8",
        85: "0.85",
        90: "0.9",
        95: "0.95",
        100: "1"
      },
      order: {
        0: "0",
        1: "1",
        2: "2",
        3: "3",
        4: "4",
        5: "5",
        6: "6",
        7: "7",
        8: "8",
        9: "9",
        10: "10",
        11: "11",
        12: "12",
        13: "13",
        14: "14",
        15: "15",
        16: "16"
      },
      outlineOffset: {
        0: "0px",
        1: "1px",
        2: "2px",
        3: "3px",
        4: "4px",
        5: "5px",
        6: "6px",
        7: "7px",
        8: "8px"
      },
      outlineWidth: {
        0: "0px",
        1: "1px",
        2: "2px",
        3: "3px",
        4: "4px",
        5: "5px",
        6: "6px",
        7: "7px",
        8: "8px"
      },
      ringOffsetWidth: {
        0: "0px",
        1: "1px",
        2: "2px",
        3: "3px",
        4: "4px",
        5: "5px",
        6: "6px",
        7: "7px",
        8: "8px"
      },
      ringWidth: {
        0: "0px",
        1: "1px",
        2: "2px",
        3: "3px",
        4: "4px",
        5: "5px",
        6: "6px",
        7: "7px",
        8: "8px"
      },
      rotate: {
        0: "0deg",
        1: "1deg",
        2: "2deg",
        3: "3deg",
        4: "4deg",
        5: "5deg",
        6: "6deg",
        7: "7deg",
        8: "8deg",
        9: "9deg",
        10: "10deg",
        11: "11deg",
        12: "12deg",
        13: "13deg",
        14: "14deg",
        15: "15deg",
        16: "16deg",
        17: "17deg",
        18: "18deg",
        19: "19deg",
        20: "20deg",
        21: "21deg",
        22: "22deg",
        23: "23deg",
        24: "24deg",
        25: "25deg",
        26: "26deg",
        27: "27deg",
        28: "28deg",
        29: "29deg",
        30: "30deg",
        31: "31deg",
        32: "32deg",
        33: "33deg",
        34: "34deg",
        35: "35deg",
        36: "36deg",
        37: "37deg",
        38: "38deg",
        39: "39deg",
        40: "40deg",
        41: "41deg",
        42: "42deg",
        43: "43deg",
        44: "44deg",
        45: "45deg",
        46: "46deg",
        47: "47deg",
        48: "48deg",
        49: "49deg",
        50: "50deg",
        51: "51deg",
        52: "52deg",
        53: "53deg",
        54: "54deg",
        55: "55deg",
        56: "56deg",
        57: "57deg",
        58: "58deg",
        59: "59deg",
        60: "60deg",
        61: "61deg",
        62: "62deg",
        63: "63deg",
        64: "64deg",
        65: "65deg",
        66: "66deg",
        67: "67deg",
        68: "68deg",
        69: "69deg",
        70: "70deg",
        71: "71deg",
        72: "72deg",
        73: "73deg",
        74: "74deg",
        75: "75deg",
        76: "76deg",
        77: "77deg",
        78: "78deg",
        79: "79deg",
        80: "80deg",
        81: "81deg",
        82: "82deg",
        83: "83deg",
        84: "84deg",
        85: "85deg",
        86: "86deg",
        87: "87deg",
        88: "88deg",
        89: "89deg",
        90: "90deg",
        91: "91deg",
        92: "92deg",
        93: "93deg",
        94: "94deg",
        95: "95deg",
        96: "96deg",
        97: "97deg",
        98: "98deg",
        99: "99deg",
        100: "100deg",
        101: "101deg",
        102: "102deg",
        103: "103deg",
        104: "104deg",
        105: "105deg",
        106: "106deg",
        107: "107deg",
        108: "108deg",
        109: "109deg",
        110: "110deg",
        111: "111deg",
        112: "112deg",
        113: "113deg",
        114: "114deg",
        115: "115deg",
        116: "116deg",
        117: "117deg",
        118: "118deg",
        119: "119deg",
        120: "120deg",
        121: "121deg",
        122: "122deg",
        123: "123deg",
        124: "124deg",
        125: "125deg",
        126: "126deg",
        127: "127deg",
        128: "128deg",
        129: "129deg",
        130: "130deg",
        131: "131deg",
        132: "132deg",
        133: "133deg",
        134: "134deg",
        135: "135deg",
        136: "136deg",
        137: "137deg",
        138: "138deg",
        139: "139deg",
        140: "140deg",
        141: "141deg",
        142: "142deg",
        143: "143deg",
        144: "144deg",
        145: "145deg",
        146: "146deg",
        147: "147deg",
        148: "148deg",
        149: "149deg",
        150: "150deg",
        151: "151deg",
        152: "152deg",
        153: "153deg",
        154: "154deg",
        155: "155deg",
        156: "156deg",
        157: "157deg",
        158: "158deg",
        159: "159deg",
        160: "160deg",
        161: "161deg",
        162: "162deg",
        163: "163deg",
        164: "164deg",
        165: "165deg",
        166: "166deg",
        167: "167deg",
        168: "168deg",
        169: "169deg",
        170: "170deg",
        171: "171deg",
        172: "172deg",
        173: "173deg",
        174: "174deg",
        175: "175deg",
        176: "176deg",
        177: "177deg",
        178: "178deg",
        179: "179deg",
        180: "180deg",
        181: "181deg",
        182: "182deg",
        183: "183deg",
        184: "184deg",
        185: "185deg",
        186: "186deg",
        187: "187deg",
        188: "188deg",
        189: "189deg",
        190: "190deg",
        191: "191deg",
        192: "192deg",
        193: "193deg",
        194: "194deg",
        195: "195deg",
        196: "196deg",
        197: "197deg",
        198: "198deg",
        199: "199deg",
        200: "200deg",
        201: "201deg",
        202: "202deg",
        203: "203deg",
        204: "204deg",
        205: "205deg",
        206: "206deg",
        207: "207deg",
        208: "208deg",
        209: "209deg",
        210: "210deg",
        211: "211deg",
        212: "212deg",
        213: "213deg",
        214: "214deg",
        215: "215deg",
        216: "216deg",
        217: "217deg",
        218: "218deg",
        219: "219deg",
        220: "220deg",
        221: "221deg",
        222: "222deg",
        223: "223deg",
        224: "224deg",
        225: "225deg",
        226: "226deg",
        227: "227deg",
        228: "228deg",
        229: "229deg",
        230: "230deg",
        231: "231deg",
        232: "232deg",
        233: "233deg",
        234: "234deg",
        235: "235deg",
        236: "236deg",
        237: "237deg",
        238: "238deg",
        239: "239deg",
        240: "240deg",
        241: "241deg",
        242: "242deg",
        243: "243deg",
        244: "244deg",
        245: "245deg",
        246: "246deg",
        247: "247deg",
        248: "248deg",
        249: "249deg",
        250: "250deg",
        251: "251deg",
        252: "252deg",
        253: "253deg",
        254: "254deg",
        255: "255deg",
        256: "256deg",
        257: "257deg",
        258: "258deg",
        259: "259deg",
        260: "260deg",
        261: "261deg",
        262: "262deg",
        263: "263deg",
        264: "264deg",
        265: "265deg",
        266: "266deg",
        267: "267deg",
        268: "268deg",
        269: "269deg",
        270: "270deg",
        271: "271deg",
        272: "272deg",
        273: "273deg",
        274: "274deg",
        275: "275deg",
        276: "276deg",
        277: "277deg",
        278: "278deg",
        279: "279deg",
        280: "280deg",
        281: "281deg",
        282: "282deg",
        283: "283deg",
        284: "284deg",
        285: "285deg",
        286: "286deg",
        287: "287deg",
        288: "288deg",
        289: "289deg",
        290: "290deg",
        291: "291deg",
        292: "292deg",
        293: "293deg",
        294: "294deg",
        295: "295deg",
        296: "296deg",
        297: "297deg",
        298: "298deg",
        299: "299deg",
        300: "300deg",
        301: "301deg",
        302: "302deg",
        303: "303deg",
        304: "304deg",
        305: "305deg",
        306: "306deg",
        307: "307deg",
        308: "308deg",
        309: "309deg",
        310: "310deg",
        311: "311deg",
        312: "312deg",
        313: "313deg",
        314: "314deg",
        315: "315deg",
        316: "316deg",
        317: "317deg",
        318: "318deg",
        319: "319deg",
        320: "320deg",
        321: "321deg",
        322: "322deg",
        323: "323deg",
        324: "324deg",
        325: "325deg",
        326: "326deg",
        327: "327deg",
        328: "328deg",
        329: "329deg",
        330: "330deg",
        331: "331deg",
        332: "332deg",
        333: "333deg",
        334: "334deg",
        335: "335deg",
        336: "336deg",
        337: "337deg",
        338: "338deg",
        339: "339deg",
        340: "340deg",
        341: "341deg",
        342: "342deg",
        343: "343deg",
        344: "344deg",
        345: "345deg",
        346: "346deg",
        347: "347deg",
        348: "348deg",
        349: "349deg",
        350: "350deg",
        351: "351deg",
        352: "352deg",
        353: "353deg",
        354: "354deg",
        355: "355deg",
        356: "356deg",
        357: "357deg",
        358: "358deg",
        359: "359deg",
        360: "360deg"
      },
      saturate: {
        0: "0",
        5: ".05",
        10: ".1",
        15: ".15",
        20: ".2",
        25: ".25",
        30: ".3",
        35: ".35",
        40: ".4",
        45: ".45",
        50: ".5",
        55: ".55",
        60: ".6",
        65: ".65",
        70: ".7",
        75: ".75",
        80: ".8",
        85: ".85",
        90: ".9",
        95: ".95",
        100: "1",
        105: "1.05",
        110: "1.1",
        115: "1.15",
        120: "1.2",
        125: "1.25",
        130: "1.3",
        135: "1.35",
        140: "1.4",
        145: "1.45",
        150: "1.5",
        155: "1.55",
        160: "1.6",
        165: "1.65",
        170: "1.7",
        175: "1.75",
        180: "1.8",
        185: "1.85",
        190: "1.9",
        195: "1.95",
        200: "2"
      },
      scale: {
        0: "0",
        5: ".05",
        10: ".1",
        15: ".15",
        20: ".2",
        25: ".25",
        30: ".3",
        35: ".35",
        40: ".4",
        45: ".45",
        50: ".5",
        55: ".55",
        60: ".6",
        65: ".65",
        70: ".7",
        75: ".75",
        80: ".8",
        85: ".85",
        90: ".9",
        95: ".95",
        100: "1",
        105: "1.05",
        110: "1.1",
        115: "1.15",
        120: "1.2",
        125: "1.25",
        130: "1.3",
        135: "1.35",
        140: "1.4",
        145: "1.45",
        150: "1.5",
        155: "1.55",
        160: "1.6",
        165: "1.65",
        170: "1.7",
        175: "1.75",
        180: "1.8",
        185: "1.85",
        190: "1.9",
        195: "1.95",
        200: "2"
      },
      skew: {
        0: "0deg",
        1: "1deg",
        2: "2deg",
        3: "3deg",
        4: "4deg",
        5: "5deg",
        6: "6deg",
        7: "7deg",
        8: "8deg",
        9: "9deg",
        10: "10deg",
        11: "11deg",
        12: "12deg",
        13: "13deg",
        14: "14deg",
        15: "15deg",
        16: "16deg",
        17: "17deg",
        18: "18deg",
        19: "19deg",
        20: "20deg",
        21: "21deg",
        22: "22deg",
        23: "23deg",
        24: "24deg",
        25: "25deg",
        26: "26deg",
        27: "27deg",
        28: "28deg",
        29: "29deg",
        30: "30deg",
        31: "31deg",
        32: "32deg",
        33: "33deg",
        34: "34deg",
        35: "35deg",
        36: "36deg",
        37: "37deg",
        38: "38deg",
        39: "39deg",
        40: "40deg",
        41: "41deg",
        42: "42deg",
        43: "43deg",
        44: "44deg",
        45: "45deg",
        46: "46deg",
        47: "47deg",
        48: "48deg",
        49: "49deg",
        50: "50deg",
        51: "51deg",
        52: "52deg",
        53: "53deg",
        54: "54deg",
        55: "55deg",
        56: "56deg",
        57: "57deg",
        58: "58deg",
        59: "59deg",
        60: "60deg",
        61: "61deg",
        62: "62deg",
        63: "63deg",
        64: "64deg",
        65: "65deg",
        66: "66deg",
        67: "67deg",
        68: "68deg",
        69: "69deg",
        70: "70deg",
        71: "71deg",
        72: "72deg",
        73: "73deg",
        74: "74deg",
        75: "75deg",
        76: "76deg",
        77: "77deg",
        78: "78deg",
        79: "79deg",
        80: "80deg",
        81: "81deg",
        82: "82deg",
        83: "83deg",
        84: "84deg",
        85: "85deg",
        86: "86deg",
        87: "87deg",
        88: "88deg",
        89: "89deg",
        90: "90deg",
        91: "91deg",
        92: "92deg",
        93: "93deg",
        94: "94deg",
        95: "95deg",
        96: "96deg",
        97: "97deg",
        98: "98deg",
        99: "99deg",
        100: "100deg",
        101: "101deg",
        102: "102deg",
        103: "103deg",
        104: "104deg",
        105: "105deg",
        106: "106deg",
        107: "107deg",
        108: "108deg",
        109: "109deg",
        110: "110deg",
        111: "111deg",
        112: "112deg",
        113: "113deg",
        114: "114deg",
        115: "115deg",
        116: "116deg",
        117: "117deg",
        118: "118deg",
        119: "119deg",
        120: "120deg",
        121: "121deg",
        122: "122deg",
        123: "123deg",
        124: "124deg",
        125: "125deg",
        126: "126deg",
        127: "127deg",
        128: "128deg",
        129: "129deg",
        130: "130deg",
        131: "131deg",
        132: "132deg",
        133: "133deg",
        134: "134deg",
        135: "135deg",
        136: "136deg",
        137: "137deg",
        138: "138deg",
        139: "139deg",
        140: "140deg",
        141: "141deg",
        142: "142deg",
        143: "143deg",
        144: "144deg",
        145: "145deg",
        146: "146deg",
        147: "147deg",
        148: "148deg",
        149: "149deg",
        150: "150deg",
        151: "151deg",
        152: "152deg",
        153: "153deg",
        154: "154deg",
        155: "155deg",
        156: "156deg",
        157: "157deg",
        158: "158deg",
        159: "159deg",
        160: "160deg",
        161: "161deg",
        162: "162deg",
        163: "163deg",
        164: "164deg",
        165: "165deg",
        166: "166deg",
        167: "167deg",
        168: "168deg",
        169: "169deg",
        170: "170deg",
        171: "171deg",
        172: "172deg",
        173: "173deg",
        174: "174deg",
        175: "175deg",
        176: "176deg",
        177: "177deg",
        178: "178deg",
        179: "179deg",
        180: "180deg",
        181: "181deg",
        182: "182deg",
        183: "183deg",
        184: "184deg",
        185: "185deg",
        186: "186deg",
        187: "187deg",
        188: "188deg",
        189: "189deg",
        190: "190deg",
        191: "191deg",
        192: "192deg",
        193: "193deg",
        194: "194deg",
        195: "195deg",
        196: "196deg",
        197: "197deg",
        198: "198deg",
        199: "199deg",
        200: "200deg",
        201: "201deg",
        202: "202deg",
        203: "203deg",
        204: "204deg",
        205: "205deg",
        206: "206deg",
        207: "207deg",
        208: "208deg",
        209: "209deg",
        210: "210deg",
        211: "211deg",
        212: "212deg",
        213: "213deg",
        214: "214deg",
        215: "215deg",
        216: "216deg",
        217: "217deg",
        218: "218deg",
        219: "219deg",
        220: "220deg",
        221: "221deg",
        222: "222deg",
        223: "223deg",
        224: "224deg",
        225: "225deg",
        226: "226deg",
        227: "227deg",
        228: "228deg",
        229: "229deg",
        230: "230deg",
        231: "231deg",
        232: "232deg",
        233: "233deg",
        234: "234deg",
        235: "235deg",
        236: "236deg",
        237: "237deg",
        238: "238deg",
        239: "239deg",
        240: "240deg",
        241: "241deg",
        242: "242deg",
        243: "243deg",
        244: "244deg",
        245: "245deg",
        246: "246deg",
        247: "247deg",
        248: "248deg",
        249: "249deg",
        250: "250deg",
        251: "251deg",
        252: "252deg",
        253: "253deg",
        254: "254deg",
        255: "255deg",
        256: "256deg",
        257: "257deg",
        258: "258deg",
        259: "259deg",
        260: "260deg",
        261: "261deg",
        262: "262deg",
        263: "263deg",
        264: "264deg",
        265: "265deg",
        266: "266deg",
        267: "267deg",
        268: "268deg",
        269: "269deg",
        270: "270deg",
        271: "271deg",
        272: "272deg",
        273: "273deg",
        274: "274deg",
        275: "275deg",
        276: "276deg",
        277: "277deg",
        278: "278deg",
        279: "279deg",
        280: "280deg",
        281: "281deg",
        282: "282deg",
        283: "283deg",
        284: "284deg",
        285: "285deg",
        286: "286deg",
        287: "287deg",
        288: "288deg",
        289: "289deg",
        290: "290deg",
        291: "291deg",
        292: "292deg",
        293: "293deg",
        294: "294deg",
        295: "295deg",
        296: "296deg",
        297: "297deg",
        298: "298deg",
        299: "299deg",
        300: "300deg",
        301: "301deg",
        302: "302deg",
        303: "303deg",
        304: "304deg",
        305: "305deg",
        306: "306deg",
        307: "307deg",
        308: "308deg",
        309: "309deg",
        310: "310deg",
        311: "311deg",
        312: "312deg",
        313: "313deg",
        314: "314deg",
        315: "315deg",
        316: "316deg",
        317: "317deg",
        318: "318deg",
        319: "319deg",
        320: "320deg",
        321: "321deg",
        322: "322deg",
        323: "323deg",
        324: "324deg",
        325: "325deg",
        326: "326deg",
        327: "327deg",
        328: "328deg",
        329: "329deg",
        330: "330deg",
        331: "331deg",
        332: "332deg",
        333: "333deg",
        334: "334deg",
        335: "335deg",
        336: "336deg",
        337: "337deg",
        338: "338deg",
        339: "339deg",
        340: "340deg",
        341: "341deg",
        342: "342deg",
        343: "343deg",
        344: "344deg",
        345: "345deg",
        346: "346deg",
        347: "347deg",
        348: "348deg",
        349: "349deg",
        350: "350deg",
        351: "351deg",
        352: "352deg",
        353: "353deg",
        354: "354deg",
        355: "355deg",
        356: "356deg",
        357: "357deg",
        358: "358deg",
        359: "359deg",
        360: "360deg"
      },
      strokeWidth: {
        0: "0",
        1: "1",
        2: "2",
        3: "3",
        4: "4",
        5: "5",
        6: "6",
        7: "7",
        8: "8"
      },
      textDecorationThickness: {
        0: "0px",
        1: "1px",
        2: "2px",
        3: "3px",
        4: "4px",
        5: "5px",
        6: "6px",
        7: "7px",
        8: "8px"
      },
      textUnderlineOffset: {
        0: "0px",
        1: "1px",
        2: "2px",
        3: "3px",
        4: "4px",
        5: "5px",
        6: "6px",
        7: "7px",
        8: "8px"
      },
      transitionDelay: {
        0: "0ms",
        50: "50ms",
        100: "100ms",
        150: "150ms",
        200: "200ms",
        250: "250ms",
        300: "300ms",
        400: "400ms",
        500: "500ms",
        600: "600ms",
        700: "700ms",
        800: "800ms",
        900: "900ms",
        1e3: "1000ms",
        1100: "1100ms",
        1200: "1200ms",
        1300: "1300ms",
        1400: "1400ms",
        1500: "150mms",
        1600: "1600ms",
        1700: "1700ms",
        1800: "1800ms",
        1900: "1900ms",
        2e3: "2000ms",
        2100: "2100ms",
        2200: "2200ms",
        2300: "2300ms",
        2400: "2400ms",
        2500: "2500ms",
        2600: "2600ms",
        2700: "2700ms",
        2800: "2800ms",
        2900: "2900ms",
        3e3: "3000ms",
        3100: "3100ms",
        3200: "3200ms",
        3300: "3300ms",
        3400: "3400ms",
        3500: "3500ms",
        3600: "3600ms",
        3700: "3700ms",
        3800: "3800ms",
        3900: "3900ms",
        4e3: "4000ms"
      },
      transitionDuration: {
        0: "0ms",
        50: "50ms",
        100: "100ms",
        150: "150ms",
        200: "200ms",
        250: "250ms",
        300: "300ms",
        400: "400ms",
        500: "500ms",
        600: "600ms",
        700: "700ms",
        800: "800ms",
        900: "900ms",
        1e3: "1000ms",
        1100: "1100ms",
        1200: "1200ms",
        1300: "1300ms",
        1400: "1400ms",
        1500: "150mms",
        1600: "1600ms",
        1700: "1700ms",
        1800: "1800ms",
        1900: "1900ms",
        2e3: "2000ms",
        2100: "2100ms",
        2200: "2200ms",
        2300: "2300ms",
        2400: "2400ms",
        2500: "2500ms",
        2600: "2600ms",
        2700: "2700ms",
        2800: "2800ms",
        2900: "2900ms",
        3e3: "3000ms",
        3100: "3100ms",
        3200: "3200ms",
        3300: "3300ms",
        3400: "3400ms",
        3500: "3500ms",
        3600: "3600ms",
        3700: "3700ms",
        3800: "3800ms",
        3900: "3900ms",
        4e3: "4000ms"
      },
      translate: {
        half: "50%",
        "1/2": "50%",
        "1/3": "33.333333%",
        "2/3": "66.666667%",
        "1/4": "25%",
        "2/4": "50%",
        "3/4": "75%",
        "1/5": "20%",
        "2/5": "40%",
        "3/5": "60%",
        "4/5": "80%",
        "1/6": "16.666667%",
        "2/6": "33.333333%",
        "3/6": "50%",
        "4/6": "66.666667%",
        "5/6": "83.333333%",
        "1/7": "14.285714%",
        "2/7": "28.571429%",
        "3/7": "42.857143%",
        "4/7": "57.142857%",
        "5/7": "71.428571%",
        "6/7": "85.714286%",
        "1/8": "12.5%",
        "2/8": "25%",
        "3/8": "37.5%",
        "4/8": "50%",
        "5/8": "62.5%",
        "6/8": "75%",
        "7/8": "87.5%",
        "1/9": "11.111111%",
        "2/9": "22.222222%",
        "3/9": "33.333333%",
        "4/9": "44.444444%",
        "5/9": "55.555556%",
        "6/9": "66.666667%",
        "7/9": "77.777778%",
        "8/9": "88.888889%",
        "1/10": "10%",
        "2/10": "20%",
        "3/10": "30%",
        "4/10": "40%",
        "5/10": "50%",
        "6/10": "60%",
        "7/10": "70%",
        "8/10": "80%",
        "9/10": "90%",
        "1/11": "9.090909%",
        "2/11": "18.181818%",
        "3/11": "27.272727%",
        "4/11": "36.363636%",
        "5/11": "45.454545%",
        "6/11": "54.545455%",
        "7/11": "63.636364%",
        "8/11": "72.727273%",
        "9/11": "81.818182%",
        "10/11": "90.909091%",
        "1/12": "8.333333%",
        "2/12": "16.666667%",
        "3/12": "25%",
        "4/12": "33.333333%",
        "5/12": "41.666667%",
        "6/12": "50%",
        "7/12": "58.333333%",
        "8/12": "66.666667%",
        "9/12": "75%",
        "10/12": "83.333333%",
        "11/12": "91.666667%",
        "1/13": "7.692308%",
        "2/13": "15.384615%",
        "3/13": "23.076923%",
        "4/13": "30.769231%",
        "5/13": "38.461538%",
        "6/13": "46.153846%",
        "7/13": "53.846154%",
        "8/13": "61.538462%",
        "9/13": "69.230769%",
        "10/13": "76.923077%",
        "11/13": "84.615385%",
        "12/13": "92.307692%",
        "1/14": "7.142857%",
        "2/14": "14.285714%",
        "3/14": "21.428571%",
        "4/14": "28.571429%",
        "5/14": "35.714286%",
        "6/14": "42.857143%",
        "7/14": "50%",
        "8/14": "57.142857%",
        "9/14": "64.285714%",
        "10/14": "71.428571%",
        "11/14": "78.571429%",
        "12/14": "85.714286%",
        "13/14": "92.857143%",
        "1/15": "6.666667%",
        "2/15": "13.333333%",
        "3/15": "20%",
        "4/15": "26.666667%",
        "5/15": "33.333333%",
        "6/15": "40%",
        "7/15": "46.666667%",
        "8/15": "53.333333%",
        "9/15": "60%",
        "10/15": "66.666667%",
        "11/15": "73.333333%",
        "12/15": "80%",
        "13/15": "86.666667%",
        "14/15": "93.333333%",
        "1/16": "6.25%",
        "2/16": "12.5%",
        "3/16": "18.75%",
        "4/16": "25%",
        "5/16": "31.25%",
        "6/16": "37.5%",
        "7/16": "43.75%",
        "8/16": "50%",
        "9/16": "56.25%",
        "10/16": "62.5%",
        "11/16": "68.75%",
        "12/16": "75%",
        "13/16": "81.25%",
        "14/16": "87.5%",
        "15/16": "93.75%"
      },
      width: {
        half: "50%",
        "1/2": "50%",
        "1/3": "33.333333%",
        "2/3": "66.666667%",
        "1/4": "25%",
        "2/4": "50%",
        "3/4": "75%",
        "1/5": "20%",
        "2/5": "40%",
        "3/5": "60%",
        "4/5": "80%",
        "1/6": "16.666667%",
        "2/6": "33.333333%",
        "3/6": "50%",
        "4/6": "66.666667%",
        "5/6": "83.333333%",
        "1/7": "14.285714%",
        "2/7": "28.571429%",
        "3/7": "42.857143%",
        "4/7": "57.142857%",
        "5/7": "71.428571%",
        "6/7": "85.714286%",
        "1/8": "12.5%",
        "2/8": "25%",
        "3/8": "37.5%",
        "4/8": "50%",
        "5/8": "62.5%",
        "6/8": "75%",
        "7/8": "87.5%",
        "1/9": "11.111111%",
        "2/9": "22.222222%",
        "3/9": "33.333333%",
        "4/9": "44.444444%",
        "5/9": "55.555556%",
        "6/9": "66.666667%",
        "7/9": "77.777778%",
        "8/9": "88.888889%",
        "1/10": "10%",
        "2/10": "20%",
        "3/10": "30%",
        "4/10": "40%",
        "5/10": "50%",
        "6/10": "60%",
        "7/10": "70%",
        "8/10": "80%",
        "9/10": "90%",
        "1/11": "9.090909%",
        "2/11": "18.181818%",
        "3/11": "27.272727%",
        "4/11": "36.363636%",
        "5/11": "45.454545%",
        "6/11": "54.545455%",
        "7/11": "63.636364%",
        "8/11": "72.727273%",
        "9/11": "81.818182%",
        "10/11": "90.909091%",
        "1/12": "8.333333%",
        "2/12": "16.666667%",
        "3/12": "25%",
        "4/12": "33.333333%",
        "5/12": "41.666667%",
        "6/12": "50%",
        "7/12": "58.333333%",
        "8/12": "66.666667%",
        "9/12": "75%",
        "10/12": "83.333333%",
        "11/12": "91.666667%",
        "1/13": "7.692308%",
        "2/13": "15.384615%",
        "3/13": "23.076923%",
        "4/13": "30.769231%",
        "5/13": "38.461538%",
        "6/13": "46.153846%",
        "7/13": "53.846154%",
        "8/13": "61.538462%",
        "9/13": "69.230769%",
        "10/13": "76.923077%",
        "11/13": "84.615385%",
        "12/13": "92.307692%",
        "1/14": "7.142857%",
        "2/14": "14.285714%",
        "3/14": "21.428571%",
        "4/14": "28.571429%",
        "5/14": "35.714286%",
        "6/14": "42.857143%",
        "7/14": "50%",
        "8/14": "57.142857%",
        "9/14": "64.285714%",
        "10/14": "71.428571%",
        "11/14": "78.571429%",
        "12/14": "85.714286%",
        "13/14": "92.857143%",
        "1/15": "6.666667%",
        "2/15": "13.333333%",
        "3/15": "20%",
        "4/15": "26.666667%",
        "5/15": "33.333333%",
        "6/15": "40%",
        "7/15": "46.666667%",
        "8/15": "53.333333%",
        "9/15": "60%",
        "10/15": "66.666667%",
        "11/15": "73.333333%",
        "12/15": "80%",
        "13/15": "86.666667%",
        "14/15": "93.333333%",
        "1/16": "6.25%",
        "2/16": "12.5%",
        "3/16": "18.75%",
        "4/16": "25%",
        "5/16": "31.25%",
        "6/16": "37.5%",
        "7/16": "43.75%",
        "8/16": "50%",
        "9/16": "56.25%",
        "10/16": "62.5%",
        "11/16": "68.75%",
        "12/16": "75%",
        "13/16": "81.25%",
        "14/16": "87.5%",
        "15/16": "93.75%"
      },
      zIndex: {
        min: "-9999",
        max: "9999",
        0: "0",
        1: "1",
        2: "2",
        3: "3",
        4: "4",
        5: "5",
        6: "6",
        7: "7",
        8: "8",
        9: "9",
        10: "10",
        11: "11",
        12: "12",
        13: "13",
        14: "14",
        15: "15",
        16: "16",
        17: "17",
        18: "18",
        19: "19",
        20: "20",
        21: "21",
        22: "22",
        23: "23",
        24: "24",
        25: "25",
        26: "26",
        27: "27",
        28: "28",
        29: "29",
        30: "30",
        31: "31",
        32: "32",
        33: "33",
        34: "34",
        35: "35",
        36: "36",
        37: "37",
        38: "38",
        39: "39",
        40: "40",
        41: "41",
        42: "42",
        43: "43",
        44: "44",
        45: "45",
        46: "46",
        47: "47",
        48: "48",
        49: "49",
        50: "50",
        51: "51",
        52: "52",
        53: "53",
        54: "54",
        55: "55",
        56: "56",
        57: "57",
        58: "58",
        59: "59",
        60: "60",
        61: "61",
        62: "62",
        63: "63",
        64: "64"
      }
    }
  }
};

var hueStep = 2; // 色相阶梯

var saturationStep = 0.16; // 饱和度阶梯，浅色部分

var saturationStep2 = 0.05; // 饱和度阶梯，深色部分

var brightnessStep1 = 0.05; // 亮度阶梯，浅色部分

var brightnessStep2 = 0.15; // 亮度阶梯，深色部分

var lightColorCount = 5; // 浅色数量，主色上

var darkColorCount = 4; // 深色数量，主色下
// 暗色主题颜色映射关系表

var darkColorMap = [{
  index: 7,
  opacity: 0.15
}, {
  index: 6,
  opacity: 0.25
}, {
  index: 5,
  opacity: 0.3
}, {
  index: 5,
  opacity: 0.45
}, {
  index: 5,
  opacity: 0.65
}, {
  index: 5,
  opacity: 0.85
}, {
  index: 4,
  opacity: 0.9
}, {
  index: 3,
  opacity: 0.95
}, {
  index: 2,
  opacity: 0.97
}, {
  index: 1,
  opacity: 0.98
}];

// Wrapper function ported from TinyColor.prototype.toHsv
// Keep it here because of `hsv.h * 360`
function toHsv(_ref) {
  var r = _ref.r,
      g = _ref.g,
      b = _ref.b;
  var hsv = rgbToHsv(r, g, b);
  return {
    h: hsv.h * 360,
    s: hsv.s,
    v: hsv.v
  };
} // Wrapper function ported from TinyColor.prototype.toHexString
// Keep it here because of the prefix `#`


function toHex(_ref2) {
  var r = _ref2.r,
      g = _ref2.g,
      b = _ref2.b;
  return "#".concat(rgbToHex(r, g, b, false));
} // Wrapper function ported from TinyColor.prototype.mix, not treeshakable.
// Amount in range [0, 1]
// Assume color1 & color2 has no alpha, since the following src code did so.


function mix(rgb1, rgb2, amount) {
  var p = amount / 100;
  var rgb = {
    r: (rgb2.r - rgb1.r) * p + rgb1.r,
    g: (rgb2.g - rgb1.g) * p + rgb1.g,
    b: (rgb2.b - rgb1.b) * p + rgb1.b
  };
  return rgb;
}

function getHue(hsv, i, light) {
  var hue; // 根据色相不同，色相转向不同

  if (Math.round(hsv.h) >= 60 && Math.round(hsv.h) <= 240) {
    hue = light ? Math.round(hsv.h) - hueStep * i : Math.round(hsv.h) + hueStep * i;
  } else {
    hue = light ? Math.round(hsv.h) + hueStep * i : Math.round(hsv.h) - hueStep * i;
  }

  if (hue < 0) {
    hue += 360;
  } else if (hue >= 360) {
    hue -= 360;
  }

  return hue;
}

function getSaturation(hsv, i, light) {
  // grey color don't change saturation
  if (hsv.h === 0 && hsv.s === 0) {
    return hsv.s;
  }

  var saturation;

  if (light) {
    saturation = hsv.s - saturationStep * i;
  } else if (i === darkColorCount) {
    saturation = hsv.s + saturationStep;
  } else {
    saturation = hsv.s + saturationStep2 * i;
  } // 边界值修正


  if (saturation > 1) {
    saturation = 1;
  } // 第一格的 s 限制在 0.06-0.1 之间


  if (light && i === lightColorCount && saturation > 0.1) {
    saturation = 0.1;
  }

  if (saturation < 0.06) {
    saturation = 0.06;
  }

  return Number(saturation.toFixed(2));
}

function getValue(hsv, i, light) {
  var value;

  if (light) {
    value = hsv.v + brightnessStep1 * i;
  } else {
    value = hsv.v - brightnessStep2 * i;
  }

  if (value > 1) {
    value = 1;
  }

  return Number(value.toFixed(2));
}

function generate(color) {
  var opts = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var patterns = [];
  var pColor = inputToRGB(color);

  for (var i = lightColorCount; i > 0; i -= 1) {
    var hsv = toHsv(pColor);
    var colorString = toHex(inputToRGB({
      h: getHue(hsv, i, true),
      s: getSaturation(hsv, i, true),
      v: getValue(hsv, i, true)
    }));
    patterns.push(colorString);
  }

  patterns.push(toHex(pColor));

  for (var _i = 1; _i <= darkColorCount; _i += 1) {
    var _hsv = toHsv(pColor);

    var _colorString = toHex(inputToRGB({
      h: getHue(_hsv, _i),
      s: getSaturation(_hsv, _i),
      v: getValue(_hsv, _i)
    }));

    patterns.push(_colorString);
  } // dark theme patterns


  if (opts.theme === 'dark') {
    return darkColorMap.map(function (_ref3) {
      var index = _ref3.index,
          opacity = _ref3.opacity;
      var darkColorString = toHex(mix(inputToRGB(opts.backgroundColor || '#141414'), inputToRGB(patterns[index]), opacity * 100));
      return darkColorString;
    });
  }

  return patterns;
}

var presetPrimaryColors = {
  red: '#F5222D',
  volcano: '#FA541C',
  orange: '#FA8C16',
  gold: '#FAAD14',
  yellow: '#FADB14',
  lime: '#A0D911',
  green: '#52C41A',
  cyan: '#13C2C2',
  blue: '#1677FF',
  geekblue: '#2F54EB',
  purple: '#722ED1',
  magenta: '#EB2F96',
  grey: '#666666'
};
var presetPalettes = {};
var presetDarkPalettes = {};
Object.keys(presetPrimaryColors).forEach(function (key) {
  presetPalettes[key] = generate(presetPrimaryColors[key]);
  presetPalettes[key].primary = presetPalettes[key][5]; // dark presetPalettes

  presetDarkPalettes[key] = generate(presetPrimaryColors[key], {
    theme: 'dark',
    backgroundColor: '#141414'
  });
  presetDarkPalettes[key].primary = presetDarkPalettes[key][5];
});

const convert$2 = (colors) => {
  return {
    DEFAULT: colors[5],
    1: colors[0],
    2: colors[1],
    3: colors[2],
    4: colors[3],
    5: colors[4],
    6: colors[5],
    7: colors[6],
    8: colors[7],
    9: colors[8],
    10: colors[9],
    hover: colors[4],
    active: colors[6],
    "lighten-5": colors[0],
    "light-1": colors[0],
    "lighten-4": colors[1],
    "light-2": colors[1],
    "lighten-3": colors[2],
    "light-3": colors[2],
    "lighten-2": colors[3],
    "light-4": colors[3],
    "lighten-1": colors[4],
    "light-5": colors[4],
    "darken-1": colors[6],
    "dark-1": colors[6],
    "darken-2": colors[7],
    "dark-2": colors[7],
    "darken-3": colors[8],
    "dark-3": colors[8],
    "darken-4": colors[9],
    "dark-4": colors[9]
  };
};
const antDesignV4Preset = ({
  /** base */
  baseSelectors = [":root"],
  baseMediaQuery = "",
  basePrimary = "#1890ff",
  baseSecondary = "#666666",
  baseSuccess = "#52c41a",
  baseWarning = "#faad14",
  baseError = "#f5222d",
  baseDanger = "#f5222d",
  baseInfo = "#1890ff",
  baseBg = "#ffffff",
  baseMaskBg = "rgba(0, 0, 0, 0.45)",
  baseDisabledBg = "#f5f5f5",
  baseBorder = "#d9d9d9",
  baseText = "rgba(0, 0, 0, 0.85)",
  basePrimaryText = "rgba(0, 0, 0, 0.85)",
  baseSecondaryText = "rgba(0, 0, 0, 0.45)",
  baseDisabledText = "rgba(0, 0, 0, 0.25)",
  baseBoxShadow = "0 3px 6px -4px rgba(0, 0, 0, 0.12), 0 6px 16px 0 rgba(0, 0, 0, 0.08), 0 9px 28px 8px rgba(0, 0, 0, 0.05)",
  /** dark */
  darkSelectors = [".dark"],
  darkMediaQuery = "",
  darkPrimary = "#177ddc",
  darkSecondary = "#5a5a5a",
  darkSuccess = "#49aa19",
  darkWarning = "#d89614",
  darkError = "#d32029",
  darkDanger = "#d32029",
  darkInfo = "#177ddc",
  darkBg = "#141414",
  darkMaskBg = "rgba(0, 0, 0, 0.45)",
  darkDisabledBg = "rgba(255, 255, 255, 0.08)",
  darkBorder = "#434343",
  darkText = "rgba(255, 255, 255, 0.85)",
  darkPrimaryText = "rgba(255, 255, 255, 0.85)",
  darkSecondaryText = "rgba(255, 255, 255, 0.45)",
  darkDisabledText = "rgba(255, 255, 255, 0.3)",
  darkBoxShadow = "0 3px 6px -4px rgba(0, 0, 0, 0.48), 0 6px 16px 0 rgba(0, 0, 0, 0.32), 0 9px 28px 8px rgba(0, 0, 0, 0.2)"
} = {}) => ({
  content: [],
  darkMode: "class",
  safelist: ["dark"],
  plugins: [
    themeSwapper({
      themes: [
        {
          name: "base",
          selectors: baseSelectors,
          mediaQuery: baseMediaQuery,
          theme: {
            colors: {
              primary: convert$2(generate(basePrimary)),
              secondary: convert$2(generate(baseSecondary)),
              success: convert$2(generate(baseSuccess)),
              warning: convert$2(generate(baseWarning)),
              error: convert$2(generate(baseError)),
              danger: convert$2(generate(baseDanger)),
              info: convert$2(generate(baseInfo)),
              red: convert$2(presetPalettes.red),
              volcano: convert$2(presetPalettes.volcano),
              orange: convert$2(presetPalettes.orange),
              gold: convert$2(presetPalettes.gold),
              yellow: convert$2(presetPalettes.yellow),
              lime: convert$2(presetPalettes.lime),
              green: convert$2(presetPalettes.green),
              cyan: convert$2(presetPalettes.cyan),
              blue: convert$2(presetPalettes.blue),
              geekblue: convert$2(presetPalettes.geekblue),
              geekBlue: convert$2(presetPalettes.geekblue),
              purple: convert$2(presetPalettes.purple),
              magenta: convert$2(presetPalettes.magenta),
              gray: {
                DEFAULT: "#8c8c8c",
                1: "#ffffff",
                2: "#fafafa",
                3: "#f5f5f5",
                4: "#f0f0f0",
                5: "#d9d9d9",
                6: "#bfbfbf",
                7: "#8c8c8c",
                8: "#595959",
                9: "#434343",
                10: "#262626",
                11: "#1f1f1f",
                12: "#141414",
                13: "#000000",
                hover: "#bfbfbf",
                active: "#595959",
                "lighten-6": "#ffffff",
                "light-6": "#ffffff",
                "lighten-5": "#fafafa",
                "light-5": "#fafafa",
                "lighten-4": "#f5f5f5",
                "light-4": "#f5f5f5",
                "lighten-3": "#f0f0f0",
                "light-3": "#f0f0f0",
                "lighten-2": "#d9d9d9",
                "light-2": "#d9d9d9",
                "lighten-1": "#bfbfbf",
                "light-1": "#bfbfbf",
                "darken-1": "#595959",
                "dark-1": "#595959",
                "darken-2": "#434343",
                "dark-2": "#434343",
                "darken-3": "#262626",
                "dark-3": "#262626",
                "darken-4": "#1f1f1f",
                "dark-4": "#1f1f1f",
                "darken-5": "#141414",
                "dark-5": "#141414",
                "darken-6": "#000000",
                "dark-6": "#000000"
              },
              grey: {
                DEFAULT: "#8c8c8c",
                1: "#ffffff",
                2: "#fafafa",
                3: "#f5f5f5",
                4: "#f0f0f0",
                5: "#d9d9d9",
                6: "#bfbfbf",
                7: "#8c8c8c",
                8: "#595959",
                9: "#434343",
                10: "#262626",
                11: "#1f1f1f",
                12: "#141414",
                13: "#000000",
                hover: "#bfbfbf",
                active: "#595959",
                "lighten-6": "#ffffff",
                "light-6": "#ffffff",
                "lighten-5": "#fafafa",
                "light-5": "#fafafa",
                "lighten-4": "#f5f5f5",
                "light-4": "#f5f5f5",
                "lighten-3": "#f0f0f0",
                "light-3": "#f0f0f0",
                "lighten-2": "#d9d9d9",
                "light-2": "#d9d9d9",
                "lighten-1": "#bfbfbf",
                "light-1": "#bfbfbf",
                "darken-1": "#595959",
                "dark-1": "#595959",
                "darken-2": "#434343",
                "dark-2": "#434343",
                "darken-3": "#262626",
                "dark-3": "#262626",
                "darken-4": "#1f1f1f",
                "dark-4": "#1f1f1f",
                "darken-5": "#141414",
                "dark-5": "#141414",
                "darken-6": "#000000",
                "dark-6": "#000000"
              }
            },
            backgroundColor: {
              DEFAULT: baseBg,
              mask: baseMaskBg,
              disabled: baseDisabledBg
            },
            borderColor: {
              DEFAULT: baseBorder
            },
            textColor: {
              DEFAULT: baseText,
              "primary-text": basePrimaryText,
              "secondary-text": baseSecondaryText,
              "disabled-text": baseDisabledText
            },
            boxShadow: {
              DEFAULT: baseBoxShadow
            }
          }
        },
        {
          name: "dark",
          selectors: darkSelectors,
          mediaQuery: darkMediaQuery,
          theme: {
            colors: {
              primary: convert$2(generate(darkPrimary, { theme: "dark", backgroundColor: darkBg })),
              secondary: convert$2(
                generate(darkSecondary, { theme: "dark", backgroundColor: darkBg })
              ),
              success: convert$2(generate(darkSuccess, { theme: "dark", backgroundColor: darkBg })),
              warning: convert$2(generate(darkWarning, { theme: "dark", backgroundColor: darkBg })),
              error: convert$2(generate(darkError, { theme: "dark", backgroundColor: darkBg })),
              danger: convert$2(generate(darkDanger, { theme: "dark", backgroundColor: darkBg })),
              info: convert$2(generate(darkInfo, { theme: "dark", backgroundColor: darkBg })),
              red: convert$2(presetDarkPalettes.red),
              volcano: convert$2(presetDarkPalettes.volcano),
              orange: convert$2(presetDarkPalettes.orange),
              gold: convert$2(presetDarkPalettes.gold),
              yellow: convert$2(presetDarkPalettes.yellow),
              lime: convert$2(presetDarkPalettes.lime),
              green: convert$2(presetDarkPalettes.green),
              cyan: convert$2(presetDarkPalettes.cyan),
              blue: convert$2(presetDarkPalettes.blue),
              geekblue: convert$2(presetDarkPalettes.geekblue),
              purple: convert$2(presetDarkPalettes.purple),
              magenta: convert$2(presetDarkPalettes.magenta)
            },
            backgroundColor: {
              DEFAULT: darkBg,
              mask: darkMaskBg,
              disabled: darkDisabledBg
            },
            borderColor: {
              DEFAULT: darkBorder
            },
            textColor: {
              DEFAULT: darkText,
              "primary-text": darkPrimaryText,
              "secondary-text": darkSecondaryText,
              "disabled-text": darkDisabledText
            },
            boxShadow: {
              DEFAULT: darkBoxShadow
            }
          }
        }
      ]
    })
  ],
  theme: {
    screens: {
      xs: "480px",
      sm: "576px",
      md: "768px",
      lg: "992px",
      xl: "1200px",
      xxl: "1600px",
      "2xl": "1600px"
    },
    extend: {
      fontFamily: {
        DEFAULT: [
          "-apple-system",
          "BlinkMacSystemFont",
          "Segoe UI",
          "Roboto",
          "Helvetica Neue",
          "Arial",
          "Noto Sans",
          "sans-serif",
          "Apple Color Emoji",
          "Segoe UI Emoji",
          "Segoe UI Symbol",
          "Noto Color Emoji"
        ]
      }
    }
  }
});

const convert$1 = (colors) => {
  return {
    DEFAULT: colors[5],
    1: colors[0],
    2: colors[1],
    3: colors[2],
    4: colors[3],
    5: colors[4],
    6: colors[5],
    7: colors[6],
    8: colors[7],
    9: colors[8],
    10: colors[9],
    hover: colors[4],
    active: colors[6],
    "lighten-5": colors[0],
    "light-1": colors[0],
    "lighten-4": colors[1],
    "light-2": colors[1],
    "lighten-3": colors[2],
    "light-3": colors[2],
    "lighten-2": colors[3],
    "light-4": colors[3],
    "lighten-1": colors[4],
    "light-5": colors[4],
    "darken-1": colors[6],
    "dark-1": colors[6],
    "darken-2": colors[7],
    "dark-2": colors[7],
    "darken-3": colors[8],
    "dark-3": colors[8],
    "darken-4": colors[9],
    "dark-4": colors[9]
  };
};
const antDesignPreset = ({
  /** base */
  baseSelectors = [":root"],
  baseMediaQuery = "",
  basePrimary = "#1677ff",
  baseSecondary = "#666666",
  baseSuccess = "#52c41a",
  baseWarning = "#faad14",
  baseError = "#ff4d4f",
  baseDanger = "#ff4d4f",
  baseInfo = "#1677ff",
  baseBg = "#ffffff",
  baseMaskBg = "rgba(0, 0, 0, 0.45)",
  baseDisabledBg = "rgba(0, 0, 0, 0.04)",
  baseBorder = "#d9d9d9",
  baseText = "rgba(0, 0, 0, 0.85)",
  basePrimaryText = "rgba(0, 0, 0, 0.85)",
  baseSecondaryText = "rgba(0, 0, 0, 0.45)",
  baseDisabledText = "rgba(0, 0, 0, 0.25)",
  baseBoxShadow = "0 1px 2px 0 rgba(0, 0, 0, 0.03), 0 1px 6px -1px rgba(0, 0, 0, 0.02), 0 2px 4px 0 rgba(0, 0, 0, 0.02)",
  /** dark */
  darkSelectors = [".dark"],
  darkMediaQuery = "",
  darkPrimary = "#1668dc",
  darkSecondary = "#5a5a5a",
  darkSuccess = "#49aa19",
  darkWarning = "#d89614",
  darkError = "#dc4446",
  darkDanger = "#dc4446",
  darkInfo = "#1668dc",
  darkBg = "#141414",
  darkMaskBg = "rgba(0, 0, 0, 0.45)",
  darkDisabledBg = "rgba(255, 255, 255, 0.08)",
  darkBorder = "#434343",
  darkText = "rgba(255, 255, 255, 0.85)",
  darkPrimaryText = "rgba(255, 255, 255, 0.85)",
  darkSecondaryText = "rgba(255, 255, 255, 0.45)",
  darkDisabledText = "rgba(255, 255, 255, 0.3)",
  darkBoxShadow = "0 1px 2px 0 rgba(0, 0, 0, 0.03), 0 1px 6px -1px rgba(0, 0, 0, 0.02), 0 2px 4px 0 rgba(0, 0, 0, 0.02)"
} = {}) => ({
  content: [],
  darkMode: "class",
  safelist: ["dark"],
  plugins: [
    themeSwapper({
      themes: [
        {
          name: "base",
          selectors: baseSelectors,
          mediaQuery: baseMediaQuery,
          theme: {
            colors: {
              primary: convert$1(generate(basePrimary)),
              secondary: convert$1(generate(baseSecondary)),
              success: convert$1(generate(baseSuccess)),
              warning: convert$1(generate(baseWarning)),
              error: convert$1(generate(baseError)),
              danger: convert$1(generate(baseDanger)),
              info: convert$1(generate(baseInfo)),
              red: convert$1(presetPalettes.red),
              volcano: convert$1(presetPalettes.volcano),
              orange: convert$1(presetPalettes.orange),
              gold: convert$1(presetPalettes.gold),
              yellow: convert$1(presetPalettes.yellow),
              lime: convert$1(presetPalettes.lime),
              green: convert$1(presetPalettes.green),
              cyan: convert$1(presetPalettes.cyan),
              blue: convert$1(presetPalettes.blue),
              geekblue: convert$1(presetPalettes.geekblue),
              geekBlue: convert$1(presetPalettes.geekblue),
              purple: convert$1(presetPalettes.purple),
              magenta: convert$1(presetPalettes.magenta),
              gray: {
                DEFAULT: "#8c8c8c",
                1: "#ffffff",
                2: "#fafafa",
                3: "#f5f5f5",
                4: "#f0f0f0",
                5: "#d9d9d9",
                6: "#bfbfbf",
                7: "#8c8c8c",
                8: "#595959",
                9: "#434343",
                10: "#262626",
                11: "#1f1f1f",
                12: "#141414",
                13: "#000000",
                hover: "#bfbfbf",
                active: "#595959",
                "lighten-6": "#ffffff",
                "light-6": "#ffffff",
                "lighten-5": "#fafafa",
                "light-5": "#fafafa",
                "lighten-4": "#f5f5f5",
                "light-4": "#f5f5f5",
                "lighten-3": "#f0f0f0",
                "light-3": "#f0f0f0",
                "lighten-2": "#d9d9d9",
                "light-2": "#d9d9d9",
                "lighten-1": "#bfbfbf",
                "light-1": "#bfbfbf",
                "darken-1": "#595959",
                "dark-1": "#595959",
                "darken-2": "#434343",
                "dark-2": "#434343",
                "darken-3": "#262626",
                "dark-3": "#262626",
                "darken-4": "#1f1f1f",
                "dark-4": "#1f1f1f",
                "darken-5": "#141414",
                "dark-5": "#141414",
                "darken-6": "#000000",
                "dark-6": "#000000"
              },
              grey: {
                DEFAULT: "#8c8c8c",
                1: "#ffffff",
                2: "#fafafa",
                3: "#f5f5f5",
                4: "#f0f0f0",
                5: "#d9d9d9",
                6: "#bfbfbf",
                7: "#8c8c8c",
                8: "#595959",
                9: "#434343",
                10: "#262626",
                11: "#1f1f1f",
                12: "#141414",
                13: "#000000",
                hover: "#bfbfbf",
                active: "#595959",
                "lighten-6": "#ffffff",
                "light-6": "#ffffff",
                "lighten-5": "#fafafa",
                "light-5": "#fafafa",
                "lighten-4": "#f5f5f5",
                "light-4": "#f5f5f5",
                "lighten-3": "#f0f0f0",
                "light-3": "#f0f0f0",
                "lighten-2": "#d9d9d9",
                "light-2": "#d9d9d9",
                "lighten-1": "#bfbfbf",
                "light-1": "#bfbfbf",
                "darken-1": "#595959",
                "dark-1": "#595959",
                "darken-2": "#434343",
                "dark-2": "#434343",
                "darken-3": "#262626",
                "dark-3": "#262626",
                "darken-4": "#1f1f1f",
                "dark-4": "#1f1f1f",
                "darken-5": "#141414",
                "dark-5": "#141414",
                "darken-6": "#000000",
                "dark-6": "#000000"
              }
            },
            backgroundColor: {
              DEFAULT: baseBg,
              mask: baseMaskBg,
              disabled: baseDisabledBg
            },
            borderColor: {
              DEFAULT: baseBorder
            },
            textColor: {
              DEFAULT: baseText,
              "primary-text": basePrimaryText,
              "secondary-text": baseSecondaryText,
              "disabled-text": baseDisabledText
            },
            boxShadow: {
              DEFAULT: baseBoxShadow
            }
          }
        },
        {
          name: "dark",
          selectors: darkSelectors,
          mediaQuery: darkMediaQuery,
          theme: {
            colors: {
              primary: convert$1(generate(darkPrimary, { theme: "dark", backgroundColor: darkBg })),
              secondary: convert$1(
                generate(darkSecondary, { theme: "dark", backgroundColor: darkBg })
              ),
              success: convert$1(generate(darkSuccess, { theme: "dark", backgroundColor: darkBg })),
              warning: convert$1(generate(darkWarning, { theme: "dark", backgroundColor: darkBg })),
              error: convert$1(generate(darkError, { theme: "dark", backgroundColor: darkBg })),
              danger: convert$1(generate(darkDanger, { theme: "dark", backgroundColor: darkBg })),
              info: convert$1(generate(darkInfo, { theme: "dark", backgroundColor: darkBg })),
              red: convert$1(presetDarkPalettes.red),
              volcano: convert$1(presetDarkPalettes.volcano),
              orange: convert$1(presetDarkPalettes.orange),
              gold: convert$1(presetDarkPalettes.gold),
              yellow: convert$1(presetDarkPalettes.yellow),
              lime: convert$1(presetDarkPalettes.lime),
              green: convert$1(presetDarkPalettes.green),
              cyan: convert$1(presetDarkPalettes.cyan),
              blue: convert$1(presetDarkPalettes.blue),
              geekblue: convert$1(presetDarkPalettes.geekblue),
              purple: convert$1(presetDarkPalettes.purple),
              magenta: convert$1(presetDarkPalettes.magenta)
            },
            backgroundColor: {
              DEFAULT: darkBg,
              mask: darkMaskBg,
              disabled: darkDisabledBg
            },
            borderColor: {
              DEFAULT: darkBorder
            },
            textColor: {
              DEFAULT: darkText,
              "primary-text": darkPrimaryText,
              "secondary-text": darkSecondaryText,
              "disabled-text": darkDisabledText
            },
            boxShadow: {
              DEFAULT: darkBoxShadow
            }
          }
        }
      ]
    })
  ],
  theme: {
    screens: {
      xs: "480px",
      sm: "576px",
      md: "768px",
      lg: "992px",
      xl: "1200px",
      xxl: "1600px",
      "2xl": "1600px"
    },
    extend: {
      fontFamily: {
        DEFAULT: [
          "-apple-system",
          "BlinkMacSystemFont",
          "Segoe UI",
          "Roboto",
          "Helvetica Neue",
          "Arial",
          "Noto Sans",
          "sans-serif",
          "Apple Color Emoji",
          "Segoe UI Emoji",
          "Segoe UI Symbol",
          "Noto Color Emoji"
        ]
      }
    }
  }
});

const convert = ({
  color,
  lightenColor,
  darkenColor
} = {}) => {
  const c = new TinyColor(color);
  const lc = new TinyColor(lightenColor || "white");
  const dc = new TinyColor(darkenColor || "black");
  return {
    DEFAULT: c.toHexString(),
    hover: c.mix(lc, 30).toHexString(),
    active: c.mix(dc, 20).toHexString(),
    disabled: c.mix(lc, 50).toHexString(),
    "lighten-9": c.mix(lc, 90).toHexString(),
    "light-9": c.mix(lc, 90).toHexString(),
    "lighten-8": c.mix(lc, 80).toHexString(),
    "light-8": c.mix(lc, 80).toHexString(),
    "lighten-7": c.mix(lc, 70).toHexString(),
    "light-7": c.mix(lc, 70).toHexString(),
    "lighten-6": c.mix(lc, 60).toHexString(),
    "light-6": c.mix(lc, 60).toHexString(),
    "lighten-5": c.mix(lc, 50).toHexString(),
    "light-5": c.mix(lc, 50).toHexString(),
    "lighten-4": c.mix(lc, 40).toHexString(),
    "light-4": c.mix(lc, 40).toHexString(),
    "lighten-3": c.mix(lc, 30).toHexString(),
    "light-3": c.mix(lc, 30).toHexString(),
    "lighten-2": c.mix(lc, 20).toHexString(),
    "light-2": c.mix(lc, 20).toHexString(),
    "lighten-1": c.mix(lc, 10).toHexString(),
    "light-1": c.mix(lc, 10).toHexString(),
    "darken-1": c.mix(dc, 10).toHexString(),
    "dark-1": c.mix(dc, 10).toHexString(),
    "darken-2": c.mix(dc, 20).toHexString(),
    "dark-2": c.mix(dc, 20).toHexString(),
    "darken-3": c.mix(dc, 30).toHexString(),
    "dark-3": c.mix(dc, 30).toHexString(),
    "darken-4": c.mix(dc, 40).toHexString(),
    "dark-4": c.mix(dc, 40).toHexString(),
    "darken-5": c.mix(dc, 50).toHexString(),
    "dark-5": c.mix(dc, 50).toHexString(),
    "darken-6": c.mix(dc, 60).toHexString(),
    "dark-6": c.mix(dc, 60).toHexString(),
    "darken-7": c.mix(dc, 70).toHexString(),
    "dark-7": c.mix(dc, 70).toHexString(),
    "darken-8": c.mix(dc, 80).toHexString(),
    "dark-8": c.mix(dc, 80).toHexString(),
    "darken-9": c.mix(dc, 90).toHexString(),
    "dark-9": c.mix(dc, 90).toHexString()
  };
};
const elementPlusPreset = ({
  /** base */
  baseSelectors = [":root"],
  baseMediaQuery = "",
  basePrimary = "#409eff",
  baseSecondary = "#909399",
  baseSuccess = "#67c23a",
  baseWarning = "#e6a23c",
  baseError = "#f56c6c",
  baseDanger = "#f56c6c",
  baseInfo = "#909399",
  baseFill = "#f0f2f5",
  baseDarkerFill = "#e6e8eb",
  baseDarkFill = "#ebedf0",
  baseLightFill = "#f5f7fa",
  baseLighterFill = "#fafafa",
  baseExtraLightFill = "#fafcff",
  baseBlankFill = "#ffffff",
  baseText = "#303133",
  basePrimaryText = "#303133",
  baseRegularText = "#606266",
  baseSecondaryText = "#909399",
  basePlaceholderText = "#a8abb2",
  baseDisabledText = "#c0c4cc",
  baseBg = "#ffffff",
  basePageBg = "#f2f3f5",
  baseOverlayBg = "#ffffff",
  baseMaskBg = "rgba(0, 0, 0, 0.5)",
  baseDisabledBg = "#f5f7fa",
  baseBorder = "#dcdfe6",
  baseDarkerBorder = "#cdd0d6",
  baseDarkBorder = "#d4d7de",
  baseLightBorder = "#e4e7ed",
  baseLighterBorder = "#ebeef5",
  baseExtraLightBorder = "#f2f6fc",
  baseBoxShadow = "0px 12px 32px 4px rgba(0, 0, 0, 0.04), 0px 8px 20px rgba(0, 0, 0, 0.08)",
  /** dark */
  darkSelectors = [".dark"],
  darkMediaQuery = "",
  darkPrimary = "#409eff",
  darkSecondary = "#909399",
  darkSuccess = "#67c23a",
  darkWarning = "#e6a23c",
  darkError = "#f56c6c",
  darkDanger = "#f56c6c",
  darkInfo = "#909399",
  darkFill = "#303030",
  darkDarkerFill = "#424243",
  darkDarkFill = "#39393a",
  darkLightFill = "#262727",
  darkLighterFill = "#1d1d1d",
  darkExtraLightFill = "#191919",
  darkBlankFill = "transparent",
  darkText = "#e5eaf3",
  darkPrimaryText = "#e5eaf3",
  darkRegularText = "#cfd3dc",
  darkSecondaryText = "#a3a6ad",
  darkPlaceholderText = "#8d9095",
  darkDisabledText = "#6c6e72",
  darkBg = "#141414",
  darkPageBg = "#0a0a0a",
  darkOverlayBg = "#1d1e1f",
  darkMaskBg = "rgba(0, 0, 0, 0.5)",
  darkDisabledBg = "transparent",
  darkBorder = "#4c4d4f",
  darkDarkerBorder = "#636466",
  darkDarkBorder = "#58585b",
  darkLightBorder = "#414243",
  darkLighterBorder = "#363637",
  darkExtraLightBorder = "#2b2b2c",
  darkBoxShadow = "0px 12px 32px 4px rgba(0, 0, 0, 0.36), 0px 8px 20px rgba(0, 0, 0, 0.72)"
} = {}) => ({
  content: [],
  darkMode: "class",
  safelist: ["dark"],
  plugins: [
    themeSwapper({
      themes: [
        {
          name: "base",
          selectors: baseSelectors,
          mediaQuery: baseMediaQuery,
          theme: {
            colors: {
              primary: convert({ color: basePrimary }),
              secondary: convert({ color: baseSecondary }),
              success: convert({ color: baseSuccess }),
              warning: convert({ color: baseWarning }),
              error: convert({ color: baseError }),
              danger: convert({ color: baseDanger }),
              info: convert({ color: baseInfo }),
              fill: {
                DEFAULT: baseFill,
                darker: baseDarkerFill,
                dark: baseDarkFill,
                light: baseLightFill,
                lighter: baseLighterFill,
                "extra-light": baseExtraLightFill,
                blank: baseBlankFill
              }
            },
            backgroundColor: {
              DEFAULT: baseBg,
              page: basePageBg,
              overlay: baseOverlayBg,
              mask: baseMaskBg,
              disabled: baseDisabledBg
            },
            borderColor: {
              DEFAULT: baseBorder,
              darker: baseDarkerBorder,
              dark: baseDarkBorder,
              light: baseLightBorder,
              lighter: baseLighterBorder,
              "extra-light": baseExtraLightBorder
            },
            textColor: {
              DEFAULT: baseText,
              "primary-text": basePrimaryText,
              "regular-text": baseRegularText,
              "secondary-text": baseSecondaryText,
              "placeholder-text": basePlaceholderText,
              "disabled-text": baseDisabledText
            },
            boxShadow: {
              DEFAULT: baseBoxShadow
            }
          }
        },
        {
          name: "dark",
          selectors: darkSelectors,
          mediaQuery: darkMediaQuery,
          theme: {
            colors: {
              primary: convert({ color: darkPrimary, lightenColor: darkBg, darkenColor: "white" }),
              secondary: convert({
                color: darkSecondary,
                lightenColor: darkBg,
                darkenColor: "white"
              }),
              success: convert({
                color: darkSuccess,
                lightenColor: darkBg,
                darkenColor: "white"
              }),
              warning: convert({
                color: darkWarning,
                lightenColor: darkBg,
                darkenColor: "white"
              }),
              error: convert({ color: darkError, lightenColor: darkBg, darkenColor: "white" }),
              danger: convert({
                color: darkDanger,
                lightenColor: darkBg,
                darkenColor: "white"
              }),
              info: convert({ color: darkInfo, lightenColor: darkBg, darkenColor: "white" }),
              fill: {
                DEFAULT: darkFill,
                darker: darkDarkerFill,
                dark: darkDarkFill,
                light: darkLightFill,
                lighter: darkLighterFill,
                "extra-light": darkExtraLightFill,
                blank: darkBlankFill
              }
            },
            backgroundColor: {
              DEFAULT: darkBg,
              page: darkPageBg,
              overlay: darkOverlayBg,
              mask: darkMaskBg,
              disabled: darkDisabledBg
            },
            borderColor: {
              DEFAULT: darkBorder,
              darker: darkDarkerBorder,
              dark: darkDarkBorder,
              light: darkLightBorder,
              lighter: darkLighterBorder,
              "extra-light": darkExtraLightBorder
            },
            textColor: {
              DEFAULT: darkText,
              "primary-text": darkPrimaryText,
              "regular-text": darkRegularText,
              "secondary-text": darkSecondaryText,
              "placeholder-text": darkPlaceholderText,
              "disabled-text": darkDisabledText
            },
            boxShadow: {
              DEFAULT: darkBoxShadow
            }
          }
        }
      ]
    })
  ],
  theme: {
    screens: {
      sm: "768px",
      md: "992px",
      lg: "1200px",
      xl: "1920px"
    },
    extend: {
      fontFamily: {
        DEFAULT: [
          "Helvetica Neue",
          "Helvetica",
          "PingFang SC",
          "Hiragino Sans GB",
          "Microsoft YaHei",
          "\u5FAE\u8F6F\u96C5\u9ED1",
          "Arial",
          "sans-serif"
        ]
      }
    }
  }
});

const miniprogramBasePreset = {
  content: [],
  theme: {
    extend: {
      spacing: {
        rpx: "1rpx",
        "1rpx": "1rpx",
        "2rpx": "2rpx",
        "3rpx": "3rpx",
        "4rpx": "4rpx",
        "5rpx": "5rpx",
        "6rpx": "6rpx",
        "7rpx": "7rpx",
        "8rpx": "8rpx",
        "9rpx": "9rpx",
        "10rpx": "10rpx",
        "11rpx": "11rpx",
        "12rpx": "12rpx",
        "13rpx": "13rpx",
        "14rpx": "14rpx",
        "15rpx": "15rpx",
        "16rpx": "16rpx",
        "17rpx": "17rpx",
        "18rpx": "18rpx",
        "19rpx": "19rpx",
        "20rpx": "20rpx",
        "21rpx": "21rpx",
        "22rpx": "22rpx",
        "23rpx": "23rpx",
        "24rpx": "24rpx",
        "25rpx": "25rpx",
        "26rpx": "26rpx",
        "27rpx": "27rpx",
        "28rpx": "28rpx",
        "29rpx": "29rpx",
        "30rpx": "30rpx",
        "31rpx": "31rpx",
        "32rpx": "32rpx",
        "33rpx": "33rpx",
        "34rpx": "34rpx",
        "35rpx": "35rpx",
        "36rpx": "36rpx",
        "37rpx": "37rpx",
        "38rpx": "38rpx",
        "39rpx": "39rpx",
        "40rpx": "40rpx",
        "41rpx": "41rpx",
        "42rpx": "42rpx",
        "43rpx": "43rpx",
        "44rpx": "44rpx",
        "45rpx": "45rpx",
        "46rpx": "46rpx",
        "47rpx": "47rpx",
        "48rpx": "48rpx",
        "49rpx": "49rpx",
        "50rpx": "50rpx",
        "51rpx": "51rpx",
        "52rpx": "52rpx",
        "53rpx": "53rpx",
        "54rpx": "54rpx",
        "55rpx": "55rpx",
        "56rpx": "56rpx",
        "57rpx": "57rpx",
        "58rpx": "58rpx",
        "59rpx": "59rpx",
        "60rpx": "60rpx",
        "61rpx": "61rpx",
        "62rpx": "62rpx",
        "63rpx": "63rpx",
        "64rpx": "64rpx",
        "65rpx": "65rpx",
        "66rpx": "66rpx",
        "67rpx": "67rpx",
        "68rpx": "68rpx",
        "69rpx": "69rpx",
        "70rpx": "70rpx",
        "71rpx": "71rpx",
        "72rpx": "72rpx",
        "73rpx": "73rpx",
        "74rpx": "74rpx",
        "75rpx": "75rpx",
        "76rpx": "76rpx",
        "77rpx": "77rpx",
        "78rpx": "78rpx",
        "79rpx": "79rpx",
        "80rpx": "80rpx",
        "81rpx": "81rpx",
        "82rpx": "82rpx",
        "83rpx": "83rpx",
        "84rpx": "84rpx",
        "85rpx": "85rpx",
        "86rpx": "86rpx",
        "87rpx": "87rpx",
        "88rpx": "88rpx",
        "89rpx": "89rpx",
        "90rpx": "90rpx",
        "91rpx": "91rpx",
        "92rpx": "92rpx",
        "93rpx": "93rpx",
        "94rpx": "94rpx",
        "95rpx": "95rpx",
        "96rpx": "96rpx",
        "97rpx": "97rpx",
        "98rpx": "98rpx",
        "99rpx": "99rpx",
        "100rpx": "100rpx",
        "101rpx": "101rpx",
        "102rpx": "102rpx",
        "103rpx": "103rpx",
        "104rpx": "104rpx",
        "105rpx": "105rpx",
        "106rpx": "106rpx",
        "107rpx": "107rpx",
        "108rpx": "108rpx",
        "109rpx": "109rpx",
        "110rpx": "110rpx",
        "111rpx": "111rpx",
        "112rpx": "112rpx",
        "113rpx": "113rpx",
        "114rpx": "114rpx",
        "115rpx": "115rpx",
        "116rpx": "116rpx",
        "117rpx": "117rpx",
        "118rpx": "118rpx",
        "119rpx": "119rpx",
        "120rpx": "120rpx",
        "121rpx": "121rpx",
        "122rpx": "122rpx",
        "123rpx": "123rpx",
        "124rpx": "124rpx",
        "125rpx": "125rpx",
        "126rpx": "126rpx",
        "127rpx": "127rpx",
        "128rpx": "128rpx",
        "129rpx": "129rpx",
        "130rpx": "130rpx",
        "131rpx": "131rpx",
        "132rpx": "132rpx",
        "133rpx": "133rpx",
        "134rpx": "134rpx",
        "135rpx": "135rpx",
        "136rpx": "136rpx",
        "137rpx": "137rpx",
        "138rpx": "138rpx",
        "139rpx": "139rpx",
        "140rpx": "140rpx",
        "141rpx": "141rpx",
        "142rpx": "142rpx",
        "143rpx": "143rpx",
        "144rpx": "144rpx",
        "145rpx": "145rpx",
        "146rpx": "146rpx",
        "147rpx": "147rpx",
        "148rpx": "148rpx",
        "149rpx": "149rpx",
        "150rpx": "150rpx",
        "151rpx": "151rpx",
        "152rpx": "152rpx",
        "153rpx": "153rpx",
        "154rpx": "154rpx",
        "155rpx": "155rpx",
        "156rpx": "156rpx",
        "157rpx": "157rpx",
        "158rpx": "158rpx",
        "159rpx": "159rpx",
        "160rpx": "160rpx",
        "161rpx": "161rpx",
        "162rpx": "162rpx",
        "163rpx": "163rpx",
        "164rpx": "164rpx",
        "165rpx": "165rpx",
        "166rpx": "166rpx",
        "167rpx": "167rpx",
        "168rpx": "168rpx",
        "169rpx": "169rpx",
        "170rpx": "170rpx",
        "171rpx": "171rpx",
        "172rpx": "172rpx",
        "173rpx": "173rpx",
        "174rpx": "174rpx",
        "175rpx": "175rpx",
        "176rpx": "176rpx",
        "177rpx": "177rpx",
        "178rpx": "178rpx",
        "179rpx": "179rpx",
        "180rpx": "180rpx",
        "181rpx": "181rpx",
        "182rpx": "182rpx",
        "183rpx": "183rpx",
        "184rpx": "184rpx",
        "185rpx": "185rpx",
        "186rpx": "186rpx",
        "187rpx": "187rpx",
        "188rpx": "188rpx",
        "189rpx": "189rpx",
        "190rpx": "190rpx",
        "191rpx": "191rpx",
        "192rpx": "192rpx",
        "193rpx": "193rpx",
        "194rpx": "194rpx",
        "195rpx": "195rpx",
        "196rpx": "196rpx",
        "197rpx": "197rpx",
        "198rpx": "198rpx",
        "199rpx": "199rpx",
        "200rpx": "200rpx",
        "201rpx": "201rpx",
        "202rpx": "202rpx",
        "203rpx": "203rpx",
        "204rpx": "204rpx",
        "205rpx": "205rpx",
        "206rpx": "206rpx",
        "207rpx": "207rpx",
        "208rpx": "208rpx",
        "209rpx": "209rpx",
        "210rpx": "210rpx",
        "211rpx": "211rpx",
        "212rpx": "212rpx",
        "213rpx": "213rpx",
        "214rpx": "214rpx",
        "215rpx": "215rpx",
        "216rpx": "216rpx",
        "217rpx": "217rpx",
        "218rpx": "218rpx",
        "219rpx": "219rpx",
        "220rpx": "220rpx",
        "221rpx": "221rpx",
        "222rpx": "222rpx",
        "223rpx": "223rpx",
        "224rpx": "224rpx",
        "225rpx": "225rpx",
        "226rpx": "226rpx",
        "227rpx": "227rpx",
        "228rpx": "228rpx",
        "229rpx": "229rpx",
        "230rpx": "230rpx",
        "231rpx": "231rpx",
        "232rpx": "232rpx",
        "233rpx": "233rpx",
        "234rpx": "234rpx",
        "235rpx": "235rpx",
        "236rpx": "236rpx",
        "237rpx": "237rpx",
        "238rpx": "238rpx",
        "239rpx": "239rpx",
        "240rpx": "240rpx",
        "241rpx": "241rpx",
        "242rpx": "242rpx",
        "243rpx": "243rpx",
        "244rpx": "244rpx",
        "245rpx": "245rpx",
        "246rpx": "246rpx",
        "247rpx": "247rpx",
        "248rpx": "248rpx",
        "249rpx": "249rpx",
        "250rpx": "250rpx",
        "251rpx": "251rpx",
        "252rpx": "252rpx",
        "253rpx": "253rpx",
        "254rpx": "254rpx",
        "255rpx": "255rpx",
        "256rpx": "256rpx",
        "257rpx": "257rpx",
        "258rpx": "258rpx",
        "259rpx": "259rpx",
        "260rpx": "260rpx",
        "261rpx": "261rpx",
        "262rpx": "262rpx",
        "263rpx": "263rpx",
        "264rpx": "264rpx",
        "265rpx": "265rpx",
        "266rpx": "266rpx",
        "267rpx": "267rpx",
        "268rpx": "268rpx",
        "269rpx": "269rpx",
        "270rpx": "270rpx",
        "271rpx": "271rpx",
        "272rpx": "272rpx",
        "273rpx": "273rpx",
        "274rpx": "274rpx",
        "275rpx": "275rpx",
        "276rpx": "276rpx",
        "277rpx": "277rpx",
        "278rpx": "278rpx",
        "279rpx": "279rpx",
        "280rpx": "280rpx",
        "281rpx": "281rpx",
        "282rpx": "282rpx",
        "283rpx": "283rpx",
        "284rpx": "284rpx",
        "285rpx": "285rpx",
        "286rpx": "286rpx",
        "287rpx": "287rpx",
        "288rpx": "288rpx",
        "289rpx": "289rpx",
        "290rpx": "290rpx",
        "291rpx": "291rpx",
        "292rpx": "292rpx",
        "293rpx": "293rpx",
        "294rpx": "294rpx",
        "295rpx": "295rpx",
        "296rpx": "296rpx",
        "297rpx": "297rpx",
        "298rpx": "298rpx",
        "299rpx": "299rpx",
        "300rpx": "300rpx",
        "301rpx": "301rpx",
        "302rpx": "302rpx",
        "303rpx": "303rpx",
        "304rpx": "304rpx",
        "305rpx": "305rpx",
        "306rpx": "306rpx",
        "307rpx": "307rpx",
        "308rpx": "308rpx",
        "309rpx": "309rpx",
        "310rpx": "310rpx",
        "311rpx": "311rpx",
        "312rpx": "312rpx",
        "313rpx": "313rpx",
        "314rpx": "314rpx",
        "315rpx": "315rpx",
        "316rpx": "316rpx",
        "317rpx": "317rpx",
        "318rpx": "318rpx",
        "319rpx": "319rpx",
        "320rpx": "320rpx",
        "321rpx": "321rpx",
        "322rpx": "322rpx",
        "323rpx": "323rpx",
        "324rpx": "324rpx",
        "325rpx": "325rpx",
        "326rpx": "326rpx",
        "327rpx": "327rpx",
        "328rpx": "328rpx",
        "329rpx": "329rpx",
        "330rpx": "330rpx",
        "331rpx": "331rpx",
        "332rpx": "332rpx",
        "333rpx": "333rpx",
        "334rpx": "334rpx",
        "335rpx": "335rpx",
        "336rpx": "336rpx",
        "337rpx": "337rpx",
        "338rpx": "338rpx",
        "339rpx": "339rpx",
        "340rpx": "340rpx",
        "341rpx": "341rpx",
        "342rpx": "342rpx",
        "343rpx": "343rpx",
        "344rpx": "344rpx",
        "345rpx": "345rpx",
        "346rpx": "346rpx",
        "347rpx": "347rpx",
        "348rpx": "348rpx",
        "349rpx": "349rpx",
        "350rpx": "350rpx",
        "351rpx": "351rpx",
        "352rpx": "352rpx",
        "353rpx": "353rpx",
        "354rpx": "354rpx",
        "355rpx": "355rpx",
        "356rpx": "356rpx",
        "357rpx": "357rpx",
        "358rpx": "358rpx",
        "359rpx": "359rpx",
        "360rpx": "360rpx",
        "361rpx": "361rpx",
        "362rpx": "362rpx",
        "363rpx": "363rpx",
        "364rpx": "364rpx",
        "365rpx": "365rpx",
        "366rpx": "366rpx",
        "367rpx": "367rpx",
        "368rpx": "368rpx",
        "369rpx": "369rpx",
        "370rpx": "370rpx",
        "371rpx": "371rpx",
        "372rpx": "372rpx",
        "373rpx": "373rpx",
        "374rpx": "374rpx",
        "375rpx": "375rpx",
        "376rpx": "376rpx",
        "377rpx": "377rpx",
        "378rpx": "378rpx",
        "379rpx": "379rpx",
        "380rpx": "380rpx",
        "381rpx": "381rpx",
        "382rpx": "382rpx",
        "383rpx": "383rpx",
        "384rpx": "384rpx",
        "385rpx": "385rpx",
        "386rpx": "386rpx",
        "387rpx": "387rpx",
        "388rpx": "388rpx",
        "389rpx": "389rpx",
        "390rpx": "390rpx",
        "391rpx": "391rpx",
        "392rpx": "392rpx",
        "393rpx": "393rpx",
        "394rpx": "394rpx",
        "395rpx": "395rpx",
        "396rpx": "396rpx",
        "397rpx": "397rpx",
        "398rpx": "398rpx",
        "399rpx": "399rpx",
        "400rpx": "400rpx",
        "401rpx": "401rpx",
        "402rpx": "402rpx",
        "403rpx": "403rpx",
        "404rpx": "404rpx",
        "405rpx": "405rpx",
        "406rpx": "406rpx",
        "407rpx": "407rpx",
        "408rpx": "408rpx",
        "409rpx": "409rpx",
        "410rpx": "410rpx",
        "411rpx": "411rpx",
        "412rpx": "412rpx",
        "413rpx": "413rpx",
        "414rpx": "414rpx",
        "415rpx": "415rpx",
        "416rpx": "416rpx",
        "417rpx": "417rpx",
        "418rpx": "418rpx",
        "419rpx": "419rpx",
        "420rpx": "420rpx",
        "421rpx": "421rpx",
        "422rpx": "422rpx",
        "423rpx": "423rpx",
        "424rpx": "424rpx",
        "425rpx": "425rpx",
        "426rpx": "426rpx",
        "427rpx": "427rpx",
        "428rpx": "428rpx",
        "429rpx": "429rpx",
        "430rpx": "430rpx",
        "431rpx": "431rpx",
        "432rpx": "432rpx",
        "433rpx": "433rpx",
        "434rpx": "434rpx",
        "435rpx": "435rpx",
        "436rpx": "436rpx",
        "437rpx": "437rpx",
        "438rpx": "438rpx",
        "439rpx": "439rpx",
        "440rpx": "440rpx",
        "441rpx": "441rpx",
        "442rpx": "442rpx",
        "443rpx": "443rpx",
        "444rpx": "444rpx",
        "445rpx": "445rpx",
        "446rpx": "446rpx",
        "447rpx": "447rpx",
        "448rpx": "448rpx",
        "449rpx": "449rpx",
        "450rpx": "450rpx",
        "451rpx": "451rpx",
        "452rpx": "452rpx",
        "453rpx": "453rpx",
        "454rpx": "454rpx",
        "455rpx": "455rpx",
        "456rpx": "456rpx",
        "457rpx": "457rpx",
        "458rpx": "458rpx",
        "459rpx": "459rpx",
        "460rpx": "460rpx",
        "461rpx": "461rpx",
        "462rpx": "462rpx",
        "463rpx": "463rpx",
        "464rpx": "464rpx",
        "465rpx": "465rpx",
        "466rpx": "466rpx",
        "467rpx": "467rpx",
        "468rpx": "468rpx",
        "469rpx": "469rpx",
        "470rpx": "470rpx",
        "471rpx": "471rpx",
        "472rpx": "472rpx",
        "473rpx": "473rpx",
        "474rpx": "474rpx",
        "475rpx": "475rpx",
        "476rpx": "476rpx",
        "477rpx": "477rpx",
        "478rpx": "478rpx",
        "479rpx": "479rpx",
        "480rpx": "480rpx",
        "481rpx": "481rpx",
        "482rpx": "482rpx",
        "483rpx": "483rpx",
        "484rpx": "484rpx",
        "485rpx": "485rpx",
        "486rpx": "486rpx",
        "487rpx": "487rpx",
        "488rpx": "488rpx",
        "489rpx": "489rpx",
        "490rpx": "490rpx",
        "491rpx": "491rpx",
        "492rpx": "492rpx",
        "493rpx": "493rpx",
        "494rpx": "494rpx",
        "495rpx": "495rpx",
        "496rpx": "496rpx",
        "497rpx": "497rpx",
        "498rpx": "498rpx",
        "499rpx": "499rpx",
        "500rpx": "500rpx",
        "501rpx": "501rpx",
        "502rpx": "502rpx",
        "503rpx": "503rpx",
        "504rpx": "504rpx",
        "505rpx": "505rpx",
        "506rpx": "506rpx",
        "507rpx": "507rpx",
        "508rpx": "508rpx",
        "509rpx": "509rpx",
        "510rpx": "510rpx",
        "511rpx": "511rpx",
        "512rpx": "512rpx",
        "513rpx": "513rpx",
        "514rpx": "514rpx",
        "515rpx": "515rpx",
        "516rpx": "516rpx",
        "517rpx": "517rpx",
        "518rpx": "518rpx",
        "519rpx": "519rpx",
        "520rpx": "520rpx",
        "521rpx": "521rpx",
        "522rpx": "522rpx",
        "523rpx": "523rpx",
        "524rpx": "524rpx",
        "525rpx": "525rpx",
        "526rpx": "526rpx",
        "527rpx": "527rpx",
        "528rpx": "528rpx",
        "529rpx": "529rpx",
        "530rpx": "530rpx",
        "531rpx": "531rpx",
        "532rpx": "532rpx",
        "533rpx": "533rpx",
        "534rpx": "534rpx",
        "535rpx": "535rpx",
        "536rpx": "536rpx",
        "537rpx": "537rpx",
        "538rpx": "538rpx",
        "539rpx": "539rpx",
        "540rpx": "540rpx",
        "541rpx": "541rpx",
        "542rpx": "542rpx",
        "543rpx": "543rpx",
        "544rpx": "544rpx",
        "545rpx": "545rpx",
        "546rpx": "546rpx",
        "547rpx": "547rpx",
        "548rpx": "548rpx",
        "549rpx": "549rpx",
        "550rpx": "550rpx",
        "551rpx": "551rpx",
        "552rpx": "552rpx",
        "553rpx": "553rpx",
        "554rpx": "554rpx",
        "555rpx": "555rpx",
        "556rpx": "556rpx",
        "557rpx": "557rpx",
        "558rpx": "558rpx",
        "559rpx": "559rpx",
        "560rpx": "560rpx",
        "561rpx": "561rpx",
        "562rpx": "562rpx",
        "563rpx": "563rpx",
        "564rpx": "564rpx",
        "565rpx": "565rpx",
        "566rpx": "566rpx",
        "567rpx": "567rpx",
        "568rpx": "568rpx",
        "569rpx": "569rpx",
        "570rpx": "570rpx",
        "571rpx": "571rpx",
        "572rpx": "572rpx",
        "573rpx": "573rpx",
        "574rpx": "574rpx",
        "575rpx": "575rpx",
        "576rpx": "576rpx",
        "577rpx": "577rpx",
        "578rpx": "578rpx",
        "579rpx": "579rpx",
        "580rpx": "580rpx",
        "581rpx": "581rpx",
        "582rpx": "582rpx",
        "583rpx": "583rpx",
        "584rpx": "584rpx",
        "585rpx": "585rpx",
        "586rpx": "586rpx",
        "587rpx": "587rpx",
        "588rpx": "588rpx",
        "589rpx": "589rpx",
        "590rpx": "590rpx",
        "591rpx": "591rpx",
        "592rpx": "592rpx",
        "593rpx": "593rpx",
        "594rpx": "594rpx",
        "595rpx": "595rpx",
        "596rpx": "596rpx",
        "597rpx": "597rpx",
        "598rpx": "598rpx",
        "599rpx": "599rpx",
        "600rpx": "600rpx",
        "601rpx": "601rpx",
        "602rpx": "602rpx",
        "603rpx": "603rpx",
        "604rpx": "604rpx",
        "605rpx": "605rpx",
        "606rpx": "606rpx",
        "607rpx": "607rpx",
        "608rpx": "608rpx",
        "609rpx": "609rpx",
        "610rpx": "610rpx",
        "611rpx": "611rpx",
        "612rpx": "612rpx",
        "613rpx": "613rpx",
        "614rpx": "614rpx",
        "615rpx": "615rpx",
        "616rpx": "616rpx",
        "617rpx": "617rpx",
        "618rpx": "618rpx",
        "619rpx": "619rpx",
        "620rpx": "620rpx",
        "621rpx": "621rpx",
        "622rpx": "622rpx",
        "623rpx": "623rpx",
        "624rpx": "624rpx",
        "625rpx": "625rpx",
        "626rpx": "626rpx",
        "627rpx": "627rpx",
        "628rpx": "628rpx",
        "629rpx": "629rpx",
        "630rpx": "630rpx",
        "631rpx": "631rpx",
        "632rpx": "632rpx",
        "633rpx": "633rpx",
        "634rpx": "634rpx",
        "635rpx": "635rpx",
        "636rpx": "636rpx",
        "637rpx": "637rpx",
        "638rpx": "638rpx",
        "639rpx": "639rpx",
        "640rpx": "640rpx",
        "641rpx": "641rpx",
        "642rpx": "642rpx",
        "643rpx": "643rpx",
        "644rpx": "644rpx",
        "645rpx": "645rpx",
        "646rpx": "646rpx",
        "647rpx": "647rpx",
        "648rpx": "648rpx",
        "649rpx": "649rpx",
        "650rpx": "650rpx",
        "651rpx": "651rpx",
        "652rpx": "652rpx",
        "653rpx": "653rpx",
        "654rpx": "654rpx",
        "655rpx": "655rpx",
        "656rpx": "656rpx",
        "657rpx": "657rpx",
        "658rpx": "658rpx",
        "659rpx": "659rpx",
        "660rpx": "660rpx",
        "661rpx": "661rpx",
        "662rpx": "662rpx",
        "663rpx": "663rpx",
        "664rpx": "664rpx",
        "665rpx": "665rpx",
        "666rpx": "666rpx",
        "667rpx": "667rpx",
        "668rpx": "668rpx",
        "669rpx": "669rpx",
        "670rpx": "670rpx",
        "671rpx": "671rpx",
        "672rpx": "672rpx",
        "673rpx": "673rpx",
        "674rpx": "674rpx",
        "675rpx": "675rpx",
        "676rpx": "676rpx",
        "677rpx": "677rpx",
        "678rpx": "678rpx",
        "679rpx": "679rpx",
        "680rpx": "680rpx",
        "681rpx": "681rpx",
        "682rpx": "682rpx",
        "683rpx": "683rpx",
        "684rpx": "684rpx",
        "685rpx": "685rpx",
        "686rpx": "686rpx",
        "687rpx": "687rpx",
        "688rpx": "688rpx",
        "689rpx": "689rpx",
        "690rpx": "690rpx",
        "691rpx": "691rpx",
        "692rpx": "692rpx",
        "693rpx": "693rpx",
        "694rpx": "694rpx",
        "695rpx": "695rpx",
        "696rpx": "696rpx",
        "697rpx": "697rpx",
        "698rpx": "698rpx",
        "699rpx": "699rpx",
        "700rpx": "700rpx",
        "701rpx": "701rpx",
        "702rpx": "702rpx",
        "703rpx": "703rpx",
        "704rpx": "704rpx",
        "705rpx": "705rpx",
        "706rpx": "706rpx",
        "707rpx": "707rpx",
        "708rpx": "708rpx",
        "709rpx": "709rpx",
        "710rpx": "710rpx",
        "711rpx": "711rpx",
        "712rpx": "712rpx",
        "713rpx": "713rpx",
        "714rpx": "714rpx",
        "715rpx": "715rpx",
        "716rpx": "716rpx",
        "717rpx": "717rpx",
        "718rpx": "718rpx",
        "719rpx": "719rpx",
        "720rpx": "720rpx",
        "721rpx": "721rpx",
        "722rpx": "722rpx",
        "723rpx": "723rpx",
        "724rpx": "724rpx",
        "725rpx": "725rpx",
        "726rpx": "726rpx",
        "727rpx": "727rpx",
        "728rpx": "728rpx",
        "729rpx": "729rpx",
        "730rpx": "730rpx",
        "731rpx": "731rpx",
        "732rpx": "732rpx",
        "733rpx": "733rpx",
        "734rpx": "734rpx",
        "735rpx": "735rpx",
        "736rpx": "736rpx",
        "737rpx": "737rpx",
        "738rpx": "738rpx",
        "739rpx": "739rpx",
        "740rpx": "740rpx",
        "741rpx": "741rpx",
        "742rpx": "742rpx",
        "743rpx": "743rpx",
        "744rpx": "744rpx",
        "745rpx": "745rpx",
        "746rpx": "746rpx",
        "747rpx": "747rpx",
        "748rpx": "748rpx",
        "749rpx": "749rpx",
        "750rpx": "750rpx",
        "751rpx": "751rpx",
        "752rpx": "752rpx",
        "753rpx": "753rpx",
        "754rpx": "754rpx",
        "755rpx": "755rpx",
        "756rpx": "756rpx",
        "757rpx": "757rpx",
        "758rpx": "758rpx",
        "759rpx": "759rpx",
        "760rpx": "760rpx",
        "761rpx": "761rpx",
        "762rpx": "762rpx",
        "763rpx": "763rpx",
        "764rpx": "764rpx",
        "765rpx": "765rpx",
        "766rpx": "766rpx",
        "767rpx": "767rpx",
        "768rpx": "768rpx",
        "769rpx": "769rpx",
        "770rpx": "770rpx",
        "771rpx": "771rpx",
        "772rpx": "772rpx",
        "773rpx": "773rpx",
        "774rpx": "774rpx",
        "775rpx": "775rpx",
        "776rpx": "776rpx",
        "777rpx": "777rpx",
        "778rpx": "778rpx",
        "779rpx": "779rpx",
        "780rpx": "780rpx",
        "781rpx": "781rpx",
        "782rpx": "782rpx",
        "783rpx": "783rpx",
        "784rpx": "784rpx",
        "785rpx": "785rpx",
        "786rpx": "786rpx",
        "787rpx": "787rpx",
        "788rpx": "788rpx",
        "789rpx": "789rpx",
        "790rpx": "790rpx",
        "791rpx": "791rpx",
        "792rpx": "792rpx",
        "793rpx": "793rpx",
        "794rpx": "794rpx",
        "795rpx": "795rpx",
        "796rpx": "796rpx",
        "797rpx": "797rpx",
        "798rpx": "798rpx",
        "799rpx": "799rpx",
        "800rpx": "800rpx",
        "801rpx": "801rpx",
        "802rpx": "802rpx",
        "803rpx": "803rpx",
        "804rpx": "804rpx",
        "805rpx": "805rpx",
        "806rpx": "806rpx",
        "807rpx": "807rpx",
        "808rpx": "808rpx",
        "809rpx": "809rpx",
        "810rpx": "810rpx",
        "811rpx": "811rpx",
        "812rpx": "812rpx",
        "813rpx": "813rpx",
        "814rpx": "814rpx",
        "815rpx": "815rpx",
        "816rpx": "816rpx",
        "817rpx": "817rpx",
        "818rpx": "818rpx",
        "819rpx": "819rpx",
        "820rpx": "820rpx",
        "821rpx": "821rpx",
        "822rpx": "822rpx",
        "823rpx": "823rpx",
        "824rpx": "824rpx",
        "825rpx": "825rpx",
        "826rpx": "826rpx",
        "827rpx": "827rpx",
        "828rpx": "828rpx",
        "829rpx": "829rpx",
        "830rpx": "830rpx",
        "831rpx": "831rpx",
        "832rpx": "832rpx",
        "833rpx": "833rpx",
        "834rpx": "834rpx",
        "835rpx": "835rpx",
        "836rpx": "836rpx",
        "837rpx": "837rpx",
        "838rpx": "838rpx",
        "839rpx": "839rpx",
        "840rpx": "840rpx",
        "841rpx": "841rpx",
        "842rpx": "842rpx",
        "843rpx": "843rpx",
        "844rpx": "844rpx",
        "845rpx": "845rpx",
        "846rpx": "846rpx",
        "847rpx": "847rpx",
        "848rpx": "848rpx",
        "849rpx": "849rpx",
        "850rpx": "850rpx",
        "851rpx": "851rpx",
        "852rpx": "852rpx",
        "853rpx": "853rpx",
        "854rpx": "854rpx",
        "855rpx": "855rpx",
        "856rpx": "856rpx",
        "857rpx": "857rpx",
        "858rpx": "858rpx",
        "859rpx": "859rpx",
        "860rpx": "860rpx",
        "861rpx": "861rpx",
        "862rpx": "862rpx",
        "863rpx": "863rpx",
        "864rpx": "864rpx",
        "865rpx": "865rpx",
        "866rpx": "866rpx",
        "867rpx": "867rpx",
        "868rpx": "868rpx",
        "869rpx": "869rpx",
        "870rpx": "870rpx",
        "871rpx": "871rpx",
        "872rpx": "872rpx",
        "873rpx": "873rpx",
        "874rpx": "874rpx",
        "875rpx": "875rpx",
        "876rpx": "876rpx",
        "877rpx": "877rpx",
        "878rpx": "878rpx",
        "879rpx": "879rpx",
        "880rpx": "880rpx",
        "881rpx": "881rpx",
        "882rpx": "882rpx",
        "883rpx": "883rpx",
        "884rpx": "884rpx",
        "885rpx": "885rpx",
        "886rpx": "886rpx",
        "887rpx": "887rpx",
        "888rpx": "888rpx",
        "889rpx": "889rpx",
        "890rpx": "890rpx",
        "891rpx": "891rpx",
        "892rpx": "892rpx",
        "893rpx": "893rpx",
        "894rpx": "894rpx",
        "895rpx": "895rpx",
        "896rpx": "896rpx",
        "897rpx": "897rpx",
        "898rpx": "898rpx",
        "899rpx": "899rpx",
        "900rpx": "900rpx",
        "901rpx": "901rpx",
        "902rpx": "902rpx",
        "903rpx": "903rpx",
        "904rpx": "904rpx",
        "905rpx": "905rpx",
        "906rpx": "906rpx",
        "907rpx": "907rpx",
        "908rpx": "908rpx",
        "909rpx": "909rpx",
        "910rpx": "910rpx",
        "911rpx": "911rpx",
        "912rpx": "912rpx",
        "913rpx": "913rpx",
        "914rpx": "914rpx",
        "915rpx": "915rpx",
        "916rpx": "916rpx",
        "917rpx": "917rpx",
        "918rpx": "918rpx",
        "919rpx": "919rpx",
        "920rpx": "920rpx",
        "921rpx": "921rpx",
        "922rpx": "922rpx",
        "923rpx": "923rpx",
        "924rpx": "924rpx",
        "925rpx": "925rpx",
        "926rpx": "926rpx",
        "927rpx": "927rpx",
        "928rpx": "928rpx",
        "929rpx": "929rpx",
        "930rpx": "930rpx",
        "931rpx": "931rpx",
        "932rpx": "932rpx",
        "933rpx": "933rpx",
        "934rpx": "934rpx",
        "935rpx": "935rpx",
        "936rpx": "936rpx",
        "937rpx": "937rpx",
        "938rpx": "938rpx",
        "939rpx": "939rpx",
        "940rpx": "940rpx",
        "941rpx": "941rpx",
        "942rpx": "942rpx",
        "943rpx": "943rpx",
        "944rpx": "944rpx",
        "945rpx": "945rpx",
        "946rpx": "946rpx",
        "947rpx": "947rpx",
        "948rpx": "948rpx",
        "949rpx": "949rpx",
        "950rpx": "950rpx",
        "951rpx": "951rpx",
        "952rpx": "952rpx",
        "953rpx": "953rpx",
        "954rpx": "954rpx",
        "955rpx": "955rpx",
        "956rpx": "956rpx",
        "957rpx": "957rpx",
        "958rpx": "958rpx",
        "959rpx": "959rpx",
        "960rpx": "960rpx",
        "961rpx": "961rpx",
        "962rpx": "962rpx",
        "963rpx": "963rpx",
        "964rpx": "964rpx",
        "965rpx": "965rpx",
        "966rpx": "966rpx",
        "967rpx": "967rpx",
        "968rpx": "968rpx",
        "969rpx": "969rpx",
        "970rpx": "970rpx",
        "971rpx": "971rpx",
        "972rpx": "972rpx",
        "973rpx": "973rpx",
        "974rpx": "974rpx",
        "975rpx": "975rpx",
        "976rpx": "976rpx",
        "977rpx": "977rpx",
        "978rpx": "978rpx",
        "979rpx": "979rpx",
        "980rpx": "980rpx",
        "981rpx": "981rpx",
        "982rpx": "982rpx",
        "983rpx": "983rpx",
        "984rpx": "984rpx",
        "985rpx": "985rpx",
        "986rpx": "986rpx",
        "987rpx": "987rpx",
        "988rpx": "988rpx",
        "989rpx": "989rpx",
        "990rpx": "990rpx",
        "991rpx": "991rpx",
        "992rpx": "992rpx",
        "993rpx": "993rpx",
        "994rpx": "994rpx",
        "995rpx": "995rpx",
        "996rpx": "996rpx",
        "997rpx": "997rpx",
        "998rpx": "998rpx",
        "999rpx": "999rpx",
        "1000rpx": "1000rpx",
        "1001rpx": "1001rpx",
        "1002rpx": "1002rpx",
        "1003rpx": "1003rpx",
        "1004rpx": "1004rpx",
        "1005rpx": "1005rpx",
        "1006rpx": "1006rpx",
        "1007rpx": "1007rpx",
        "1008rpx": "1008rpx",
        "1009rpx": "1009rpx",
        "1010rpx": "1010rpx",
        "1011rpx": "1011rpx",
        "1012rpx": "1012rpx",
        "1013rpx": "1013rpx",
        "1014rpx": "1014rpx",
        "1015rpx": "1015rpx",
        "1016rpx": "1016rpx",
        "1017rpx": "1017rpx",
        "1018rpx": "1018rpx",
        "1019rpx": "1019rpx",
        "1020rpx": "1020rpx",
        "1021rpx": "1021rpx",
        "1022rpx": "1022rpx",
        "1023rpx": "1023rpx",
        "1024rpx": "1024rpx",
        "1025rpx": "1025rpx",
        "1026rpx": "1026rpx",
        "1027rpx": "1027rpx",
        "1028rpx": "1028rpx",
        "1029rpx": "1029rpx",
        "1030rpx": "1030rpx",
        "1031rpx": "1031rpx",
        "1032rpx": "1032rpx",
        "1033rpx": "1033rpx",
        "1034rpx": "1034rpx",
        "1035rpx": "1035rpx",
        "1036rpx": "1036rpx",
        "1037rpx": "1037rpx",
        "1038rpx": "1038rpx",
        "1039rpx": "1039rpx",
        "1040rpx": "1040rpx",
        "1041rpx": "1041rpx",
        "1042rpx": "1042rpx",
        "1043rpx": "1043rpx",
        "1044rpx": "1044rpx",
        "1045rpx": "1045rpx",
        "1046rpx": "1046rpx",
        "1047rpx": "1047rpx",
        "1048rpx": "1048rpx",
        "1049rpx": "1049rpx",
        "1050rpx": "1050rpx",
        "1051rpx": "1051rpx",
        "1052rpx": "1052rpx",
        "1053rpx": "1053rpx",
        "1054rpx": "1054rpx",
        "1055rpx": "1055rpx",
        "1056rpx": "1056rpx",
        "1057rpx": "1057rpx",
        "1058rpx": "1058rpx",
        "1059rpx": "1059rpx",
        "1060rpx": "1060rpx",
        "1061rpx": "1061rpx",
        "1062rpx": "1062rpx",
        "1063rpx": "1063rpx",
        "1064rpx": "1064rpx",
        "1065rpx": "1065rpx",
        "1066rpx": "1066rpx",
        "1067rpx": "1067rpx",
        "1068rpx": "1068rpx",
        "1069rpx": "1069rpx",
        "1070rpx": "1070rpx",
        "1071rpx": "1071rpx",
        "1072rpx": "1072rpx",
        "1073rpx": "1073rpx",
        "1074rpx": "1074rpx",
        "1075rpx": "1075rpx",
        "1076rpx": "1076rpx",
        "1077rpx": "1077rpx",
        "1078rpx": "1078rpx",
        "1079rpx": "1079rpx",
        "1080rpx": "1080rpx",
        "1081rpx": "1081rpx",
        "1082rpx": "1082rpx",
        "1083rpx": "1083rpx",
        "1084rpx": "1084rpx",
        "1085rpx": "1085rpx",
        "1086rpx": "1086rpx",
        "1087rpx": "1087rpx",
        "1088rpx": "1088rpx",
        "1089rpx": "1089rpx",
        "1090rpx": "1090rpx",
        "1091rpx": "1091rpx",
        "1092rpx": "1092rpx",
        "1093rpx": "1093rpx",
        "1094rpx": "1094rpx",
        "1095rpx": "1095rpx",
        "1096rpx": "1096rpx",
        "1097rpx": "1097rpx",
        "1098rpx": "1098rpx",
        "1099rpx": "1099rpx",
        "1100rpx": "1100rpx",
        "1101rpx": "1101rpx",
        "1102rpx": "1102rpx",
        "1103rpx": "1103rpx",
        "1104rpx": "1104rpx",
        "1105rpx": "1105rpx",
        "1106rpx": "1106rpx",
        "1107rpx": "1107rpx",
        "1108rpx": "1108rpx",
        "1109rpx": "1109rpx",
        "1110rpx": "1110rpx",
        "1111rpx": "1111rpx",
        "1112rpx": "1112rpx",
        "1113rpx": "1113rpx",
        "1114rpx": "1114rpx",
        "1115rpx": "1115rpx",
        "1116rpx": "1116rpx",
        "1117rpx": "1117rpx",
        "1118rpx": "1118rpx",
        "1119rpx": "1119rpx",
        "1120rpx": "1120rpx",
        "1121rpx": "1121rpx",
        "1122rpx": "1122rpx",
        "1123rpx": "1123rpx",
        "1124rpx": "1124rpx",
        "1125rpx": "1125rpx",
        "1126rpx": "1126rpx",
        "1127rpx": "1127rpx",
        "1128rpx": "1128rpx",
        "1129rpx": "1129rpx",
        "1130rpx": "1130rpx",
        "1131rpx": "1131rpx",
        "1132rpx": "1132rpx",
        "1133rpx": "1133rpx",
        "1134rpx": "1134rpx",
        "1135rpx": "1135rpx",
        "1136rpx": "1136rpx",
        "1137rpx": "1137rpx",
        "1138rpx": "1138rpx",
        "1139rpx": "1139rpx",
        "1140rpx": "1140rpx",
        "1141rpx": "1141rpx",
        "1142rpx": "1142rpx",
        "1143rpx": "1143rpx",
        "1144rpx": "1144rpx",
        "1145rpx": "1145rpx",
        "1146rpx": "1146rpx",
        "1147rpx": "1147rpx",
        "1148rpx": "1148rpx",
        "1149rpx": "1149rpx",
        "1150rpx": "1150rpx",
        "1151rpx": "1151rpx",
        "1152rpx": "1152rpx",
        "1153rpx": "1153rpx",
        "1154rpx": "1154rpx",
        "1155rpx": "1155rpx",
        "1156rpx": "1156rpx",
        "1157rpx": "1157rpx",
        "1158rpx": "1158rpx",
        "1159rpx": "1159rpx",
        "1160rpx": "1160rpx",
        "1161rpx": "1161rpx",
        "1162rpx": "1162rpx",
        "1163rpx": "1163rpx",
        "1164rpx": "1164rpx",
        "1165rpx": "1165rpx",
        "1166rpx": "1166rpx",
        "1167rpx": "1167rpx",
        "1168rpx": "1168rpx",
        "1169rpx": "1169rpx",
        "1170rpx": "1170rpx",
        "1171rpx": "1171rpx",
        "1172rpx": "1172rpx",
        "1173rpx": "1173rpx",
        "1174rpx": "1174rpx",
        "1175rpx": "1175rpx",
        "1176rpx": "1176rpx",
        "1177rpx": "1177rpx",
        "1178rpx": "1178rpx",
        "1179rpx": "1179rpx",
        "1180rpx": "1180rpx",
        "1181rpx": "1181rpx",
        "1182rpx": "1182rpx",
        "1183rpx": "1183rpx",
        "1184rpx": "1184rpx",
        "1185rpx": "1185rpx",
        "1186rpx": "1186rpx",
        "1187rpx": "1187rpx",
        "1188rpx": "1188rpx",
        "1189rpx": "1189rpx",
        "1190rpx": "1190rpx",
        "1191rpx": "1191rpx",
        "1192rpx": "1192rpx",
        "1193rpx": "1193rpx",
        "1194rpx": "1194rpx",
        "1195rpx": "1195rpx",
        "1196rpx": "1196rpx",
        "1197rpx": "1197rpx",
        "1198rpx": "1198rpx",
        "1199rpx": "1199rpx",
        "1200rpx": "1200rpx",
        "1201rpx": "1201rpx",
        "1202rpx": "1202rpx",
        "1203rpx": "1203rpx",
        "1204rpx": "1204rpx",
        "1205rpx": "1205rpx",
        "1206rpx": "1206rpx",
        "1207rpx": "1207rpx",
        "1208rpx": "1208rpx",
        "1209rpx": "1209rpx",
        "1210rpx": "1210rpx",
        "1211rpx": "1211rpx",
        "1212rpx": "1212rpx",
        "1213rpx": "1213rpx",
        "1214rpx": "1214rpx",
        "1215rpx": "1215rpx",
        "1216rpx": "1216rpx",
        "1217rpx": "1217rpx",
        "1218rpx": "1218rpx",
        "1219rpx": "1219rpx",
        "1220rpx": "1220rpx",
        "1221rpx": "1221rpx",
        "1222rpx": "1222rpx",
        "1223rpx": "1223rpx",
        "1224rpx": "1224rpx",
        "1225rpx": "1225rpx",
        "1226rpx": "1226rpx",
        "1227rpx": "1227rpx",
        "1228rpx": "1228rpx",
        "1229rpx": "1229rpx",
        "1230rpx": "1230rpx",
        "1231rpx": "1231rpx",
        "1232rpx": "1232rpx",
        "1233rpx": "1233rpx",
        "1234rpx": "1234rpx",
        "1235rpx": "1235rpx",
        "1236rpx": "1236rpx",
        "1237rpx": "1237rpx",
        "1238rpx": "1238rpx",
        "1239rpx": "1239rpx",
        "1240rpx": "1240rpx",
        "1241rpx": "1241rpx",
        "1242rpx": "1242rpx",
        "1243rpx": "1243rpx",
        "1244rpx": "1244rpx",
        "1245rpx": "1245rpx",
        "1246rpx": "1246rpx",
        "1247rpx": "1247rpx",
        "1248rpx": "1248rpx",
        "1249rpx": "1249rpx",
        "1250rpx": "1250rpx",
        "1251rpx": "1251rpx",
        "1252rpx": "1252rpx",
        "1253rpx": "1253rpx",
        "1254rpx": "1254rpx",
        "1255rpx": "1255rpx",
        "1256rpx": "1256rpx",
        "1257rpx": "1257rpx",
        "1258rpx": "1258rpx",
        "1259rpx": "1259rpx",
        "1260rpx": "1260rpx",
        "1261rpx": "1261rpx",
        "1262rpx": "1262rpx",
        "1263rpx": "1263rpx",
        "1264rpx": "1264rpx",
        "1265rpx": "1265rpx",
        "1266rpx": "1266rpx",
        "1267rpx": "1267rpx",
        "1268rpx": "1268rpx",
        "1269rpx": "1269rpx",
        "1270rpx": "1270rpx",
        "1271rpx": "1271rpx",
        "1272rpx": "1272rpx",
        "1273rpx": "1273rpx",
        "1274rpx": "1274rpx",
        "1275rpx": "1275rpx",
        "1276rpx": "1276rpx",
        "1277rpx": "1277rpx",
        "1278rpx": "1278rpx",
        "1279rpx": "1279rpx",
        "1280rpx": "1280rpx",
        "1281rpx": "1281rpx",
        "1282rpx": "1282rpx",
        "1283rpx": "1283rpx",
        "1284rpx": "1284rpx",
        "1285rpx": "1285rpx",
        "1286rpx": "1286rpx",
        "1287rpx": "1287rpx",
        "1288rpx": "1288rpx",
        "1289rpx": "1289rpx",
        "1290rpx": "1290rpx",
        "1291rpx": "1291rpx",
        "1292rpx": "1292rpx",
        "1293rpx": "1293rpx",
        "1294rpx": "1294rpx",
        "1295rpx": "1295rpx",
        "1296rpx": "1296rpx",
        "1297rpx": "1297rpx",
        "1298rpx": "1298rpx",
        "1299rpx": "1299rpx",
        "1300rpx": "1300rpx",
        "1301rpx": "1301rpx",
        "1302rpx": "1302rpx",
        "1303rpx": "1303rpx",
        "1304rpx": "1304rpx",
        "1305rpx": "1305rpx",
        "1306rpx": "1306rpx",
        "1307rpx": "1307rpx",
        "1308rpx": "1308rpx",
        "1309rpx": "1309rpx",
        "1310rpx": "1310rpx",
        "1311rpx": "1311rpx",
        "1312rpx": "1312rpx",
        "1313rpx": "1313rpx",
        "1314rpx": "1314rpx",
        "1315rpx": "1315rpx",
        "1316rpx": "1316rpx",
        "1317rpx": "1317rpx",
        "1318rpx": "1318rpx",
        "1319rpx": "1319rpx",
        "1320rpx": "1320rpx",
        "1321rpx": "1321rpx",
        "1322rpx": "1322rpx",
        "1323rpx": "1323rpx",
        "1324rpx": "1324rpx",
        "1325rpx": "1325rpx",
        "1326rpx": "1326rpx",
        "1327rpx": "1327rpx",
        "1328rpx": "1328rpx",
        "1329rpx": "1329rpx",
        "1330rpx": "1330rpx",
        "1331rpx": "1331rpx",
        "1332rpx": "1332rpx",
        "1333rpx": "1333rpx",
        "1334rpx": "1334rpx",
        "1335rpx": "1335rpx",
        "1336rpx": "1336rpx",
        "1337rpx": "1337rpx",
        "1338rpx": "1338rpx",
        "1339rpx": "1339rpx",
        "1340rpx": "1340rpx",
        "1341rpx": "1341rpx",
        "1342rpx": "1342rpx",
        "1343rpx": "1343rpx",
        "1344rpx": "1344rpx",
        "1345rpx": "1345rpx",
        "1346rpx": "1346rpx",
        "1347rpx": "1347rpx",
        "1348rpx": "1348rpx",
        "1349rpx": "1349rpx",
        "1350rpx": "1350rpx",
        "1351rpx": "1351rpx",
        "1352rpx": "1352rpx",
        "1353rpx": "1353rpx",
        "1354rpx": "1354rpx",
        "1355rpx": "1355rpx",
        "1356rpx": "1356rpx",
        "1357rpx": "1357rpx",
        "1358rpx": "1358rpx",
        "1359rpx": "1359rpx",
        "1360rpx": "1360rpx",
        "1361rpx": "1361rpx",
        "1362rpx": "1362rpx",
        "1363rpx": "1363rpx",
        "1364rpx": "1364rpx",
        "1365rpx": "1365rpx",
        "1366rpx": "1366rpx",
        "1367rpx": "1367rpx",
        "1368rpx": "1368rpx",
        "1369rpx": "1369rpx",
        "1370rpx": "1370rpx",
        "1371rpx": "1371rpx",
        "1372rpx": "1372rpx",
        "1373rpx": "1373rpx",
        "1374rpx": "1374rpx",
        "1375rpx": "1375rpx",
        "1376rpx": "1376rpx",
        "1377rpx": "1377rpx",
        "1378rpx": "1378rpx",
        "1379rpx": "1379rpx",
        "1380rpx": "1380rpx",
        "1381rpx": "1381rpx",
        "1382rpx": "1382rpx",
        "1383rpx": "1383rpx",
        "1384rpx": "1384rpx",
        "1385rpx": "1385rpx",
        "1386rpx": "1386rpx",
        "1387rpx": "1387rpx",
        "1388rpx": "1388rpx",
        "1389rpx": "1389rpx",
        "1390rpx": "1390rpx",
        "1391rpx": "1391rpx",
        "1392rpx": "1392rpx",
        "1393rpx": "1393rpx",
        "1394rpx": "1394rpx",
        "1395rpx": "1395rpx",
        "1396rpx": "1396rpx",
        "1397rpx": "1397rpx",
        "1398rpx": "1398rpx",
        "1399rpx": "1399rpx",
        "1400rpx": "1400rpx",
        "1401rpx": "1401rpx",
        "1402rpx": "1402rpx",
        "1403rpx": "1403rpx",
        "1404rpx": "1404rpx",
        "1405rpx": "1405rpx",
        "1406rpx": "1406rpx",
        "1407rpx": "1407rpx",
        "1408rpx": "1408rpx",
        "1409rpx": "1409rpx",
        "1410rpx": "1410rpx",
        "1411rpx": "1411rpx",
        "1412rpx": "1412rpx",
        "1413rpx": "1413rpx",
        "1414rpx": "1414rpx",
        "1415rpx": "1415rpx",
        "1416rpx": "1416rpx",
        "1417rpx": "1417rpx",
        "1418rpx": "1418rpx",
        "1419rpx": "1419rpx",
        "1420rpx": "1420rpx",
        "1421rpx": "1421rpx",
        "1422rpx": "1422rpx",
        "1423rpx": "1423rpx",
        "1424rpx": "1424rpx",
        "1425rpx": "1425rpx",
        "1426rpx": "1426rpx",
        "1427rpx": "1427rpx",
        "1428rpx": "1428rpx",
        "1429rpx": "1429rpx",
        "1430rpx": "1430rpx",
        "1431rpx": "1431rpx",
        "1432rpx": "1432rpx",
        "1433rpx": "1433rpx",
        "1434rpx": "1434rpx",
        "1435rpx": "1435rpx",
        "1436rpx": "1436rpx",
        "1437rpx": "1437rpx",
        "1438rpx": "1438rpx",
        "1439rpx": "1439rpx",
        "1440rpx": "1440rpx",
        "1441rpx": "1441rpx",
        "1442rpx": "1442rpx",
        "1443rpx": "1443rpx",
        "1444rpx": "1444rpx",
        "1445rpx": "1445rpx",
        "1446rpx": "1446rpx",
        "1447rpx": "1447rpx",
        "1448rpx": "1448rpx",
        "1449rpx": "1449rpx",
        "1450rpx": "1450rpx",
        "1451rpx": "1451rpx",
        "1452rpx": "1452rpx",
        "1453rpx": "1453rpx",
        "1454rpx": "1454rpx",
        "1455rpx": "1455rpx",
        "1456rpx": "1456rpx",
        "1457rpx": "1457rpx",
        "1458rpx": "1458rpx",
        "1459rpx": "1459rpx",
        "1460rpx": "1460rpx",
        "1461rpx": "1461rpx",
        "1462rpx": "1462rpx",
        "1463rpx": "1463rpx",
        "1464rpx": "1464rpx",
        "1465rpx": "1465rpx",
        "1466rpx": "1466rpx",
        "1467rpx": "1467rpx",
        "1468rpx": "1468rpx",
        "1469rpx": "1469rpx",
        "1470rpx": "1470rpx",
        "1471rpx": "1471rpx",
        "1472rpx": "1472rpx",
        "1473rpx": "1473rpx",
        "1474rpx": "1474rpx",
        "1475rpx": "1475rpx",
        "1476rpx": "1476rpx",
        "1477rpx": "1477rpx",
        "1478rpx": "1478rpx",
        "1479rpx": "1479rpx",
        "1480rpx": "1480rpx",
        "1481rpx": "1481rpx",
        "1482rpx": "1482rpx",
        "1483rpx": "1483rpx",
        "1484rpx": "1484rpx",
        "1485rpx": "1485rpx",
        "1486rpx": "1486rpx",
        "1487rpx": "1487rpx",
        "1488rpx": "1488rpx",
        "1489rpx": "1489rpx",
        "1490rpx": "1490rpx",
        "1491rpx": "1491rpx",
        "1492rpx": "1492rpx",
        "1493rpx": "1493rpx",
        "1494rpx": "1494rpx",
        "1495rpx": "1495rpx",
        "1496rpx": "1496rpx",
        "1497rpx": "1497rpx",
        "1498rpx": "1498rpx",
        "1499rpx": "1499rpx",
        "1500rpx": "1500rpx",
        "1501rpx": "1501rpx",
        "1502rpx": "1502rpx",
        "1503rpx": "1503rpx",
        "1504rpx": "1504rpx",
        "1505rpx": "1505rpx",
        "1506rpx": "1506rpx",
        "1507rpx": "1507rpx",
        "1508rpx": "1508rpx",
        "1509rpx": "1509rpx",
        "1510rpx": "1510rpx",
        "1511rpx": "1511rpx",
        "1512rpx": "1512rpx",
        "1513rpx": "1513rpx",
        "1514rpx": "1514rpx",
        "1515rpx": "1515rpx",
        "1516rpx": "1516rpx",
        "1517rpx": "1517rpx",
        "1518rpx": "1518rpx",
        "1519rpx": "1519rpx",
        "1520rpx": "1520rpx",
        "1521rpx": "1521rpx",
        "1522rpx": "1522rpx",
        "1523rpx": "1523rpx",
        "1524rpx": "1524rpx",
        "1525rpx": "1525rpx",
        "1526rpx": "1526rpx",
        "1527rpx": "1527rpx",
        "1528rpx": "1528rpx",
        "1529rpx": "1529rpx",
        "1530rpx": "1530rpx",
        "1531rpx": "1531rpx",
        "1532rpx": "1532rpx",
        "1533rpx": "1533rpx",
        "1534rpx": "1534rpx",
        "1535rpx": "1535rpx",
        "1536rpx": "1536rpx",
        "1537rpx": "1537rpx",
        "1538rpx": "1538rpx",
        "1539rpx": "1539rpx",
        "1540rpx": "1540rpx",
        "1541rpx": "1541rpx",
        "1542rpx": "1542rpx",
        "1543rpx": "1543rpx",
        "1544rpx": "1544rpx",
        "1545rpx": "1545rpx",
        "1546rpx": "1546rpx",
        "1547rpx": "1547rpx",
        "1548rpx": "1548rpx",
        "1549rpx": "1549rpx",
        "1550rpx": "1550rpx",
        "1551rpx": "1551rpx",
        "1552rpx": "1552rpx",
        "1553rpx": "1553rpx",
        "1554rpx": "1554rpx",
        "1555rpx": "1555rpx",
        "1556rpx": "1556rpx",
        "1557rpx": "1557rpx",
        "1558rpx": "1558rpx",
        "1559rpx": "1559rpx",
        "1560rpx": "1560rpx",
        "1561rpx": "1561rpx",
        "1562rpx": "1562rpx",
        "1563rpx": "1563rpx",
        "1564rpx": "1564rpx",
        "1565rpx": "1565rpx",
        "1566rpx": "1566rpx",
        "1567rpx": "1567rpx",
        "1568rpx": "1568rpx",
        "1569rpx": "1569rpx",
        "1570rpx": "1570rpx",
        "1571rpx": "1571rpx",
        "1572rpx": "1572rpx",
        "1573rpx": "1573rpx",
        "1574rpx": "1574rpx",
        "1575rpx": "1575rpx",
        "1576rpx": "1576rpx",
        "1577rpx": "1577rpx",
        "1578rpx": "1578rpx",
        "1579rpx": "1579rpx",
        "1580rpx": "1580rpx",
        "1581rpx": "1581rpx",
        "1582rpx": "1582rpx",
        "1583rpx": "1583rpx",
        "1584rpx": "1584rpx",
        "1585rpx": "1585rpx",
        "1586rpx": "1586rpx",
        "1587rpx": "1587rpx",
        "1588rpx": "1588rpx",
        "1589rpx": "1589rpx",
        "1590rpx": "1590rpx",
        "1591rpx": "1591rpx",
        "1592rpx": "1592rpx",
        "1593rpx": "1593rpx",
        "1594rpx": "1594rpx",
        "1595rpx": "1595rpx",
        "1596rpx": "1596rpx",
        "1597rpx": "1597rpx",
        "1598rpx": "1598rpx",
        "1599rpx": "1599rpx",
        "1600rpx": "1600rpx",
        "1601rpx": "1601rpx",
        "1602rpx": "1602rpx",
        "1603rpx": "1603rpx",
        "1604rpx": "1604rpx",
        "1605rpx": "1605rpx",
        "1606rpx": "1606rpx",
        "1607rpx": "1607rpx",
        "1608rpx": "1608rpx",
        "1609rpx": "1609rpx",
        "1610rpx": "1610rpx",
        "1611rpx": "1611rpx",
        "1612rpx": "1612rpx",
        "1613rpx": "1613rpx",
        "1614rpx": "1614rpx",
        "1615rpx": "1615rpx",
        "1616rpx": "1616rpx",
        "1617rpx": "1617rpx",
        "1618rpx": "1618rpx",
        "1619rpx": "1619rpx",
        "1620rpx": "1620rpx",
        "1621rpx": "1621rpx",
        "1622rpx": "1622rpx",
        "1623rpx": "1623rpx",
        "1624rpx": "1624rpx",
        "1625rpx": "1625rpx",
        "1626rpx": "1626rpx",
        "1627rpx": "1627rpx",
        "1628rpx": "1628rpx",
        "1629rpx": "1629rpx",
        "1630rpx": "1630rpx",
        "1631rpx": "1631rpx",
        "1632rpx": "1632rpx",
        "1633rpx": "1633rpx",
        "1634rpx": "1634rpx",
        "1635rpx": "1635rpx",
        "1636rpx": "1636rpx",
        "1637rpx": "1637rpx",
        "1638rpx": "1638rpx",
        "1639rpx": "1639rpx",
        "1640rpx": "1640rpx",
        "1641rpx": "1641rpx",
        "1642rpx": "1642rpx",
        "1643rpx": "1643rpx",
        "1644rpx": "1644rpx",
        "1645rpx": "1645rpx",
        "1646rpx": "1646rpx",
        "1647rpx": "1647rpx",
        "1648rpx": "1648rpx",
        "1649rpx": "1649rpx",
        "1650rpx": "1650rpx",
        "1651rpx": "1651rpx",
        "1652rpx": "1652rpx",
        "1653rpx": "1653rpx",
        "1654rpx": "1654rpx",
        "1655rpx": "1655rpx",
        "1656rpx": "1656rpx",
        "1657rpx": "1657rpx",
        "1658rpx": "1658rpx",
        "1659rpx": "1659rpx",
        "1660rpx": "1660rpx",
        "1661rpx": "1661rpx",
        "1662rpx": "1662rpx",
        "1663rpx": "1663rpx",
        "1664rpx": "1664rpx",
        "1665rpx": "1665rpx",
        "1666rpx": "1666rpx",
        "1667rpx": "1667rpx",
        "1668rpx": "1668rpx",
        "1669rpx": "1669rpx",
        "1670rpx": "1670rpx",
        "1671rpx": "1671rpx",
        "1672rpx": "1672rpx",
        "1673rpx": "1673rpx",
        "1674rpx": "1674rpx",
        "1675rpx": "1675rpx",
        "1676rpx": "1676rpx",
        "1677rpx": "1677rpx",
        "1678rpx": "1678rpx",
        "1679rpx": "1679rpx",
        "1680rpx": "1680rpx",
        "1681rpx": "1681rpx",
        "1682rpx": "1682rpx",
        "1683rpx": "1683rpx",
        "1684rpx": "1684rpx",
        "1685rpx": "1685rpx",
        "1686rpx": "1686rpx",
        "1687rpx": "1687rpx",
        "1688rpx": "1688rpx",
        "1689rpx": "1689rpx",
        "1690rpx": "1690rpx",
        "1691rpx": "1691rpx",
        "1692rpx": "1692rpx",
        "1693rpx": "1693rpx",
        "1694rpx": "1694rpx",
        "1695rpx": "1695rpx",
        "1696rpx": "1696rpx",
        "1697rpx": "1697rpx",
        "1698rpx": "1698rpx",
        "1699rpx": "1699rpx",
        "1700rpx": "1700rpx",
        "1701rpx": "1701rpx",
        "1702rpx": "1702rpx",
        "1703rpx": "1703rpx",
        "1704rpx": "1704rpx",
        "1705rpx": "1705rpx",
        "1706rpx": "1706rpx",
        "1707rpx": "1707rpx",
        "1708rpx": "1708rpx",
        "1709rpx": "1709rpx",
        "1710rpx": "1710rpx",
        "1711rpx": "1711rpx",
        "1712rpx": "1712rpx",
        "1713rpx": "1713rpx",
        "1714rpx": "1714rpx",
        "1715rpx": "1715rpx",
        "1716rpx": "1716rpx",
        "1717rpx": "1717rpx",
        "1718rpx": "1718rpx",
        "1719rpx": "1719rpx",
        "1720rpx": "1720rpx",
        "1721rpx": "1721rpx",
        "1722rpx": "1722rpx",
        "1723rpx": "1723rpx",
        "1724rpx": "1724rpx",
        "1725rpx": "1725rpx",
        "1726rpx": "1726rpx",
        "1727rpx": "1727rpx",
        "1728rpx": "1728rpx",
        "1729rpx": "1729rpx",
        "1730rpx": "1730rpx",
        "1731rpx": "1731rpx",
        "1732rpx": "1732rpx",
        "1733rpx": "1733rpx",
        "1734rpx": "1734rpx",
        "1735rpx": "1735rpx",
        "1736rpx": "1736rpx",
        "1737rpx": "1737rpx",
        "1738rpx": "1738rpx",
        "1739rpx": "1739rpx",
        "1740rpx": "1740rpx",
        "1741rpx": "1741rpx",
        "1742rpx": "1742rpx",
        "1743rpx": "1743rpx",
        "1744rpx": "1744rpx",
        "1745rpx": "1745rpx",
        "1746rpx": "1746rpx",
        "1747rpx": "1747rpx",
        "1748rpx": "1748rpx",
        "1749rpx": "1749rpx",
        "1750rpx": "1750rpx",
        "1751rpx": "1751rpx",
        "1752rpx": "1752rpx",
        "1753rpx": "1753rpx",
        "1754rpx": "1754rpx",
        "1755rpx": "1755rpx",
        "1756rpx": "1756rpx",
        "1757rpx": "1757rpx",
        "1758rpx": "1758rpx",
        "1759rpx": "1759rpx",
        "1760rpx": "1760rpx",
        "1761rpx": "1761rpx",
        "1762rpx": "1762rpx",
        "1763rpx": "1763rpx",
        "1764rpx": "1764rpx",
        "1765rpx": "1765rpx",
        "1766rpx": "1766rpx",
        "1767rpx": "1767rpx",
        "1768rpx": "1768rpx",
        "1769rpx": "1769rpx",
        "1770rpx": "1770rpx",
        "1771rpx": "1771rpx",
        "1772rpx": "1772rpx",
        "1773rpx": "1773rpx",
        "1774rpx": "1774rpx",
        "1775rpx": "1775rpx",
        "1776rpx": "1776rpx",
        "1777rpx": "1777rpx",
        "1778rpx": "1778rpx",
        "1779rpx": "1779rpx",
        "1780rpx": "1780rpx",
        "1781rpx": "1781rpx",
        "1782rpx": "1782rpx",
        "1783rpx": "1783rpx",
        "1784rpx": "1784rpx",
        "1785rpx": "1785rpx",
        "1786rpx": "1786rpx",
        "1787rpx": "1787rpx",
        "1788rpx": "1788rpx",
        "1789rpx": "1789rpx",
        "1790rpx": "1790rpx",
        "1791rpx": "1791rpx",
        "1792rpx": "1792rpx",
        "1793rpx": "1793rpx",
        "1794rpx": "1794rpx",
        "1795rpx": "1795rpx",
        "1796rpx": "1796rpx",
        "1797rpx": "1797rpx",
        "1798rpx": "1798rpx",
        "1799rpx": "1799rpx",
        "1800rpx": "1800rpx",
        "1801rpx": "1801rpx",
        "1802rpx": "1802rpx",
        "1803rpx": "1803rpx",
        "1804rpx": "1804rpx",
        "1805rpx": "1805rpx",
        "1806rpx": "1806rpx",
        "1807rpx": "1807rpx",
        "1808rpx": "1808rpx",
        "1809rpx": "1809rpx",
        "1810rpx": "1810rpx",
        "1811rpx": "1811rpx",
        "1812rpx": "1812rpx",
        "1813rpx": "1813rpx",
        "1814rpx": "1814rpx",
        "1815rpx": "1815rpx",
        "1816rpx": "1816rpx",
        "1817rpx": "1817rpx",
        "1818rpx": "1818rpx",
        "1819rpx": "1819rpx",
        "1820rpx": "1820rpx",
        "1821rpx": "1821rpx",
        "1822rpx": "1822rpx",
        "1823rpx": "1823rpx",
        "1824rpx": "1824rpx",
        "1825rpx": "1825rpx",
        "1826rpx": "1826rpx",
        "1827rpx": "1827rpx",
        "1828rpx": "1828rpx",
        "1829rpx": "1829rpx",
        "1830rpx": "1830rpx",
        "1831rpx": "1831rpx",
        "1832rpx": "1832rpx",
        "1833rpx": "1833rpx",
        "1834rpx": "1834rpx",
        "1835rpx": "1835rpx",
        "1836rpx": "1836rpx",
        "1837rpx": "1837rpx",
        "1838rpx": "1838rpx",
        "1839rpx": "1839rpx",
        "1840rpx": "1840rpx",
        "1841rpx": "1841rpx",
        "1842rpx": "1842rpx",
        "1843rpx": "1843rpx",
        "1844rpx": "1844rpx",
        "1845rpx": "1845rpx",
        "1846rpx": "1846rpx",
        "1847rpx": "1847rpx",
        "1848rpx": "1848rpx",
        "1849rpx": "1849rpx",
        "1850rpx": "1850rpx",
        "1851rpx": "1851rpx",
        "1852rpx": "1852rpx",
        "1853rpx": "1853rpx",
        "1854rpx": "1854rpx",
        "1855rpx": "1855rpx",
        "1856rpx": "1856rpx",
        "1857rpx": "1857rpx",
        "1858rpx": "1858rpx",
        "1859rpx": "1859rpx",
        "1860rpx": "1860rpx",
        "1861rpx": "1861rpx",
        "1862rpx": "1862rpx",
        "1863rpx": "1863rpx",
        "1864rpx": "1864rpx",
        "1865rpx": "1865rpx",
        "1866rpx": "1866rpx",
        "1867rpx": "1867rpx",
        "1868rpx": "1868rpx",
        "1869rpx": "1869rpx",
        "1870rpx": "1870rpx",
        "1871rpx": "1871rpx",
        "1872rpx": "1872rpx",
        "1873rpx": "1873rpx",
        "1874rpx": "1874rpx",
        "1875rpx": "1875rpx",
        "1876rpx": "1876rpx",
        "1877rpx": "1877rpx",
        "1878rpx": "1878rpx",
        "1879rpx": "1879rpx",
        "1880rpx": "1880rpx",
        "1881rpx": "1881rpx",
        "1882rpx": "1882rpx",
        "1883rpx": "1883rpx",
        "1884rpx": "1884rpx",
        "1885rpx": "1885rpx",
        "1886rpx": "1886rpx",
        "1887rpx": "1887rpx",
        "1888rpx": "1888rpx",
        "1889rpx": "1889rpx",
        "1890rpx": "1890rpx",
        "1891rpx": "1891rpx",
        "1892rpx": "1892rpx",
        "1893rpx": "1893rpx",
        "1894rpx": "1894rpx",
        "1895rpx": "1895rpx",
        "1896rpx": "1896rpx",
        "1897rpx": "1897rpx",
        "1898rpx": "1898rpx",
        "1899rpx": "1899rpx",
        "1900rpx": "1900rpx",
        "1901rpx": "1901rpx",
        "1902rpx": "1902rpx",
        "1903rpx": "1903rpx",
        "1904rpx": "1904rpx",
        "1905rpx": "1905rpx",
        "1906rpx": "1906rpx",
        "1907rpx": "1907rpx",
        "1908rpx": "1908rpx",
        "1909rpx": "1909rpx",
        "1910rpx": "1910rpx",
        "1911rpx": "1911rpx",
        "1912rpx": "1912rpx",
        "1913rpx": "1913rpx",
        "1914rpx": "1914rpx",
        "1915rpx": "1915rpx",
        "1916rpx": "1916rpx",
        "1917rpx": "1917rpx",
        "1918rpx": "1918rpx",
        "1919rpx": "1919rpx",
        "1920rpx": "1920rpx",
        "1921rpx": "1921rpx",
        "1922rpx": "1922rpx",
        "1923rpx": "1923rpx",
        "1924rpx": "1924rpx",
        "1925rpx": "1925rpx",
        "1926rpx": "1926rpx",
        "1927rpx": "1927rpx",
        "1928rpx": "1928rpx",
        "1929rpx": "1929rpx",
        "1930rpx": "1930rpx",
        "1931rpx": "1931rpx",
        "1932rpx": "1932rpx",
        "1933rpx": "1933rpx",
        "1934rpx": "1934rpx",
        "1935rpx": "1935rpx",
        "1936rpx": "1936rpx",
        "1937rpx": "1937rpx",
        "1938rpx": "1938rpx",
        "1939rpx": "1939rpx",
        "1940rpx": "1940rpx",
        "1941rpx": "1941rpx",
        "1942rpx": "1942rpx",
        "1943rpx": "1943rpx",
        "1944rpx": "1944rpx",
        "1945rpx": "1945rpx",
        "1946rpx": "1946rpx",
        "1947rpx": "1947rpx",
        "1948rpx": "1948rpx",
        "1949rpx": "1949rpx",
        "1950rpx": "1950rpx",
        "1951rpx": "1951rpx",
        "1952rpx": "1952rpx",
        "1953rpx": "1953rpx",
        "1954rpx": "1954rpx",
        "1955rpx": "1955rpx",
        "1956rpx": "1956rpx",
        "1957rpx": "1957rpx",
        "1958rpx": "1958rpx",
        "1959rpx": "1959rpx",
        "1960rpx": "1960rpx",
        "1961rpx": "1961rpx",
        "1962rpx": "1962rpx",
        "1963rpx": "1963rpx",
        "1964rpx": "1964rpx",
        "1965rpx": "1965rpx",
        "1966rpx": "1966rpx",
        "1967rpx": "1967rpx",
        "1968rpx": "1968rpx",
        "1969rpx": "1969rpx",
        "1970rpx": "1970rpx",
        "1971rpx": "1971rpx",
        "1972rpx": "1972rpx",
        "1973rpx": "1973rpx",
        "1974rpx": "1974rpx",
        "1975rpx": "1975rpx",
        "1976rpx": "1976rpx",
        "1977rpx": "1977rpx",
        "1978rpx": "1978rpx",
        "1979rpx": "1979rpx",
        "1980rpx": "1980rpx",
        "1981rpx": "1981rpx",
        "1982rpx": "1982rpx",
        "1983rpx": "1983rpx",
        "1984rpx": "1984rpx",
        "1985rpx": "1985rpx",
        "1986rpx": "1986rpx",
        "1987rpx": "1987rpx",
        "1988rpx": "1988rpx",
        "1989rpx": "1989rpx",
        "1990rpx": "1990rpx",
        "1991rpx": "1991rpx",
        "1992rpx": "1992rpx",
        "1993rpx": "1993rpx",
        "1994rpx": "1994rpx",
        "1995rpx": "1995rpx",
        "1996rpx": "1996rpx",
        "1997rpx": "1997rpx",
        "1998rpx": "1998rpx",
        "1999rpx": "1999rpx",
        "2000rpx": "2000rpx",
        "2001rpx": "2001rpx",
        "2002rpx": "2002rpx",
        "2003rpx": "2003rpx",
        "2004rpx": "2004rpx",
        "2005rpx": "2005rpx",
        "2006rpx": "2006rpx",
        "2007rpx": "2007rpx",
        "2008rpx": "2008rpx",
        "2009rpx": "2009rpx",
        "2010rpx": "2010rpx",
        "2011rpx": "2011rpx",
        "2012rpx": "2012rpx",
        "2013rpx": "2013rpx",
        "2014rpx": "2014rpx",
        "2015rpx": "2015rpx",
        "2016rpx": "2016rpx",
        "2017rpx": "2017rpx",
        "2018rpx": "2018rpx",
        "2019rpx": "2019rpx",
        "2020rpx": "2020rpx",
        "2021rpx": "2021rpx",
        "2022rpx": "2022rpx",
        "2023rpx": "2023rpx",
        "2024rpx": "2024rpx",
        "2025rpx": "2025rpx",
        "2026rpx": "2026rpx",
        "2027rpx": "2027rpx",
        "2028rpx": "2028rpx",
        "2029rpx": "2029rpx",
        "2030rpx": "2030rpx",
        "2031rpx": "2031rpx",
        "2032rpx": "2032rpx",
        "2033rpx": "2033rpx",
        "2034rpx": "2034rpx",
        "2035rpx": "2035rpx",
        "2036rpx": "2036rpx",
        "2037rpx": "2037rpx",
        "2038rpx": "2038rpx",
        "2039rpx": "2039rpx",
        "2040rpx": "2040rpx",
        "2041rpx": "2041rpx",
        "2042rpx": "2042rpx",
        "2043rpx": "2043rpx",
        "2044rpx": "2044rpx",
        "2045rpx": "2045rpx",
        "2046rpx": "2046rpx",
        "2047rpx": "2047rpx",
        "2048rpx": "2048rpx"
      },
      borderRadius: {
        rpx: "1rpx",
        "1rpx": "1rpx",
        "2rpx": "2rpx",
        "3rpx": "3rpx",
        "4rpx": "4rpx",
        "5rpx": "5rpx",
        "6rpx": "6rpx",
        "7rpx": "7rpx",
        "8rpx": "8rpx",
        "9rpx": "9rpx",
        "10rpx": "10rpx",
        "11rpx": "11rpx",
        "12rpx": "12rpx",
        "13rpx": "13rpx",
        "14rpx": "14rpx",
        "15rpx": "15rpx",
        "16rpx": "16rpx",
        "17rpx": "17rpx",
        "18rpx": "18rpx",
        "19rpx": "19rpx",
        "20rpx": "20rpx",
        "21rpx": "21rpx",
        "22rpx": "22rpx",
        "23rpx": "23rpx",
        "24rpx": "24rpx",
        "25rpx": "25rpx",
        "26rpx": "26rpx",
        "27rpx": "27rpx",
        "28rpx": "28rpx",
        "29rpx": "29rpx",
        "30rpx": "30rpx",
        "31rpx": "31rpx",
        "32rpx": "32rpx",
        "33rpx": "33rpx",
        "34rpx": "34rpx",
        "35rpx": "35rpx",
        "36rpx": "36rpx",
        "37rpx": "37rpx",
        "38rpx": "38rpx",
        "39rpx": "39rpx",
        "40rpx": "40rpx",
        "41rpx": "41rpx",
        "42rpx": "42rpx",
        "43rpx": "43rpx",
        "44rpx": "44rpx",
        "45rpx": "45rpx",
        "46rpx": "46rpx",
        "47rpx": "47rpx",
        "48rpx": "48rpx",
        "49rpx": "49rpx",
        "50rpx": "50rpx",
        "51rpx": "51rpx",
        "52rpx": "52rpx",
        "53rpx": "53rpx",
        "54rpx": "54rpx",
        "55rpx": "55rpx",
        "56rpx": "56rpx",
        "57rpx": "57rpx",
        "58rpx": "58rpx",
        "59rpx": "59rpx",
        "60rpx": "60rpx",
        "61rpx": "61rpx",
        "62rpx": "62rpx",
        "63rpx": "63rpx",
        "64rpx": "64rpx"
      },
      borderWidth: {
        rpx: "1rpx",
        "1rpx": "1rpx",
        "2rpx": "2rpx",
        "3rpx": "3rpx",
        "4rpx": "4rpx",
        "5rpx": "5rpx",
        "6rpx": "6rpx",
        "7rpx": "7rpx",
        "8rpx": "8rpx",
        "9rpx": "9rpx",
        "10rpx": "10rpx",
        "11rpx": "11rpx",
        "12rpx": "12rpx",
        "13rpx": "13rpx",
        "14rpx": "14rpx",
        "15rpx": "15rpx",
        "16rpx": "16rpx",
        "17rpx": "17rpx",
        "18rpx": "18rpx",
        "19rpx": "19rpx",
        "20rpx": "20rpx",
        "21rpx": "21rpx",
        "22rpx": "22rpx",
        "23rpx": "23rpx",
        "24rpx": "24rpx",
        "25rpx": "25rpx",
        "26rpx": "26rpx",
        "27rpx": "27rpx",
        "28rpx": "28rpx",
        "29rpx": "29rpx",
        "30rpx": "30rpx",
        "31rpx": "31rpx",
        "32rpx": "32rpx"
      }
    }
  }
};

const easyPreset = ({
  selectors = [".easy"],
  mediaQuery = "",
  fontSize = "24px"
} = {}) => ({
  content: [],
  plugins: [
    themeSwapper({
      themes: [
        {
          name: "base",
          selectors,
          mediaQuery,
          theme: {
            fontSize: {
              DEFAULT: fontSize
            }
          }
        }
      ]
    })
  ]
});

export { antDesignPreset, antDesignV4Preset, basePreset, easyPreset, elementPlusPreset, miniprogramBasePreset };
